/// <reference types="node" />
import { EventEmitter } from 'events';
import * as Protocol from '../types/tot';
import { Connection } from './Connection';
import { OutputResult } from './Output';
import { IRunnerConfig } from './Runner';
import Target from './Target';
export interface BrowserParams extends IRunnerConfig {
}
export declare type BrowserTargetId = string;
export declare enum EBrowserEvents {
    Disconnected = "disconnected",
    TargetCreated = "targetcreated",
    TargetDestroyed = "targetdestroyed",
    TargetInfoChanged = "targetinfochanged",
}
export interface TargetHistory extends Protocol.Target.TargetInfo {
    reason: string;
    version: number;
    ts: string;
}
export declare class Browser extends EventEmitter {
    private closeCallback;
    private isAnalysing;
    private params;
    private pendingRunners;
    private pendingRunnersCallback;
    private runnerResults;
    private targets;
    private targetsHistory;
    private depth;
    connection: Connection;
    userDataDir: string;
    static create(connection: Connection, params: BrowserParams, closeCallback: () => Promise<{}>, userDataDir: string): Promise<Browser>;
    constructor(connection: Connection, params: BrowserParams, closeCallback: () => Promise<{}>, userDataDir: string);
    private createTarget();
    private targetCreated(event);
    private targetDestroyed(event);
    private targetInfoChanged(event);
    private runnerResultCallback(report);
    analyse(url: string): Promise<OutputResult>;
    close(): Promise<void>;
    getTargets(): Promise<Target[]>;
    getTargetsHistory(): Promise<TargetHistory[]>;
    updateTargetsHistory(targetInfo: Protocol.Target.TargetInfo, reason: string): void;
}
