"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
// Native.
var util_1 = require("util");
// Package.
var debug = require("debug");
var error = require("../utils/error");
var JsHandle_1 = require("./JsHandle");
var getExceptionMessage_1 = require("../utils/getExceptionMessage");
// Code.
var debugVerbose = debug('di:verbose:executionContext');
var debugWarn = debug('di:warn:executionContext');
var ExecutionContext = /** @class */ (function () {
    function ExecutionContext(client, contextPayload, objectHandleFactory) {
        this.client = client;
        this.contextId = contextPayload.id;
        if (contextPayload.auxData) {
            var frameId = contextPayload.auxData.frameId;
            if (frameId && util_1.isString(frameId)) {
                this.frameId = frameId;
            }
            var isDefault = contextPayload.auxData.isDefault;
            if (isDefault && util_1.isBoolean(isDefault)) {
                this.isDefault = isDefault;
            }
        }
        else {
            this.isDefault = true;
        }
        this.objectHandleFactory = objectHandleFactory;
    }
    ExecutionContext.prototype.evaluate = function (pageFunction) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        return __awaiter(this, void 0, void 0, function () {
            var objectHandle, result, err_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        debugVerbose("evaluate");
                        return [4 /*yield*/, this.evaluateHandle.apply(this, [pageFunction].concat(args))];
                    case 1:
                        objectHandle = _a.sent();
                        if (!objectHandle) return [3 /*break*/, 7];
                        result = void 0;
                        _a.label = 2;
                    case 2:
                        _a.trys.push([2, 4, , 5]);
                        return [4 /*yield*/, objectHandle.jsonValue()];
                    case 3:
                        result = _a.sent();
                        return [3 /*break*/, 5];
                    case 4:
                        err_1 = _a.sent();
                        debugWarn(err_1);
                        return [3 /*break*/, 5];
                    case 5: return [4 /*yield*/, objectHandle.dispose()];
                    case 6:
                        _a.sent();
                        return [2 /*return*/, result];
                    case 7: return [2 /*return*/];
                }
            });
        });
    };
    ExecutionContext.prototype.evaluateHandle = function (pageFunction) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        return __awaiter(this, void 0, void 0, function () {
            function convertArgument(arg) {
                if (Object.is(arg, -0)) {
                    return { unserializableValue: '-0' };
                }
                if (Object.is(arg, Infinity)) {
                    return { unserializableValue: 'Infinity' };
                }
                if (Object.is(arg, -Infinity)) {
                    return { unserializableValue: '-Infinity' };
                }
                if (Object.is(arg, NaN)) {
                    return { unserializableValue: 'NaN' };
                }
                var objectHandle = arg && arg instanceof JsHandle_1.default ? arg : null;
                if (objectHandle) {
                    if (objectHandle.context !== this) {
                        throw new error.FlowError('ExecutionContext: objectHandle can be evaluated only in the context they were created');
                    }
                    if (objectHandle.disposed) {
                        throw new error.FlowError('ExecutionContext: objectHandle is disposed');
                    }
                    if (objectHandle.remoteObject.unserializableValue) {
                        return {
                            unserializableValue: objectHandle.remoteObject.unserializableValue,
                        };
                    }
                    if (!objectHandle.remoteObject.objectId) {
                        return { value: objectHandle.remoteObject.value };
                    }
                    return { objectId: objectHandle.remoteObject.objectId };
                }
                return { value: arg };
            }
            var contextId, expression, evaluateParams, _a, exceptionDetails, remoteObject, err_2, callFunctionOnParameters, _b, exceptionDetails, remoteObject, err_3;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0:
                        debugVerbose("evaluateHandle");
                        if (!(typeof pageFunction === 'string')) return [3 /*break*/, 4];
                        contextId = this.contextId;
                        expression = pageFunction;
                        evaluateParams = {
                            expression: expression,
                            contextId: contextId,
                            returnByValue: false,
                            awaitPromise: true,
                        };
                        _c.label = 1;
                    case 1:
                        _c.trys.push([1, 3, , 4]);
                        return [4 /*yield*/, this.client.send('Runtime.evaluate', evaluateParams)];
                    case 2:
                        _a = _c.sent(), exceptionDetails = _a.exceptionDetails, remoteObject = _a.result;
                        if (exceptionDetails) {
                            throw new error.ProtocolError('ExecutionContext: evaluation failed: ' +
                                getExceptionMessage_1.default(exceptionDetails));
                        }
                        return [2 /*return*/, this.objectHandleFactory(remoteObject)];
                    case 3:
                        err_2 = _c.sent();
                        debugWarn(err_2);
                        return [2 /*return*/];
                    case 4:
                        callFunctionOnParameters = {
                            functionDeclaration: pageFunction.toString(),
                            executionContextId: this.contextId,
                            arguments: args.map(convertArgument.bind(this)),
                            returnByValue: false,
                            awaitPromise: true,
                        };
                        _c.label = 5;
                    case 5:
                        _c.trys.push([5, 7, , 8]);
                        return [4 /*yield*/, this.client.send('Runtime.callFunctionOn', callFunctionOnParameters)];
                    case 6:
                        _b = _c.sent(), exceptionDetails = _b.exceptionDetails, remoteObject = _b.result;
                        if (exceptionDetails) {
                            throw new error.ProtocolError('ExecutionContext: evaluation failed: ' +
                                getExceptionMessage_1.default(exceptionDetails));
                        }
                        return [2 /*return*/, this.objectHandleFactory(remoteObject)];
                    case 7:
                        err_3 = _c.sent();
                        debugWarn(err_3);
                        return [2 /*return*/];
                    case 8: return [2 /*return*/];
                }
            });
        });
    };
    ExecutionContext.prototype.queryObjects = function (objectHandle) {
        return __awaiter(this, void 0, void 0, function () {
            var queryObjectsParams, response;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        debugVerbose("queryObjects");
                        if (objectHandle.disposed) {
                            throw new error.FlowError('ExecutionContext: objectHandle is disposed');
                        }
                        if (!objectHandle.remoteObject.objectId) {
                            throw new error.FlowError('ExecutionContext: objectHandle must not be referencing primitive value');
                        }
                        queryObjectsParams = {
                            prototypeObjectId: objectHandle.remoteObject.objectId,
                        };
                        return [4 /*yield*/, this.client.send('Runtime.queryObjects', queryObjectsParams)];
                    case 1:
                        response = _a.sent();
                        return [2 /*return*/, this.objectHandleFactory(response.objects)];
                }
            });
        });
    };
    return ExecutionContext;
}());
exports.default = ExecutionContext;
