"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
// Package.
var debug = require("debug");
// Code.
var debugVerbose = debug('di:verbose:frame');
var debugWarn = debug('di:warn:frame');
var Frame = /** @class */ (function () {
    function Frame(client, page, parentFrame, id) {
        this.childFrames = new Set();
        this.detached = false;
        this.waitTasks = new Set();
        this.name = '';
        this.url = '';
        this.lifecycleEvents = new Set();
        this.client = client;
        this.parentFrame = parentFrame;
        this.page = page;
        this.id = id;
        if (this.parentFrame) {
            this.parentFrame.childFrames.add(this);
        }
    }
    Frame.prototype.setDefaultContext = function (context) {
        var _this = this;
        debugVerbose("Set default context");
        if (context) {
            if (this.contextResolveCallback) {
                this.contextResolveCallback.call(null, context);
            }
            this.contextResolveCallback = undefined;
            for (var _i = 0, _a = Array.from(this.waitTasks); _i < _a.length; _i++) {
                var waitTask = _a[_i];
                waitTask.rerun();
            }
        }
        else {
            this.contextPromise = new Promise(function (fulfill) {
                _this.contextResolveCallback = fulfill;
            });
        }
    };
    Frame.prototype.executionContext = function () {
        return this.contextPromise;
    };
    Frame.prototype.evaluate = function (pageFunction) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        return __awaiter(this, void 0, void 0, function () {
            var context;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.contextPromise];
                    case 1:
                        context = _a.sent();
                        if (context) {
                            return [2 /*return*/, context.evaluate.apply(context, [pageFunction].concat(args))];
                        }
                        else {
                            debugWarn("Required context not found");
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    Frame.prototype.content = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.evaluate(function () {
                            var result = '';
                            if (document.doctype) {
                                result = new XMLSerializer().serializeToString(document.doctype);
                            }
                            if (document.documentElement) {
                                result += document.documentElement.outerHTML;
                            }
                            return result;
                        })];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    Frame.prototype.setContent = function (html) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.evaluate(function (h) {
                            document.open();
                            document.write(h);
                            document.close();
                        }, html)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    Frame.prototype.text = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.evaluate(function () {
                            var result = '';
                            if (document.documentElement) {
                                result += document.documentElement.outerText;
                            }
                            return result;
                        })];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    Frame.prototype.navigated = function (framePayload) {
        this.name = framePayload.name || '';
        this.url = framePayload.url;
    };
    Frame.prototype.detach = function () {
        this.waitTasks.forEach(function (waitTask) {
            waitTask.terminate(new Error('waitForSelector failed: frame got detached.'));
        });
        if (this.parentFrame) {
            this.parentFrame.childFrames.delete(this);
        }
        this.parentFrame = null;
        this.detached = true;
    };
    Frame.prototype.getChildFrames = function () {
        return Array.from(this.childFrames);
    };
    Frame.prototype.addWaitTask = function (waitTask) {
        this.waitTasks.add(waitTask);
    };
    Frame.prototype.getWaitTask = function () {
        return this.waitTasks;
    };
    Frame.prototype.removeWaitTask = function (waitTask) {
        this.waitTasks.delete(waitTask);
    };
    Frame.prototype.isDetached = function () {
        return this.detached;
    };
    Frame.prototype.onLifecycleEvent = function (loaderId, name) {
        if (name === 'init') {
            this.loaderId = loaderId;
            this.lifecycleEvents.clear();
        }
        this.lifecycleEvents.add(name);
    };
    return Frame;
}());
exports.default = Frame;
