"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// Code.
var apiCoverage = null;
var Helper = /** @class */ (function () {
    function Helper() {
    }
    Helper.addEventListener = function (emitter, eventName, handler) {
        emitter.on(eventName, handler);
        return { emitter: emitter, eventName: eventName, handler: handler };
    };
    Helper.isString = function (obj) {
        return typeof obj === 'string' || obj instanceof String;
    };
    Helper.isNumber = function (obj) {
        return typeof obj === 'number' || obj instanceof Number;
    };
    Helper.promisify = function (nodeFunction) {
        function promisified() {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return new Promise(function (resolve, reject) {
                function callback(err) {
                    var result = [];
                    for (var _i = 1; _i < arguments.length; _i++) {
                        result[_i - 1] = arguments[_i];
                    }
                    if (err)
                        return reject(err);
                    if (result.length === 1)
                        return resolve(result[0]);
                    return resolve(result);
                }
                nodeFunction.call.apply(nodeFunction, [null].concat(args, [callback]));
            });
        }
        return promisified;
    };
    Helper.removeEventListeners = function (listeners) {
        for (var _i = 0, listeners_1 = listeners; _i < listeners_1.length; _i++) {
            var listener = listeners_1[_i];
            listener.emitter.removeListener(listener.eventName, listener.handler);
        }
        listeners.splice(0, listeners.length);
    };
    Helper.tracePublicAPI = function (classType) {
        var className = classType.prototype.constructor.name;
        className =
            className.substring(0, 1).toLowerCase() + className.substring(1);
        var debug = require('debug')("di:public:" + className);
        if (!debug.enabled && !apiCoverage)
            return;
        var _loop_1 = function (methodName) {
            var method = Reflect.get(classType.prototype, methodName);
            if (methodName === 'constructor' ||
                typeof methodName !== 'string' ||
                methodName.startsWith('_') ||
                typeof method !== 'function')
                return "continue";
            if (apiCoverage)
                apiCoverage.set(className + "." + methodName, false);
            Reflect.set(classType.prototype, methodName, function () {
                var args = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    args[_i] = arguments[_i];
                }
                var argsText = args.map(stringifyArgument).join(', ');
                var callsite = className + "." + methodName + "(" + argsText + ")";
                if (debug.enabled)
                    debug(callsite);
                if (apiCoverage)
                    apiCoverage.set(className + "." + methodName, true);
                return method.call.apply(method, [this].concat(args));
            });
        };
        for (var _i = 0, _a = Reflect.ownKeys(classType.prototype); _i < _a.length; _i++) {
            var methodName = _a[_i];
            _loop_1(methodName);
        }
        if (classType.Events) {
            if (apiCoverage) {
                for (var _b = 0, _c = Object.values(classType.Events); _b < _c.length; _b++) {
                    var event_1 = _c[_b];
                    apiCoverage.set(className + ".emit(" + JSON.stringify(event_1) + ")", false);
                }
            }
            var method_1 = Reflect.get(classType.prototype, 'emit');
            Reflect.set(classType.prototype, 'emit', function (event) {
                var args = [];
                for (var _i = 1; _i < arguments.length; _i++) {
                    args[_i - 1] = arguments[_i];
                }
                var argsText = [JSON.stringify(event)]
                    .concat(args.map(stringifyArgument))
                    .join(', ');
                if (debug.enabled && this.listenerCount(event))
                    debug(className + ".emit(" + argsText + ")");
                if (apiCoverage && this.listenerCount(event))
                    apiCoverage.set(className + ".emit(" + JSON.stringify(event) + ")", true);
                return method_1.call.apply(method_1, [this, event].concat(args));
            });
        }
        /**
         * @param {!Object} arg
         * @return {string}
         */
        function stringifyArgument(arg) {
            if (Helper.isString(arg) || Helper.isNumber(arg) || !arg)
                return JSON.stringify(arg);
            if (typeof arg === 'function') {
                var text = arg
                    .toString()
                    .split('\n')
                    .map(function (line) { return line.trim(); })
                    .join('');
                if (text.length > 20)
                    text = text.substring(0, 20) + '…';
                return "\"" + text + "\"";
            }
            var state = {};
            var keys = Object.keys(arg);
            for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
                var key = keys_1[_i];
                var value = arg[key];
                if (Helper.isString(value) || Helper.isNumber(value))
                    state[key] = JSON.stringify(value);
            }
            var name = arg.constructor.name === 'Object' ? '' : arg.constructor.name;
            return name + JSON.stringify(state);
        }
    };
    Helper.evaluationString = function (fun) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        return "(" + fun + ")(" + args.map(serializeArgument).join(',') + ")";
        function serializeArgument(arg) {
            if (Object.is(arg, undefined))
                return 'undefined';
            return JSON.stringify(arg);
        }
    };
    return Helper;
}());
exports.default = Helper;
