"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
// Native.
var childProcess = require("child_process");
var fs = require("fs-extra");
var os = require("os");
var path = require("path");
// Package.
var debug = require("debug");
var readline = require("readline");
var removeFolder = require("rimraf");
// Internal.
var Connection_1 = require("./Connection");
var Helper_1 = require("./Helper");
// Code.
var debugVerbose = debug('di:verbose:launcher');
var mkdtempAsync = Helper_1.default.promisify(fs.mkdtemp);
var removeFolderAsync = Helper_1.default.promisify(removeFolder);
exports.CHROME_PROFILE_PATH = path.join(os.tmpdir(), 'devtools-interface_dev_profile-');
var DEFAULT_ARGS = [
    '--disable-background-networking',
    '--disable-background-timer-throttling',
    '--disable-client-side-phishing-detection',
    '--disable-default-apps',
    '--disable-extensions',
    '--disable-hang-monitor',
    '--disable-popup-blocking',
    '--disable-prompt-on-repost',
    '--disable-sync',
    '--disable-translate',
    '--metrics-recording-only',
    '--no-first-run',
    '--remote-debugging-port=0',
    '--safebrowsing-disable-auto-update',
    '--disable-web-security',
    '--ignore-certificate-errors',
    '--ignore-certificate-errors-spki-list',
    // Only for Linux env.
    "--disable-setuid-sandbox",
    "--no-sandbox",
    // Mandatory for Amazon Lambda.
    '--single-process',
    // ALL
    '--enable-devtools-experiments',
    '--enable-logging',
    '--v=0',
    // Cache
    '--disable-gpu-program-cache',
    '--disable-gpu-shader-disk-cache',
    '--v8-cache-options=off',
    '--v8-cache-strategies-for-cache-storage=off',
];
var AUTOMATION_ARGS = [
    '--enable-automation',
    '--password-store=basic',
    '--use-mock-keychain',
];
var Launcher = /** @class */ (function () {
    function Launcher() {
    }
    Launcher.launch = function (options) {
        return __awaiter(this, void 0, void 0, function () {
            function killChrome() {
                Helper_1.default.removeEventListeners(listeners);
                if (chromeProcess.pid) {
                    if (temporaryUserDataDir) {
                        // Force kill chrome.
                        if (process.platform === 'win32')
                            childProcess.execSync("taskkill /pid " + chromeProcess.pid + " /T /F");
                        else
                            process.kill(-chromeProcess.pid, 'SIGKILL');
                    }
                    else {
                        // Terminate chrome gracefully.
                        if (process.platform === 'win32')
                            childProcess.execSync("taskkill /pid " + chromeProcess.pid);
                        else
                            process.kill(-chromeProcess.pid, 'SIGTERM');
                    }
                }
                if (temporaryUserDataDir) {
                    // Attempt to remove temporary profile directory to avoid littering.
                    try {
                        removeFolder.sync(temporaryUserDataDir);
                    }
                    catch (err) { }
                }
                return waitForChromeToClose;
            }
            function forceKillChrome() {
                Helper_1.default.removeEventListeners(listeners);
                if (chromeProcess.pid && !chromeProcess.killed && !chromeClosed) {
                    // Force kill chrome.
                    if (process.platform === 'win32')
                        childProcess.execSync("taskkill /pid " + chromeProcess.pid + " /T /F");
                    else
                        process.kill(-chromeProcess.pid, 'SIGKILL');
                }
                // Attempt to remove temporary profile directory to avoid littering.
                try {
                    if (temporaryUserDataDir) {
                        removeFolder.sync(temporaryUserDataDir);
                    }
                }
                catch (e) { }
            }
            var temporaryUserDataDir, chromeArguments, chromeExecutable, chromeProcess, chromeClosed, waitForChromeToClose, listeners, connectionDelay, browserWSEndpoint, connection, err_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        debugVerbose("Launch options: %j", options);
                        temporaryUserDataDir = '';
                        chromeArguments = DEFAULT_ARGS;
                        chromeExecutable = options.executablePath;
                        if (options.appMode) {
                            options.headless = false;
                        }
                        else {
                            chromeArguments.push.apply(chromeArguments, AUTOMATION_ARGS);
                        }
                        if (!(!options.args ||
                            !options.args.some(function (arg) { return arg.startsWith('--user-data-dir'); }))) return [3 /*break*/, 3];
                        if (!!options.userDataDir) return [3 /*break*/, 2];
                        return [4 /*yield*/, mkdtempAsync(exports.CHROME_PROFILE_PATH)];
                    case 1:
                        temporaryUserDataDir = (_a.sent());
                        debugVerbose("Created temporaryUserDataDir: " + temporaryUserDataDir);
                        _a.label = 2;
                    case 2:
                        chromeArguments.push("--user-data-dir=" + (options.userDataDir || temporaryUserDataDir) + "/user-data", "--homedir=" + (options.userDataDir || temporaryUserDataDir) + "/homedir", "--data-path=" + (options.userDataDir || temporaryUserDataDir) + "/data-path", "--disk-cache-dir=" + (options.userDataDir || temporaryUserDataDir) + "/disk-cache");
                        _a.label = 3;
                    case 3:
                        if (options.devtools === true) {
                            chromeArguments.push('--auto-open-devtools-for-tabs');
                            options.headless = false;
                        }
                        if (options.headless) {
                            chromeArguments.push('--headless', 
                            // '--disable-gpu',
                            '--hide-scrollbars', '--mute-audio');
                        }
                        if (options.proxy) {
                            chromeArguments.push("--proxy-server=" + options.proxy);
                        }
                        if (Array.isArray(options.args)) {
                            chromeArguments.push.apply(chromeArguments, options.args);
                        }
                        chromeProcess = childProcess.spawn(chromeExecutable, chromeArguments, {
                            detached: true,
                            env: options.env || process.env,
                        });
                        if (options.dumpio) {
                            chromeProcess.stdout.pipe(process.stdout);
                            chromeProcess.stderr.pipe(process.stderr);
                        }
                        chromeClosed = false;
                        waitForChromeToClose = new Promise(function (fulfill, reject) {
                            chromeProcess.once('close', function () {
                                chromeClosed = true;
                                // Cleanup as processes exit.
                                if (temporaryUserDataDir) {
                                    removeFolderAsync(temporaryUserDataDir)
                                        .then(function () { return fulfill(); })
                                        .catch(function (err) { return reject(err); });
                                }
                                else {
                                    fulfill();
                                }
                            });
                        });
                        listeners = [
                            Helper_1.default.addEventListener(process, 'exit', forceKillChrome),
                        ];
                        if (options.handleSIGINT !== false) {
                            listeners.push(Helper_1.default.addEventListener(process, 'SIGINT', forceKillChrome));
                        }
                        if (options.handleSIGTERM !== false) {
                            listeners.push(Helper_1.default.addEventListener(process, 'SIGTERM', killChrome));
                        }
                        if (options.handleSIGHUP !== false) {
                            listeners.push(Helper_1.default.addEventListener(process, 'SIGHUP', killChrome));
                        }
                        _a.label = 4;
                    case 4:
                        _a.trys.push([4, 7, , 8]);
                        connectionDelay = options.slowMo || 0;
                        return [4 /*yield*/, waitForWSEndpoint(chromeProcess, options.timeout || 30 * 1000)];
                    case 5:
                        browserWSEndpoint = (_a.sent());
                        debugVerbose("Listening on %s", browserWSEndpoint);
                        return [4 /*yield*/, Connection_1.Connection.create(browserWSEndpoint, connectionDelay)];
                    case 6:
                        connection = _a.sent();
                        return [2 /*return*/, {
                                connection: connection,
                                closeCallback: killChrome,
                                userDataDir: temporaryUserDataDir,
                            }];
                    case 7:
                        err_1 = _a.sent();
                        forceKillChrome();
                        throw err_1;
                    case 8: return [2 /*return*/];
                }
            });
        });
    };
    return Launcher;
}());
exports.Launcher = Launcher;
function waitForWSEndpoint(chromeProcess, timeout) {
    return new Promise(function (resolve, reject) {
        var rl = readline.createInterface({ input: chromeProcess.stderr });
        var stderr = '';
        var listeners = [
            Helper_1.default.addEventListener(rl, 'line', onLine),
            Helper_1.default.addEventListener(rl, 'close', function () { return onClose(); }),
            Helper_1.default.addEventListener(chromeProcess, 'exit', function () { return onClose(); }),
            Helper_1.default.addEventListener(chromeProcess, 'error', function (error) { return onClose(error); }),
        ];
        var timeoutId = timeout ? setTimeout(onTimeout, timeout) : 0;
        function onClose(error) {
            cleanup();
            reject(new Error([
                'Failed to launch chrome!' + (error ? ' ' + error.message : ''),
                stderr,
            ].join('\n')));
        }
        function onTimeout() {
            cleanup();
            reject(new Error("Timed out after " + timeout + " ms while trying to connect to Chrome!"));
        }
        function onLine(line) {
            stderr += line + '\n';
            var match = line.match(/^DevTools listening on (ws:\/\/.*)$/);
            if (!match)
                return;
            cleanup();
            resolve(match[1]);
        }
        function cleanup() {
            if (timeoutId)
                clearTimeout(timeoutId);
            Helper_1.default.removeEventListeners(listeners);
        }
    });
}
