"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
// Package.
var _ = require("lodash");
var debug = require("debug");
var Helper_1 = require("./Helper");
var FrameManager_1 = require("./FrameManager");
// Code.
var debugVerbose = debug('di:verbose:navigatorWatcher');
var debugWarn = debug('di:warn:navigatorWatcher');
var ENavigatorWatcher;
(function (ENavigatorWatcher) {
    ENavigatorWatcher["DOMContentLoaded"] = "domcontentloaded";
    ENavigatorWatcher["Load"] = "load";
    ENavigatorWatcher["NetworkIdle"] = "networkidle0";
    ENavigatorWatcher["NetworkAlmostIdle"] = "networkidle2";
})(ENavigatorWatcher = exports.ENavigatorWatcher || (exports.ENavigatorWatcher = {}));
var protocolLifecycleToENavigatorWatcher = {
    DOMContentLoaded: ENavigatorWatcher.DOMContentLoaded,
    load: ENavigatorWatcher.Load,
    networkIdle: ENavigatorWatcher.NetworkIdle,
    networkAlmostIdle: ENavigatorWatcher.NetworkAlmostIdle,
};
var crawlerToProtocolLifecycle = {
    load: 'load',
    domcontentloaded: 'DOMContentLoaded',
    networkidle0: 'networkIdle',
    networkidle2: 'networkAlmostIdle',
};
var NavigatorWatcher = /** @class */ (function () {
    function NavigatorWatcher(frameManager, frame, options) {
        var _this = this;
        this.eventListeners = [];
        this.pendingEvents = new Set();
        this.expectedLifecycle = [];
        var waitUntil = [ENavigatorWatcher.Load];
        if (options && Array.isArray(options.waitUntil)) {
            waitUntil = options.waitUntil.slice();
        }
        else if (options && typeof options.waitUntil === 'string') {
            waitUntil = [options.waitUntil];
        }
        this.expectedLifecycle = waitUntil.map(function (value) {
            var protocolEvent = crawlerToProtocolLifecycle[value];
            return protocolEvent;
        });
        this.frameManager = frameManager;
        this.frame = frame;
        this.timeout = _.get(options, 'timeout', 30000);
        this.initialLoaderId = this.frame && this.frame.loaderId;
        this.eventListeners = [
            Helper_1.default.addEventListener(this.frameManager, FrameManager_1.default.Events.LifecycleEvent, this.checkLifecycleComplete.bind(this)),
            Helper_1.default.addEventListener(this.frameManager, FrameManager_1.default.Events.FrameDetached, this.checkLifecycleComplete.bind(this)),
        ];
        var lifecycleCompletePromise = new Promise(function (fulfill) {
            _this.lifecycleCompleteCallback = fulfill;
        });
        this._navigationPromise = Promise.race([
            this.createTimeoutPromise(),
            lifecycleCompletePromise,
        ]).then(function (error) {
            _this.cleanup();
            return error;
        });
    }
    NavigatorWatcher.prototype.navigationPromise = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this._navigationPromise];
            });
        });
    };
    NavigatorWatcher.prototype.checkLifecycleComplete = function () {
        // We expect navigation to commit.
        if (this.frame && this.frame.loaderId === this.initialLoaderId)
            return;
        if (this.frame && !checkLifecycle(this.frame, this.expectedLifecycle))
            return;
        this.lifecycleCompleteCallback();
        function checkLifecycle(frame, expectedLifecycle) {
            for (var _i = 0, expectedLifecycle_1 = expectedLifecycle; _i < expectedLifecycle_1.length; _i++) {
                var event_1 = expectedLifecycle_1[_i];
                if (!frame.lifecycleEvents.has(event_1))
                    return false;
            }
            for (var _a = 0, _b = frame.getChildFrames(); _a < _b.length; _a++) {
                var child = _b[_a];
                if (!checkLifecycle(child, expectedLifecycle))
                    return false;
            }
            return true;
        }
    };
    NavigatorWatcher.prototype.createTimeoutPromise = function () {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            var errorMessage;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!!this.timeout) return [3 /*break*/, 2];
                        return [4 /*yield*/, new Promise(function () { })];
                    case 1: return [2 /*return*/, _a.sent()];
                    case 2:
                        errorMessage = 'Navigation Timeout Exceeded: ' + this.timeout + 'ms exceeded';
                        return [2 /*return*/, new Promise(function (fulfill) { return (_this.maximumTimer = setTimeout(fulfill, _this.timeout)); }).then(function () {
                                // return new Error(errorMessage)
                                debugWarn(errorMessage);
                                return null;
                            })];
                }
            });
        });
    };
    NavigatorWatcher.prototype.cleanup = function () {
        Helper_1.default.removeEventListeners(this.eventListeners);
        clearTimeout(this.idleTimer);
        clearTimeout(this.maximumTimer);
    };
    NavigatorWatcher.prototype.onLifecycleEvent = function (event) {
        if (event.frameId !== this.frameId) {
            return;
        }
        var protocolLifecycleName = _.get(protocolLifecycleToENavigatorWatcher, event.name);
        if (!protocolLifecycleName) {
            return;
        }
        this.pendingEvents.delete(protocolLifecycleName);
        if (this.pendingEvents.size === 0) {
            this.pendingEventsCallback();
        }
    };
    NavigatorWatcher.prototype.waitForNavigation = function () {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            var navigationPromises, watchdog, pendingEventsFired, error;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        debugVerbose("waitForNavigation");
                        navigationPromises = [];
                        if (this.timeout) {
                            watchdog = new Promise(function (fulfill) { return (_this.maximumTimer = setTimeout(fulfill, _this.timeout)); }).then(function () { return 'Navigation Timeout Exceeded: ' + _this.timeout + 'ms exceeded'; });
                            navigationPromises.push(watchdog);
                        }
                        this.eventListeners.push(Helper_1.default.addEventListener(this.client, 'Page.lifecycleEvent', this.onLifecycleEvent.bind(this)));
                        pendingEventsFired = new Promise(function (fulfill) { return (_this.pendingEventsCallback = fulfill); }).then(function () { return null; });
                        navigationPromises.push(pendingEventsFired);
                        return [4 /*yield*/, Promise.race(navigationPromises)];
                    case 1:
                        error = _a.sent();
                        this.cleanup();
                        return [2 /*return*/, error ? new Error(error) : null];
                }
            });
        });
    };
    NavigatorWatcher.prototype.cancel = function () {
        Helper_1.default.removeEventListeners(this.eventListeners);
        this.lifecycleCompleteCallback(new Error('Navigation failed'));
        this.cleanup();
    };
    return NavigatorWatcher;
}());
exports.default = NavigatorWatcher;
