/// <reference types="node" />
import { EventEmitter } from 'events';
import Session from './Session';
export default class NetworkManager extends EventEmitter {
    private attemptedAuthentications;
    private client;
    private credentials?;
    private interceptionIdToRequest;
    private protocolRequestInterceptionEnabled;
    private requestHashToRequestIds;
    private requestHashToInterceptionIds;
    private requestIdToRequest;
    private userRequestInterceptionEnabled;
    extraHTTPHeaders: {
        [key: string]: string;
    };
    constructor(client: Session);
    static readonly Events: {
        Request: string;
        Response: string;
        RequestFailed: string;
        RequestFinished: string;
    };
    private handleRequestRedirect(request, redirectStatus, redirectHeaders);
    private handleRequestStart(requestId, interceptionId, url, resourceType, requestPayload);
    private onLoadingFailed(event);
    private onLoadingFinished(event);
    private onRequestIntercepted(event);
    private onResponseReceived(event);
    private onRequestWillBeSent(event);
    setUserAgent(userAgent: string): Promise<void>;
    authenticate(credentials: {
        username: string;
        password: string;
    }): Promise<void>;
    updateProtocolRequestInterception(): Promise<void>;
}
