"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
// Native.
var events_1 = require("events");
// Internal.
var WebInspector_1 = require("./WebInspector");
var NetworkRecorder = /** @class */ (function (_super) {
    __extends(NetworkRecorder, _super);
    function NetworkRecorder() {
        var _this = _super.call(this) || this;
        _this.records = [];
        _this.startedRequestCount = 0;
        _this.finishedRequestCount = 0;
        _this.networkManager = WebInspector_1.default.NetworkManager.createWithFakeTarget();
        _this.networkManager.addEventListener(_this.EventTypes.RequestStarted, _this.onRequestStarted.bind(_this));
        _this.networkManager.addEventListener(_this.EventTypes.RequestFinished, _this.onRequestFinished.bind(_this));
        return _this;
    }
    Object.defineProperty(NetworkRecorder.prototype, "EventTypes", {
        get: function () {
            return WebInspector_1.default.NetworkManager.Events;
        },
        enumerable: true,
        configurable: true
    });
    NetworkRecorder.prototype.activeRequestCount = function () {
        return this.startedRequestCount - this.finishedRequestCount;
    };
    NetworkRecorder.prototype.onRequestStarted = function (request) {
        this.startedRequestCount++;
        this.records.push(request.data);
        // If only one request in progress, emit event that
        // we've transitioned from idle to busy.
        if (this.isBusy()) {
            this.emit('networkbusy');
        }
        // If exactly three requests in progress, we've
        // transitioned from 2-idle to 2-busy.
        if (this.is2Buzy()) {
            this.emit('network-2-busy');
        }
    };
    NetworkRecorder.prototype.onRequestFinished = function (request) {
        this.finishedRequestCount++;
        this.emit('requestloaded', request.data);
        // If no requests in progress, emit event that
        // we've transitioned from busy to idle.
        if (this.isIdle()) {
            this.emit('networkidle');
        }
        // If one or two request are in progress, emit event
        // that we've transitioned from busy to 2-idle.
        if (this.is2Idle()) {
            this.emit('network-2-idle');
        }
    };
    NetworkRecorder.prototype.onRequestWillBeSent = function (params) {
        // NOTE:
        //   - data.timestamp -> time
        //   - data.type -> resourceType
        this.networkManager._dispatcher.requestWillBeSent(params.requestId, params.frameId, params.loaderId, params.documentURL, params.request, params.timestamp, params.wallTime, params.initiator, params.redirectResponse, params.type);
    };
    NetworkRecorder.prototype.onRequestServedFromCache = function (params) {
        this.networkManager._dispatcher.requestServedFromCache(params.requestId);
    };
    NetworkRecorder.prototype.onResponseReceived = function (params) {
        // NOTE:
        //   - data.timestamp -> time
        //   - data.type -> resourceType
        this.networkManager._dispatcher.responseReceived(params.requestId, params.frameId, params.loaderId, params.timestamp, params.type, params.response);
    };
    NetworkRecorder.prototype.onDataReceived = function (params) {
        // NOTE:
        //   - data.timestamp -> time
        this.networkManager._dispatcher.dataReceived(params.requestId, params.timestamp, params.dataLength, params.encodedDataLength);
    };
    NetworkRecorder.prototype.onLoadingFinished = function (params) {
        // NOTE:
        //   - data.timestamp -> finishTime
        this.networkManager._dispatcher.loadingFinished(params.requestId, params.timestamp, params.encodedDataLength);
    };
    NetworkRecorder.prototype.onLoadingFailed = function (params) {
        // NOTE:
        //   - data.errorText -> localizedDescription
        //   - data.timestamp -> time
        //   - data.type -> resourceType
        this.networkManager._dispatcher.loadingFailed(params.requestId, params.timestamp, params.type, params.errorText, params.canceled, params.blockedReason);
    };
    NetworkRecorder.prototype.onResourceChangedPriority = function (params) {
        this.networkManager._dispatcher.resourceChangedPriority(params.requestId, params.newPriority, params.timestamp);
    };
    NetworkRecorder.prototype.isIdle = function () {
        return this.activeRequestCount() === 0;
    };
    NetworkRecorder.prototype.isBusy = function () {
        return this.activeRequestCount() === 1;
    };
    NetworkRecorder.prototype.is2Idle = function () {
        return this.activeRequestCount() <= 2;
    };
    NetworkRecorder.prototype.is2Buzy = function () {
        return this.activeRequestCount() === 3;
    };
    NetworkRecorder.prototype.getRecords = function () {
        return this.records;
    };
    NetworkRecorder.prototype.dispatch = function (method, params) {
        if (!method.startsWith('Network.')) {
            return;
        }
        switch (method) {
            case 'Network.requestWillBeSent':
                return this.onRequestWillBeSent(params);
            case 'Network.requestServedFromCache':
                return this.onRequestServedFromCache(params);
            case 'Network.responseReceived':
                return this.onResponseReceived(params);
            case 'Network.dataReceived':
                return this.onDataReceived(params);
            case 'Network.loadingFinished':
                return this.onLoadingFinished(params);
            case 'Network.loadingFailed':
                return this.onLoadingFailed(params);
            case 'Network.resourceChangedPriority':
                return this.onResourceChangedPriority(params);
            default:
                return;
        }
    };
    return NetworkRecorder;
}(events_1.EventEmitter));
exports.default = NetworkRecorder;
