/// <reference types="node" />
import { EventEmitter } from 'events';
import * as Protocol from '../types/tot';
import Frame from './Frame';
import Element from './Element';
import { EmulationViewport } from './EmulationManager';
import { INavigatorWatcherOptions } from './NavigatorWatcher';
import Session from './Session';
import { Keyboard, Mouse, Touchscreen } from './Input';
import { DevtoolLogRecord } from './DevtoolLogManager';
export default class Page extends EventEmitter {
    private client;
    private emulationManager;
    private frameManager;
    private networkManager;
    private viewport;
    initialFrameTree: Protocol.Page.FrameResourceTree;
    keyboard: Keyboard;
    mouse: Mouse;
    touchscreen: Touchscreen;
    userDataDir: string;
    static readonly Events: {
        Console: string;
        Dialog: string;
        Error: string;
        FrameAttached: string;
        FrameDetached: string;
        FrameNavigated: string;
        Load: string;
        Metrics: string;
        PageError: string;
        Request: string;
        RequestFailed: string;
        RequestFinished: string;
        Response: string;
    };
    static create(client: Session, userDataDir: string): Promise<Page>;
    constructor(client: Session, frameTree: Protocol.Page.FrameResourceTree, userDataDir: string);
    private onCertificateError(event);
    authenticate(credentials: {
        username: string;
        password: string;
    }): Promise<void>;
    mainFrame(): Frame | undefined;
    mainFrameId(): string;
    startRecordDevtoolLogs(): void;
    endRecordDevtoolLogs(): DevtoolLogRecord[];
    getMeta(): {
        frameId: string;
        targetId: string;
        targetVersion: number;
    };
    getNetworkRecords(): any[];
    beginNetworkStatusMonitoring(url: string): Promise<void>;
    endNetworkStatusMonitoring(): Promise<void>;
    navigate(url: string, options?: INavigatorWatcherOptions): Promise<Response>;
    getTargetId(): string;
    emit(event: string | symbol, ...args: any[]): boolean;
    on(event: string | symbol, listener: (...args: any[]) => void): this;
    once(event: string | symbol, listener: (...args: any[]) => void): this;
    off(event: string | symbol, listener: (...args: any[]) => void): this;
    send<A, B>(method: string, params?: A): Promise<B>;
    querySelectorAll(selector: string): Promise<Element[]>;
    getObjectProperty(objectId: string, propName: string): Promise<string | null>;
    content(): Promise<string | null>;
    setContent(html: string): Promise<void>;
    text(): Promise<string | null>;
    emulate(deviceName: string): Promise<[void, void]>;
    screenshot(params?: {
        quality?: number;
    }): Promise<string>;
    setViewport(viewport: EmulationViewport): Promise<void>;
    setUserAgent(userAgent: string): Promise<void>;
}
