"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
// Package.
var _ = require("lodash");
var debug = require("debug");
var Helper_1 = require("./Helper");
var statusTexts_1 = require("../utils/statusTexts");
// Code.
var debugError = debug('di:error:request');
var debugVerbose = debug('di:verbose:request');
var Request = /** @class */ (function () {
    function Request(client, requestId, interceptionId, allowInterception, url, resourceType, payload) {
        var _this = this;
        this.headers = {};
        this.interceptionHandled = false;
        this.response = null;
        this.client = client;
        this.requestId = requestId;
        this.interceptionId = interceptionId;
        this.allowInterception = allowInterception;
        this.url = url;
        this.resourceType = resourceType.toLowerCase();
        this.completePromise = new Promise(function (fulfill) {
            _this.completePromiseFulfill = fulfill;
        });
        this.method = payload.method;
        this.postData = payload.postData;
        Object.keys(payload.headers).forEach(function (key) {
            _this.headers[key.toLowerCase()] = payload.headers[key];
        });
    }
    Request.prototype.abort = function () {
        return __awaiter(this, void 0, void 0, function () {
            var params;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        console.assert(this.allowInterception, 'Request Interception is not enabled!');
                        console.assert(!this.interceptionHandled, 'Request is already handled!');
                        this.interceptionHandled = true;
                        if (!(typeof this.interceptionId === 'string')) return [3 /*break*/, 2];
                        params = {
                            interceptionId: this.interceptionId,
                            errorReason: 'Failed',
                        };
                        debugVerbose("continueInterceptedRequest params: %j", params);
                        return [4 /*yield*/, this.client
                                .send('Network.continueInterceptedRequest', params)
                                .catch(function (error) {
                                // In certain cases, protocol will return error if the request was already canceled
                                // or the page was closed. We should tolerate these errors.
                                debugError(error);
                            })];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2: return [2 /*return*/];
                }
            });
        });
    };
    Request.prototype.continue = function (overrides) {
        return __awaiter(this, void 0, void 0, function () {
            var params;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        console.assert(this.allowInterception, 'Request Interception is not enabled!');
                        console.assert(!this.interceptionHandled, 'Request is already handled!');
                        this.interceptionHandled = true;
                        if (!(typeof this.interceptionId === 'string')) return [3 /*break*/, 2];
                        params = {
                            interceptionId: this.interceptionId,
                            url: _.get(overrides, 'url'),
                            method: _.get(overrides, 'method'),
                            postData: _.get(overrides, 'postData'),
                            headers: _.get(overrides, 'headers'),
                        };
                        debugVerbose("continueInterceptedRequest params: %j", params);
                        return [4 /*yield*/, this.client
                                .send('Network.continueInterceptedRequest', params)
                                .catch(function (error) {
                                // In certain cases, protocol will return error if the request was already canceled
                                // or the page was closed. We should tolerate these errors.
                                debugError(error);
                            })];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2: return [2 /*return*/];
                }
            });
        });
    };
    Request.prototype.respond = function (response) {
        return __awaiter(this, void 0, void 0, function () {
            var responseBody, responseHeaders, _i, _a, header, statusCode, statusText, statusLine, CRLF, text, _b, _c, header, responseBuffer;
            return __generator(this, function (_d) {
                switch (_d.label) {
                    case 0:
                        // Mocking responses for dataURL requests is not currently supported.
                        if (this.url && this.url.startsWith('data:'))
                            return [2 /*return*/];
                        console.assert(this.allowInterception, 'Request Interception is not enabled!');
                        console.assert(!this.interceptionHandled, 'Request is already handled!');
                        this.interceptionHandled = true;
                        responseBody = response.body && Helper_1.default.isString(response.body)
                            ? Buffer.from(response.body)
                            : response.body || null;
                        responseHeaders = {};
                        if (response.headers) {
                            for (_i = 0, _a = Object.keys(response.headers); _i < _a.length; _i++) {
                                header = _a[_i];
                                responseHeaders[header.toLowerCase()] = response.headers[header];
                            }
                        }
                        if (response.contentType)
                            responseHeaders['content-type'] = response.contentType;
                        if (responseBody && !('content-length' in responseHeaders)) {
                            responseHeaders['content-length'] = Buffer.byteLength(responseBody);
                        }
                        statusCode = response.status || 200;
                        statusText = statusTexts_1.default[statusCode] || '';
                        statusLine = "HTTP/1.1 " + statusCode + " " + statusText;
                        CRLF = '\r\n';
                        text = statusLine + CRLF;
                        for (_b = 0, _c = Object.keys(responseHeaders); _b < _c.length; _b++) {
                            header = _c[_b];
                            text += header + ': ' + responseHeaders[header] + CRLF;
                        }
                        text += CRLF;
                        responseBuffer = Buffer.from(text, 'utf8');
                        if (responseBody) {
                            responseBuffer = Buffer.concat([responseBuffer, responseBody]);
                        }
                        return [4 /*yield*/, this.client
                                .send('Network.continueInterceptedRequest', {
                                interceptionId: this.interceptionId,
                                rawResponse: responseBuffer.toString('base64'),
                            })
                                .catch(function (error) {
                                // In certain cases, protocol will return error if the request was already canceled
                                // or the page was closed. We should tolerate these errors.
                                debugError(error);
                            })];
                    case 1:
                        _d.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    return Request;
}());
exports.default = Request;
