"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
// Native.
var events_1 = require("events");
// Package.
var debug = require("debug");
var error = require("../utils/error");
var DevtoolLogManager_1 = require("./DevtoolLogManager");
var NetworkRecorder_1 = require("./NetworkRecorder");
// Code.
var debugVerbose = debug('di:verbose:session');
var debugSilly = debug('di:silly:session');
var Session = /** @class */ (function (_super) {
    __extends(Session, _super);
    function Session(connection, targetId, sessionId) {
        var _this = _super.call(this) || this;
        _this.callbacks = new Map();
        _this.lastId = 0;
        _this.networkStatusMonitor = new NetworkRecorder_1.default();
        _this.devtoolLogManager = new DevtoolLogManager_1.default();
        _this.targetVersion = 1;
        _this.connection = connection;
        _this.sessionId = sessionId;
        _this.setTargetId(targetId);
        return _this;
    }
    Session.prototype.dispose = function () {
        return __awaiter(this, void 0, void 0, function () {
            var params;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        debugVerbose("Dispose session");
                        params = {
                            targetId: this.targetId,
                        };
                        return [4 /*yield*/, this.connection.send('Target.closeTarget', params)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    Session.prototype.setEvent = function (message) {
        this.devtoolLogManager.setEvent(message);
    };
    Session.prototype.setTargetId = function (id) {
        this.targetId = id;
        this.devtoolLogManager.setTargetId(id);
    };
    Session.prototype.setTargetVersion = function (version) {
        this.targetVersion = version;
        this.devtoolLogManager.setTargetVersion(version);
    };
    Session.prototype.onClosed = function () {
        debugVerbose("onClosed");
        this.callbacks.forEach(function (callback) {
            callback.reject(new error.ProtocolError("Session (" + callback.method + "): Target closed"));
        });
        this.callbacks.clear();
    };
    Session.prototype.onMessage = function (message) {
        debugSilly("\u25C0 RECV " + message);
        var object = JSON.parse(message);
        if (object.id && this.callbacks.has(object.id)) {
            var callback = this.callbacks.get(object.id);
            this.callbacks.delete(object.id);
            if (callback) {
                if (object.error) {
                    new error.ProtocolError("Session (" + callback.method + "): " + object.error.message + " " + object
                        .error.data);
                }
                callback.resolve(object.result);
            }
        }
        else {
            console.assert(!object.id);
            this.emit(object.method, object.params);
            this.devtoolLogManager.record(object);
            this.networkStatusMonitor.dispatch(object.method, object.params);
        }
    };
    Session.prototype.send = function (method, params) {
        var _this = this;
        if (!this.connection) {
            return Promise.reject(new error.FlowError("Session (" + method + "): Session closed. Most likely the page has been closed"));
        }
        var id = ++this.lastId;
        var message = JSON.stringify({ id: id, method: method, params: params });
        debugSilly("SEND \u25BA " + message);
        var targetParams = {
            message: message,
            sessionId: this.sessionId,
        };
        this.connection
            .send('Target.sendMessageToTarget', targetParams)
            .catch(function (err) {
            // The response from target might have been already dispatched.
            if (!_this.callbacks.has(id)) {
                return;
            }
            var callback = _this.callbacks.get(id);
            _this.callbacks.delete(id);
            if (callback) {
                return callback.reject(err);
            }
        });
        return new Promise(function (resolve, reject) {
            return _this.callbacks.set(id, { resolve: resolve, reject: reject, method: method });
        });
    };
    Session.prototype.beginNetworkStatusMonitoring = function (startingUrl) {
        this.monitoredUrl = startingUrl;
        this.networkStatusMonitor.on('requestloaded', this.callbackNetworkStatusMonitoring);
    };
    Session.prototype.getNetworkRecords = function () {
        return this.networkStatusMonitor.getRecords();
    };
    Session.prototype.callbackNetworkStatusMonitoring = function (redirectRequest) {
        // Ignore if this is not a redirected request.
        if (!redirectRequest.redirectSource) {
            return;
        }
        var earlierRequest = redirectRequest.redirectSource;
        if (earlierRequest.url === this.monitoredUrl) {
            this.monitoredUrl = redirectRequest.url;
        }
    };
    Session.prototype.endNetworkStatusMonitoring = function () {
        this.networkStatusMonitor.removeListener('requestloaded', this.callbackNetworkStatusMonitoring);
        return this.monitoredUrl;
    };
    return Session;
}(events_1.EventEmitter));
exports.default = Session;
