"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// Package.
var debug = require("debug");
// Code.
var debugVerbose = debug('di:verbose:runner');
var ETracer;
(function (ETracer) {
    ETracer["Span"] = "span";
})(ETracer = exports.ETracer || (exports.ETracer = {}));
var ETracerEvent;
(function (ETracerEvent) {
    // Events.
    ETracerEvent["BeforeAll"] = "beforeAll";
    ETracerEvent["BeforeLoad"] = "beforeLoad";
    ETracerEvent["DomContentEvent"] = "domContentEvent";
    ETracerEvent["LoadEvent"] = "loadEvent";
    ETracerEvent["AfterLoad"] = "afterLoad";
    ETracerEvent["AfterAll"] = "afterAll";
})(ETracerEvent = exports.ETracerEvent || (exports.ETracerEvent = {}));
var beforeAllEvent = { event: ETracerEvent.BeforeAll };
var domContentEvent = { event: ETracerEvent.DomContentEvent };
var loadEvent = { event: ETracerEvent.LoadEvent };
var beforeLoadEvent = { event: ETracerEvent.BeforeLoad };
var afterLoadEvent = { event: ETracerEvent.AfterLoad };
var afterAllEvent = { event: ETracerEvent.AfterAll };
var Tracer = /** @class */ (function () {
    function Tracer(page) {
        this.page = page;
    }
    Tracer.prototype.prepare = function () {
        var _this = this;
        debugVerbose("prepare");
        this.page.emit(ETracer.Span, beforeAllEvent);
        this.page.once('Page.domContentEventFired', function () {
            return _this.page.emit(ETracer.Span, domContentEvent);
        });
        this.page.once('Page.loadEventFired', function () {
            return _this.page.emit(ETracer.Span, loadEvent);
        });
    };
    Tracer.prototype.beforeLoad = function () {
        debugVerbose("beforeLoad");
        this.page.emit(ETracer.Span, beforeLoadEvent);
    };
    Tracer.prototype.afterLoad = function () {
        debugVerbose("afterLoad");
        this.page.emit(ETracer.Span, afterLoadEvent);
    };
    Tracer.prototype.dispose = function () {
        debugVerbose("dispose");
        this.page.emit(ETracer.Span, afterAllEvent);
    };
    return Tracer;
}());
exports.default = Tracer;
