"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
// Native.
var util_1 = require("util");
// Internal.
var error = require("../utils/error");
var Helper_1 = require("./Helper");
// Code.
var WaitTask = /** @class */ (function () {
    function WaitTask(frame, predicateBody, polling, timeout) {
        var _this = this;
        this.runCount = 0;
        this.terminated = false;
        if (util_1.isString(polling)) {
            if (polling !== 'raf' && polling !== 'mutation') {
                throw new error.ValidationError("Unknown polling option: " + polling);
            }
        }
        else if (util_1.isNumber(polling)) {
            if (polling <= 0) {
                throw new error.ValidationError("Cannot poll with non-positive interval: " + polling);
            }
        }
        else {
            throw new error.ValidationError("Unknown polling option: " + polling);
        }
        this.frame = frame;
        this.pageScript = Helper_1.default.evaluationString(waitForPredicatePageFunction, predicateBody, polling, timeout);
        this.frame.addWaitTask(this);
        this.promise = new Promise(function (resolve, reject) {
            _this.resolve = resolve;
            _this.reject = reject;
        });
        this.timeoutTimer = setTimeout(function () {
            return _this.terminate(new Error("waiting failed: timeout " + timeout + "ms exceeded"));
        }, timeout);
        this.rerun();
    }
    WaitTask.prototype.cleanup = function () {
        clearTimeout(this.timeoutTimer);
        this.frame.removeWaitTask(this);
    };
    WaitTask.prototype.rerun = function () {
        return __awaiter(this, void 0, void 0, function () {
            var runCount, success, error, err_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        runCount = ++this.runCount;
                        success = false;
                        error = null;
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        return [4 /*yield*/, this.frame.evaluate(this.pageScript)];
                    case 2:
                        success = _a.sent();
                        return [3 /*break*/, 4];
                    case 3:
                        err_1 = _a.sent();
                        error = err_1;
                        return [3 /*break*/, 4];
                    case 4:
                        if (this.terminated || runCount !== this.runCount)
                            return [2 /*return*/];
                        // Ignore timeouts in pageScript - we track timeouts ourselves.
                        if (!success && !error)
                            return [2 /*return*/];
                        // When the page is navigated, the promise is rejected.
                        // We will try again in the new execution context.
                        if (error && error.message.includes('Execution context was destroyed'))
                            return [2 /*return*/];
                        // We could have tried to evaluate in a context which was already
                        // destroyed.
                        if (error &&
                            error.message.includes('Cannot find context with specified id'))
                            return [2 /*return*/];
                        if (error)
                            this.reject(error);
                        else
                            this.resolve();
                        this.cleanup();
                        return [2 /*return*/];
                }
            });
        });
    };
    WaitTask.prototype.terminate = function (error) {
        this.terminated = true;
        this.reject(error);
        this.cleanup();
    };
    return WaitTask;
}());
exports.default = WaitTask;
function waitForPredicatePageFunction(predicateBody, polling, timeout) {
    return __awaiter(this, void 0, void 0, function () {
        function pollMutation() {
            if (predicate())
                return Promise.resolve();
            var fulfill;
            var result = new Promise(function (x) { return (fulfill = x); });
            var observer = new MutationObserver(function () {
                if (timedOut || predicate()) {
                    observer.disconnect();
                    fulfill();
                }
            });
            observer.observe(document, {
                childList: true,
                subtree: true,
                attributes: true,
            });
            return result;
        }
        function pollRaf() {
            var fulfill;
            var result = new Promise(function (x) { return (fulfill = x); });
            onRaf();
            return result;
            function onRaf() {
                if (timedOut || predicate())
                    fulfill();
                else
                    requestAnimationFrame(onRaf);
            }
        }
        function pollInterval(pollInterval) {
            var fulfill;
            var result = new Promise(function (x) { return (fulfill = x); });
            onTimeout();
            return result;
            function onTimeout() {
                if (timedOut || predicate())
                    fulfill();
                else
                    setTimeout(onTimeout, pollInterval);
            }
        }
        var predicate, timedOut;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    predicate = new Function(predicateBody);
                    timedOut = false;
                    setTimeout(function () { return (timedOut = true); }, timeout);
                    if (!(polling === 'raf')) return [3 /*break*/, 2];
                    return [4 /*yield*/, pollRaf()];
                case 1:
                    _a.sent();
                    return [3 /*break*/, 6];
                case 2:
                    if (!(polling === 'mutation')) return [3 /*break*/, 4];
                    return [4 /*yield*/, pollMutation()];
                case 3:
                    _a.sent();
                    return [3 /*break*/, 6];
                case 4:
                    if (!(typeof polling === 'number')) return [3 /*break*/, 6];
                    return [4 /*yield*/, pollInterval(polling)];
                case 5:
                    _a.sent();
                    _a.label = 6;
                case 6: return [2 /*return*/, !timedOut];
            }
        });
    });
}
