/**
 * Debugging Protocol Domains
 * Generated on Mon Nov 20 2017 15:41:33 GMT+0100 (CET)
 */
export declare namespace Inspector {
    type DetachedParameters = {
        /** The reason why connection has been terminated. */
        reason: string;
    };
}
export declare namespace Memory {
    /** Memory pressure level. */
    type PressureLevel = "moderate" | "critical";
    type GetDOMCountersReturn = {
        documents: number;
        nodes: number;
        jsEventListeners: number;
    };
    type SetPressureNotificationsSuppressedParameters = {
        /** If true, memory pressure notifications will be suppressed. */
        suppressed: boolean;
    };
    type SimulatePressureNotificationParameters = {
        /** Memory pressure level of the notification. */
        level: PressureLevel;
    };
}
export declare namespace Performance {
    /** Run-time execution metric. */
    interface Metric {
        /** Metric name. */
        name: string;
        /** Metric value. */
        value: number;
    }
    type MetricsParameters = {
        /** Current values of the metrics. */
        metrics: Metric[];
        /** Timestamp title. */
        title: string;
    };
    type GetMetricsReturn = {
        /** Current values for run-time metrics. */
        metrics: Metric[];
    };
}
/** Actions and events related to the inspected page belong to the page domain. */
export declare namespace Page {
    /** Resource type as it was perceived by the rendering engine. */
    type ResourceType = "Document" | "Stylesheet" | "Image" | "Media" | "Font" | "Script" | "TextTrack" | "XHR" | "Fetch" | "EventSource" | "WebSocket" | "Manifest" | "Other";
    /** Unique frame identifier. */
    type FrameId = string;
    /** Information about the Frame on the page. */
    interface Frame {
        /** Frame unique identifier. */
        id: string;
        /** Parent frame identifier. */
        parentId?: string;
        /** Identifier of the loader associated with this frame. */
        loaderId: Network.LoaderId;
        /** Frame's name as specified in the tag. */
        name?: string;
        /** Frame document's URL. */
        url: string;
        /** Frame document's security origin. */
        securityOrigin: string;
        /** Frame document's mimeType as determined by the browser. */
        mimeType: string;
        /** If the frame failed to load, this contains the URL that could not be loaded. */
        unreachableUrl?: string;
    }
    /** Information about the Resource on the page. */
    interface FrameResource {
        /** Resource URL. */
        url: string;
        /** Type of this resource. */
        type: ResourceType;
        /** Resource mimeType as determined by the browser. */
        mimeType: string;
        /** last-modified timestamp as reported by server. */
        lastModified?: Network.TimeSinceEpoch;
        /** Resource content size. */
        contentSize?: number;
        /** True if the resource failed to load. */
        failed?: boolean;
        /** True if the resource was canceled during loading. */
        canceled?: boolean;
    }
    /** Information about the Frame hierarchy along with their cached resources. */
    interface FrameResourceTree {
        /** Frame information for this tree item. */
        frame: Frame;
        /** Child frames. */
        childFrames?: FrameResourceTree[];
        /** Information about frame resources. */
        resources: FrameResource[];
    }
    /** Information about the Frame hierarchy. */
    interface FrameTree {
        /** Frame information for this tree item. */
        frame: Frame;
        /** Child frames. */
        childFrames?: FrameTree[];
    }
    /** Unique script identifier. */
    type ScriptIdentifier = string;
    /** Transition type. */
    type TransitionType = "link" | "typed" | "auto_bookmark" | "auto_subframe" | "manual_subframe" | "generated" | "auto_toplevel" | "form_submit" | "reload" | "keyword" | "keyword_generated" | "other";
    /** Navigation history entry. */
    interface NavigationEntry {
        /** Unique id of the navigation history entry. */
        id: number;
        /** URL of the navigation history entry. */
        url: string;
        /** URL that the user typed in the url bar. */
        userTypedURL: string;
        /** Title of the navigation history entry. */
        title: string;
        /** Transition type. */
        transitionType: TransitionType;
    }
    /** Screencast frame metadata. */
    interface ScreencastFrameMetadata {
        /** Top offset in DIP. */
        offsetTop: number;
        /** Page scale factor. */
        pageScaleFactor: number;
        /** Device screen width in DIP. */
        deviceWidth: number;
        /** Device screen height in DIP. */
        deviceHeight: number;
        /** Position of horizontal scroll in CSS pixels. */
        scrollOffsetX: number;
        /** Position of vertical scroll in CSS pixels. */
        scrollOffsetY: number;
        /** Frame swap timestamp. */
        timestamp?: Network.TimeSinceEpoch;
    }
    /** Javascript dialog type. */
    type DialogType = "alert" | "confirm" | "prompt" | "beforeunload";
    /** Error while paring app manifest. */
    interface AppManifestError {
        /** Error message. */
        message: string;
        /** If criticial, this is a non-recoverable parse error. */
        critical: number;
        /** Error line. */
        line: number;
        /** Error column. */
        column: number;
    }
    /** Layout viewport position and dimensions. */
    interface LayoutViewport {
        /** Horizontal offset relative to the document (CSS pixels). */
        pageX: number;
        /** Vertical offset relative to the document (CSS pixels). */
        pageY: number;
        /** Width (CSS pixels), excludes scrollbar if present. */
        clientWidth: number;
        /** Height (CSS pixels), excludes scrollbar if present. */
        clientHeight: number;
    }
    /** Visual viewport position, dimensions, and scale. */
    interface VisualViewport {
        /** Horizontal offset relative to the layout viewport (CSS pixels). */
        offsetX: number;
        /** Vertical offset relative to the layout viewport (CSS pixels). */
        offsetY: number;
        /** Horizontal offset relative to the document (CSS pixels). */
        pageX: number;
        /** Vertical offset relative to the document (CSS pixels). */
        pageY: number;
        /** Width (CSS pixels), excludes scrollbar if present. */
        clientWidth: number;
        /** Height (CSS pixels), excludes scrollbar if present. */
        clientHeight: number;
        /** Scale relative to the ideal viewport (size at width=device-width). */
        scale: number;
    }
    /** Viewport for capturing screenshot. */
    interface Viewport {
        /** X offset in CSS pixels. */
        x: number;
        /** Y offset in CSS pixels */
        y: number;
        /** Rectangle width in CSS pixels */
        width: number;
        /** Rectangle height in CSS pixels */
        height: number;
        /** Page scale factor. */
        scale: number;
    }
    type DomContentEventFiredParameters = {
        timestamp: Network.MonotonicTime;
    };
    type LoadEventFiredParameters = {
        timestamp: Network.MonotonicTime;
    };
    type LifecycleEventParameters = {
        /** Id of the frame. */
        frameId: FrameId;
        /** Loader identifier. Empty string if the request is fetched from worker. */
        loaderId: Network.LoaderId;
        name: string;
        timestamp: Network.MonotonicTime;
    };
    type FrameAttachedParameters = {
        /** Id of the frame that has been attached. */
        frameId: FrameId;
        /** Parent frame identifier. */
        parentFrameId: FrameId;
        /** JavaScript stack trace of when frame was attached, only set if frame initiated from script. */
        stack?: Runtime.StackTrace;
    };
    type FrameNavigatedParameters = {
        /** Frame object. */
        frame: Frame;
    };
    type FrameDetachedParameters = {
        /** Id of the frame that has been detached. */
        frameId: FrameId;
    };
    type FrameStartedLoadingParameters = {
        /** Id of the frame that has started loading. */
        frameId: FrameId;
    };
    type FrameStoppedLoadingParameters = {
        /** Id of the frame that has stopped loading. */
        frameId: FrameId;
    };
    type FrameScheduledNavigationParameters = {
        /** Id of the frame that has scheduled a navigation. */
        frameId: FrameId;
        /** Delay (in seconds) until the navigation is scheduled to begin. The navigation is not guaranteed to start. */
        delay: number;
        /** The reason for the navigation. */
        reason: "formSubmissionGet" | "formSubmissionPost" | "httpHeaderRefresh" | "scriptInitiated" | "metaTagRefresh" | "pageBlockInterstitial" | "reload";
        /** The destination URL for the scheduled navigation. */
        url: string;
    };
    type FrameClearedScheduledNavigationParameters = {
        /** Id of the frame that has cleared its scheduled navigation. */
        frameId: FrameId;
    };
    type JavascriptDialogOpeningParameters = {
        /** Frame url. */
        url: string;
        /** Message that will be displayed by the dialog. */
        message: string;
        /** Dialog type. */
        type: DialogType;
        /** Default dialog prompt. */
        defaultPrompt?: string;
    };
    type JavascriptDialogClosedParameters = {
        /** Whether dialog was confirmed. */
        result: boolean;
        /** User input in case of prompt. */
        userInput: string;
    };
    type ScreencastFrameParameters = {
        /** Base64-encoded compressed image. */
        data: string;
        /** Screencast frame metadata. */
        metadata: ScreencastFrameMetadata;
        /** Frame number. */
        sessionId: number;
    };
    type ScreencastVisibilityChangedParameters = {
        /** True if the page is visible. */
        visible: boolean;
    };
    type WindowOpenParameters = {
        /** The URL for the new window. */
        url: string;
        /** Window name. */
        windowName: string;
        /** An array of enabled window features. */
        windowFeatures: string[];
        /** Whether or not it was triggered by user gesture. */
        userGesture: boolean;
    };
    type AddScriptToEvaluateOnLoadParameters = {
        scriptSource: string;
    };
    type AddScriptToEvaluateOnLoadReturn = {
        /** Identifier of the added script. */
        identifier: ScriptIdentifier;
    };
    type RemoveScriptToEvaluateOnLoadParameters = {
        identifier: ScriptIdentifier;
    };
    type AddScriptToEvaluateOnNewDocumentParameters = {
        source: string;
    };
    type AddScriptToEvaluateOnNewDocumentReturn = {
        /** Identifier of the added script. */
        identifier: ScriptIdentifier;
    };
    type RemoveScriptToEvaluateOnNewDocumentParameters = {
        identifier: ScriptIdentifier;
    };
    type SetAutoAttachToCreatedPagesParameters = {
        /** If true, browser will open a new inspector window for every page created from this one. */
        autoAttach: boolean;
    };
    type SetLifecycleEventsEnabledParameters = {
        /** If true, starts emitting lifecycle events. */
        enabled: boolean;
    };
    type ReloadParameters = {
        /** If true, browser cache is ignored (as if the user pressed Shift+refresh). */
        ignoreCache?: boolean;
        /** If set, the script will be injected into all frames of the inspected page after reload. */
        scriptToEvaluateOnLoad?: string;
    };
    type SetAdBlockingEnabledParameters = {
        /** Whether to block ads. */
        enabled: boolean;
    };
    type NavigateParameters = {
        /** URL to navigate the page to. */
        url: string;
        /** Referrer URL. */
        referrer?: string;
        /** Intended transition type. */
        transitionType?: TransitionType;
    };
    type NavigateReturn = {
        /** Frame id that has navigated (or failed to navigate) */
        frameId: FrameId;
        /** User friendly error message, present if and only if navigation has failed. */
        errorText?: string;
    };
    type GetNavigationHistoryReturn = {
        /** Index of the current navigation history entry. */
        currentIndex: number;
        /** Array of navigation history entries. */
        entries: NavigationEntry[];
    };
    type NavigateToHistoryEntryParameters = {
        /** Unique id of the entry to navigate to. */
        entryId: number;
    };
    type GetCookiesReturn = {
        /** Array of cookie objects. */
        cookies: Network.Cookie[];
    };
    type DeleteCookieParameters = {
        /** Name of the cookie to remove. */
        cookieName: string;
        /** URL to match cooke domain and path. */
        url: string;
    };
    type GetResourceTreeReturn = {
        /** Present frame / resource tree structure. */
        frameTree: FrameResourceTree;
    };
    type GetFrameTreeReturn = {
        /** Present frame tree structure. */
        frameTree: FrameTree;
    };
    type GetResourceContentParameters = {
        /** Frame id to get resource for. */
        frameId: FrameId;
        /** URL of the resource to get content for. */
        url: string;
    };
    type GetResourceContentReturn = {
        /** Resource content. */
        content: string;
        /** True, if content was served as base64. */
        base64Encoded: boolean;
    };
    type SearchInResourceParameters = {
        /** Frame id for resource to search in. */
        frameId: FrameId;
        /** URL of the resource to search in. */
        url: string;
        /** String to search for. */
        query: string;
        /** If true, search is case sensitive. */
        caseSensitive?: boolean;
        /** If true, treats string parameter as regex. */
        isRegex?: boolean;
    };
    type SearchInResourceReturn = {
        /** List of search matches. */
        result: Debugger.SearchMatch[];
    };
    type SetDocumentContentParameters = {
        /** Frame id to set HTML for. */
        frameId: FrameId;
        /** HTML content to set. */
        html: string;
    };
    type SetDeviceMetricsOverrideParameters = {
        /** Overriding width value in pixels (minimum 0, maximum 10000000). 0 disables the override. */
        width: number;
        /** Overriding height value in pixels (minimum 0, maximum 10000000). 0 disables the override. */
        height: number;
        /** Overriding device scale factor value. 0 disables the override. */
        deviceScaleFactor: number;
        /** Whether to emulate mobile device. This includes viewport meta tag, overlay scrollbars, text autosizing and more. */
        mobile: boolean;
        /** Scale to apply to resulting view image. */
        scale?: number;
        /** Overriding screen width value in pixels (minimum 0, maximum 10000000). */
        screenWidth?: number;
        /** Overriding screen height value in pixels (minimum 0, maximum 10000000). */
        screenHeight?: number;
        /** Overriding view X position on screen in pixels (minimum 0, maximum 10000000). */
        positionX?: number;
        /** Overriding view Y position on screen in pixels (minimum 0, maximum 10000000). */
        positionY?: number;
        /** Do not set visible view size, rely upon explicit setVisibleSize call. */
        dontSetVisibleSize?: boolean;
        /** Screen orientation override. */
        screenOrientation?: Emulation.ScreenOrientation;
        /** The viewport dimensions and scale. If not set, the override is cleared. */
        viewport?: Viewport;
    };
    type SetGeolocationOverrideParameters = {
        /** Mock latitude */
        latitude?: number;
        /** Mock longitude */
        longitude?: number;
        /** Mock accuracy */
        accuracy?: number;
    };
    type SetDeviceOrientationOverrideParameters = {
        /** Mock alpha */
        alpha: number;
        /** Mock beta */
        beta: number;
        /** Mock gamma */
        gamma: number;
    };
    type SetTouchEmulationEnabledParameters = {
        /** Whether the touch event emulation should be enabled. */
        enabled: boolean;
        /** Touch/gesture events configuration. Default: current platform. */
        configuration?: "mobile" | "desktop";
    };
    type CaptureScreenshotParameters = {
        /** Image compression format (defaults to png). */
        format?: "jpeg" | "png";
        /** Compression quality from range [0..100] (jpeg only). */
        quality?: number;
        /** Capture the screenshot of a given region only. */
        clip?: Viewport;
        /** Capture the screenshot from the surface, rather than the view. Defaults to true. */
        fromSurface?: boolean;
    };
    type CaptureScreenshotReturn = {
        /** Base64-encoded image data. */
        data: string;
    };
    type PrintToPDFParameters = {
        /** Paper orientation. Defaults to false. */
        landscape?: boolean;
        /** Display header and footer. Defaults to false. */
        displayHeaderFooter?: boolean;
        /** Print background graphics. Defaults to false. */
        printBackground?: boolean;
        /** Scale of the webpage rendering. Defaults to 1. */
        scale?: number;
        /** Paper width in inches. Defaults to 8.5 inches. */
        paperWidth?: number;
        /** Paper height in inches. Defaults to 11 inches. */
        paperHeight?: number;
        /** Top margin in inches. Defaults to 1cm (~0.4 inches). */
        marginTop?: number;
        /** Bottom margin in inches. Defaults to 1cm (~0.4 inches). */
        marginBottom?: number;
        /** Left margin in inches. Defaults to 1cm (~0.4 inches). */
        marginLeft?: number;
        /** Right margin in inches. Defaults to 1cm (~0.4 inches). */
        marginRight?: number;
        /** Paper ranges to print, e.g., '1-5, 8, 11-13'. Defaults to the empty string, which means print all pages. */
        pageRanges?: string;
        /** Whether to silently ignore invalid but successfully parsed page ranges, such as '3-2'. Defaults to false. */
        ignoreInvalidPageRanges?: boolean;
    };
    type PrintToPDFReturn = {
        /** Base64-encoded pdf data. */
        data: string;
    };
    type StartScreencastParameters = {
        /** Image compression format. */
        format?: "jpeg" | "png";
        /** Compression quality from range [0..100]. */
        quality?: number;
        /** Maximum screenshot width. */
        maxWidth?: number;
        /** Maximum screenshot height. */
        maxHeight?: number;
        /** Send every n-th frame. */
        everyNthFrame?: number;
    };
    type ScreencastFrameAckParameters = {
        /** Frame number. */
        sessionId: number;
    };
    type HandleJavaScriptDialogParameters = {
        /** Whether to accept or dismiss the dialog. */
        accept: boolean;
        /** The text to enter into the dialog prompt before accepting. Used only if this is a prompt dialog. */
        promptText?: string;
    };
    type GetAppManifestReturn = {
        /** Manifest location. */
        url: string;
        errors: AppManifestError[];
        /** Manifest content. */
        data?: string;
    };
    type GetLayoutMetricsReturn = {
        /** Metrics relating to the layout viewport. */
        layoutViewport: LayoutViewport;
        /** Metrics relating to the visual viewport. */
        visualViewport: VisualViewport;
        /** Size of scrollable area. */
        contentSize: DOM.Rect;
    };
    type CreateIsolatedWorldParameters = {
        /** Id of the frame in which the isolated world should be created. */
        frameId: FrameId;
        /** An optional name which is reported in the Execution Context. */
        worldName?: string;
        /** Whether or not universal access should be granted to the isolated world. This is a powerful option, use with caution. */
        grantUniveralAccess?: boolean;
    };
    type CreateIsolatedWorldReturn = {
        /** Execution context of the isolated world. */
        executionContextId: Runtime.ExecutionContextId;
    };
    type SetDownloadBehaviorParameters = {
        /** Whether to allow all or deny all download requests, or use default Chrome behavior if available (otherwise deny). */
        behavior: "deny" | "allow" | "default";
        /** The default path to save downloaded files to. This is requred if behavior is set to 'allow' */
        downloadPath?: string;
    };
}
/** This domain provides various functionality related to drawing atop the inspected page. */
export declare namespace Overlay {
    /** Configuration data for the highlighting of page elements. */
    interface HighlightConfig {
        /** Whether the node info tooltip should be shown (default: false). */
        showInfo?: boolean;
        /** Whether the rulers should be shown (default: false). */
        showRulers?: boolean;
        /** Whether the extension lines from node to the rulers should be shown (default: false). */
        showExtensionLines?: boolean;
        displayAsMaterial?: boolean;
        /** The content box highlight fill color (default: transparent). */
        contentColor?: DOM.RGBA;
        /** The padding highlight fill color (default: transparent). */
        paddingColor?: DOM.RGBA;
        /** The border highlight fill color (default: transparent). */
        borderColor?: DOM.RGBA;
        /** The margin highlight fill color (default: transparent). */
        marginColor?: DOM.RGBA;
        /** The event target element highlight fill color (default: transparent). */
        eventTargetColor?: DOM.RGBA;
        /** The shape outside fill color (default: transparent). */
        shapeColor?: DOM.RGBA;
        /** The shape margin fill color (default: transparent). */
        shapeMarginColor?: DOM.RGBA;
        /** Selectors to highlight relevant nodes. */
        selectorList?: string;
        /** The grid layout color (default: transparent). */
        cssGridColor?: DOM.RGBA;
    }
    type InspectMode = "searchForNode" | "searchForUAShadowDOM" | "none";
    type NodeHighlightRequestedParameters = {
        nodeId: DOM.NodeId;
    };
    type InspectNodeRequestedParameters = {
        /** Id of the node to inspect. */
        backendNodeId: DOM.BackendNodeId;
    };
    type ScreenshotRequestedParameters = {
        /** Viewport to capture, in CSS. */
        viewport: Page.Viewport;
    };
    type SetShowPaintRectsParameters = {
        /** True for showing paint rectangles */
        result: boolean;
    };
    type SetShowDebugBordersParameters = {
        /** True for showing debug borders */
        show: boolean;
    };
    type SetShowFPSCounterParameters = {
        /** True for showing the FPS counter */
        show: boolean;
    };
    type SetShowScrollBottleneckRectsParameters = {
        /** True for showing scroll bottleneck rects */
        show: boolean;
    };
    type SetShowViewportSizeOnResizeParameters = {
        /** Whether to paint size or not. */
        show: boolean;
    };
    type SetPausedInDebuggerMessageParameters = {
        /** The message to display, also triggers resume and step over controls. */
        message?: string;
    };
    type SetSuspendedParameters = {
        /** Whether overlay should be suspended and not consume any resources until resumed. */
        suspended: boolean;
    };
    type SetInspectModeParameters = {
        /** Set an inspection mode. */
        mode: InspectMode;
        /** A descriptor for the highlight appearance of hovered-over nodes. May be omitted if <code>enabled == false</code>. */
        highlightConfig?: HighlightConfig;
    };
    type HighlightRectParameters = {
        /** X coordinate */
        x: number;
        /** Y coordinate */
        y: number;
        /** Rectangle width */
        width: number;
        /** Rectangle height */
        height: number;
        /** The highlight fill color (default: transparent). */
        color?: DOM.RGBA;
        /** The highlight outline color (default: transparent). */
        outlineColor?: DOM.RGBA;
    };
    type HighlightQuadParameters = {
        /** Quad to highlight */
        quad: DOM.Quad;
        /** The highlight fill color (default: transparent). */
        color?: DOM.RGBA;
        /** The highlight outline color (default: transparent). */
        outlineColor?: DOM.RGBA;
    };
    type HighlightNodeParameters = {
        /** A descriptor for the highlight appearance. */
        highlightConfig: HighlightConfig;
        /** Identifier of the node to highlight. */
        nodeId?: DOM.NodeId;
        /** Identifier of the backend node to highlight. */
        backendNodeId?: DOM.BackendNodeId;
        /** JavaScript object id of the node to be highlighted. */
        objectId?: Runtime.RemoteObjectId;
    };
    type HighlightFrameParameters = {
        /** Identifier of the frame to highlight. */
        frameId: Page.FrameId;
        /** The content box highlight fill color (default: transparent). */
        contentColor?: DOM.RGBA;
        /** The content box highlight outline color (default: transparent). */
        contentOutlineColor?: DOM.RGBA;
    };
    type GetHighlightObjectForTestParameters = {
        /** Id of the node to get highlight object for. */
        nodeId: DOM.NodeId;
    };
    type GetHighlightObjectForTestReturn = {
        /** Highlight data for the node. */
        highlight: any;
    };
}
/** This domain emulates different environments for the page. */
export declare namespace Emulation {
    /** Screen orientation. */
    interface ScreenOrientation {
        /** Orientation type. */
        type: "portraitPrimary" | "portraitSecondary" | "landscapePrimary" | "landscapeSecondary";
        /** Orientation angle. */
        angle: number;
    }
    /** advance: If the scheduler runs out of immediate work, the virtual time base may fast forward to allow the next delayed task (if any) to run; pause: The virtual time base may not advance; pauseIfNetworkFetchesPending: The virtual time base may not advance if there are any pending resource fetches. */
    type VirtualTimePolicy = "advance" | "pause" | "pauseIfNetworkFetchesPending";
    type VirtualTimeAdvancedParameters = {
        /** The amount of virtual time that has elapsed in milliseconds since virtual time was first enabled. */
        virtualTimeElapsed: number;
    };
    type VirtualTimePausedParameters = {
        /** The amount of virtual time that has elapsed in milliseconds since virtual time was first enabled. */
        virtualTimeElapsed: number;
    };
    type SetDeviceMetricsOverrideParameters = {
        /** Overriding width value in pixels (minimum 0, maximum 10000000). 0 disables the override. */
        width: number;
        /** Overriding height value in pixels (minimum 0, maximum 10000000). 0 disables the override. */
        height: number;
        /** Overriding device scale factor value. 0 disables the override. */
        deviceScaleFactor: number;
        /** Whether to emulate mobile device. This includes viewport meta tag, overlay scrollbars, text autosizing and more. */
        mobile: boolean;
        /** Scale to apply to resulting view image. */
        scale?: number;
        /** Overriding screen width value in pixels (minimum 0, maximum 10000000). */
        screenWidth?: number;
        /** Overriding screen height value in pixels (minimum 0, maximum 10000000). */
        screenHeight?: number;
        /** Overriding view X position on screen in pixels (minimum 0, maximum 10000000). */
        positionX?: number;
        /** Overriding view Y position on screen in pixels (minimum 0, maximum 10000000). */
        positionY?: number;
        /** Do not set visible view size, rely upon explicit setVisibleSize call. */
        dontSetVisibleSize?: boolean;
        /** Screen orientation override. */
        screenOrientation?: ScreenOrientation;
        /** If set, the visible area of the page will be overridden to this viewport. This viewport change is not observed by the page, e.g. viewport-relative elements do not change positions. */
        viewport?: Page.Viewport;
    };
    type SetPageScaleFactorParameters = {
        /** Page scale factor. */
        pageScaleFactor: number;
    };
    type SetVisibleSizeParameters = {
        /** Frame width (DIP). */
        width: number;
        /** Frame height (DIP). */
        height: number;
    };
    type SetScriptExecutionDisabledParameters = {
        /** Whether script execution should be disabled in the page. */
        value: boolean;
    };
    type SetGeolocationOverrideParameters = {
        /** Mock latitude */
        latitude?: number;
        /** Mock longitude */
        longitude?: number;
        /** Mock accuracy */
        accuracy?: number;
    };
    type SetTouchEmulationEnabledParameters = {
        /** Whether the touch event emulation should be enabled. */
        enabled: boolean;
        /** Maximum touch points supported. Defaults to one. */
        maxTouchPoints?: number;
    };
    type SetEmitTouchEventsForMouseParameters = {
        /** Whether touch emulation based on mouse input should be enabled. */
        enabled: boolean;
        /** Touch/gesture events configuration. Default: current platform. */
        configuration?: "mobile" | "desktop";
    };
    type SetEmulatedMediaParameters = {
        /** Media type to emulate. Empty string disables the override. */
        media: string;
    };
    type SetCPUThrottlingRateParameters = {
        /** Throttling rate as a slowdown factor (1 is no throttle, 2 is 2x slowdown, etc). */
        rate: number;
    };
    type CanEmulateReturn = {
        /** True if emulation is supported. */
        result: boolean;
    };
    type SetVirtualTimePolicyParameters = {
        policy: VirtualTimePolicy;
        /** If set, after this many virtual milliseconds have elapsed virtual time will be paused and a virtualTimeBudgetExpired event is sent. */
        budget?: number;
        /** If set this specifies the maximum number of tasks that can be run before virtual is forced forwards to prevent deadlock. */
        maxVirtualTimeTaskStarvationCount?: number;
    };
    type SetVirtualTimePolicyReturn = {
        /** Absolute timestamp at which virtual time was first enabled (milliseconds since epoch). */
        virtualTimeBase: Runtime.Timestamp;
    };
    type SetNavigatorOverridesParameters = {
        /** The platform navigator.platform should return. */
        platform: string;
    };
    type SetDefaultBackgroundColorOverrideParameters = {
        /** RGBA of the default background color. If not specified, any existing override will be cleared. */
        color?: DOM.RGBA;
    };
}
/** Security */
export declare namespace Security {
    /** An internal certificate ID value. */
    type CertificateId = number;
    /** A description of mixed content (HTTP resources on HTTPS pages), as defined by https://www.w3.org/TR/mixed-content/#categories */
    type MixedContentType = "blockable" | "optionally-blockable" | "none";
    /** The security level of a page or resource. */
    type SecurityState = "unknown" | "neutral" | "insecure" | "secure" | "info";
    /** An explanation of an factor contributing to the security state. */
    interface SecurityStateExplanation {
        /** Security state representing the severity of the factor being explained. */
        securityState: SecurityState;
        /** Short phrase describing the type of factor. */
        summary: string;
        /** Full text explanation of the factor. */
        description: string;
        /** The type of mixed content described by the explanation. */
        mixedContentType: MixedContentType;
        /** Page certificate. */
        certificate: string[];
    }
    /** Information about insecure content on the page. */
    interface InsecureContentStatus {
        /** True if the page was loaded over HTTPS and ran mixed (HTTP) content such as scripts. */
        ranMixedContent: boolean;
        /** True if the page was loaded over HTTPS and displayed mixed (HTTP) content such as images. */
        displayedMixedContent: boolean;
        /** True if the page was loaded over HTTPS and contained a form targeting an insecure url. */
        containedMixedForm: boolean;
        /** True if the page was loaded over HTTPS without certificate errors, and ran content such as scripts that were loaded with certificate errors. */
        ranContentWithCertErrors: boolean;
        /** True if the page was loaded over HTTPS without certificate errors, and displayed content such as images that were loaded with certificate errors. */
        displayedContentWithCertErrors: boolean;
        /** Security state representing a page that ran insecure content. */
        ranInsecureContentStyle: SecurityState;
        /** Security state representing a page that displayed insecure content. */
        displayedInsecureContentStyle: SecurityState;
    }
    /** The action to take when a certificate error occurs. continue will continue processing the request and cancel will cancel the request. */
    type CertificateErrorAction = "continue" | "cancel";
    type SecurityStateChangedParameters = {
        /** Security state. */
        securityState: SecurityState;
        /** True if the page was loaded over cryptographic transport such as HTTPS. */
        schemeIsCryptographic: boolean;
        /** List of explanations for the security state. If the overall security state is `insecure` or `warning`, at least one corresponding explanation should be included. */
        explanations: SecurityStateExplanation[];
        /** Information about insecure content on the page. */
        insecureContentStatus: InsecureContentStatus;
        /** Overrides user-visible description of the state. */
        summary?: string;
    };
    type CertificateErrorParameters = {
        /** The ID of the event. */
        eventId: number;
        /** The type of the error. */
        errorType: string;
        /** The url that was requested. */
        requestURL: string;
    };
    type HandleCertificateErrorParameters = {
        /** The ID of the event. */
        eventId: number;
        /** The action to take on the certificate error. */
        action: CertificateErrorAction;
    };
    type SetOverrideCertificateErrorsParameters = {
        /** If true, certificate errors will be overridden. */
        override: boolean;
    };
}
/** Audits domain allows investigation of page violations and possible improvements. */
export declare namespace Audits {
    type GetEncodedResponseParameters = {
        /** Identifier of the network request to get content for. */
        requestId: Network.RequestId;
        /** The encoding to use. */
        encoding: "webp" | "jpeg" | "png";
        /** The quality of the encoding (0-1). (defaults to 1) */
        quality?: number;
        /** Whether to only return the size information (defaults to false). */
        sizeOnly?: boolean;
    };
    type GetEncodedResponseReturn = {
        /** The encoded body as a base64 string. Omitted if sizeOnly is true. */
        body?: string;
        /** Size before re-encoding. */
        originalSize: number;
        /** Size after re-encoding. */
        encodedSize: number;
    };
}
/** Network domain allows tracking network activities of the page. It exposes information about http, file, data and other requests and responses, their headers, bodies, timing, etc. */
export declare namespace Network {
    /** Unique loader identifier. */
    type LoaderId = string;
    /** Unique request identifier. */
    type RequestId = string;
    /** Unique intercepted request identifier. */
    type InterceptionId = string;
    /** Network level fetch failure reason. */
    type ErrorReason = "Failed" | "Aborted" | "TimedOut" | "AccessDenied" | "ConnectionClosed" | "ConnectionReset" | "ConnectionRefused" | "ConnectionAborted" | "ConnectionFailed" | "NameNotResolved" | "InternetDisconnected" | "AddressUnreachable";
    /** UTC time in seconds, counted from January 1, 1970. */
    type TimeSinceEpoch = number;
    /** Monotonically increasing time in seconds since an arbitrary point in the past. */
    type MonotonicTime = number;
    /** Request / response headers as keys / values of JSON object. */
    type Headers = any;
    /** The underlying connection technology that the browser is supposedly using. */
    type ConnectionType = "none" | "cellular2g" | "cellular3g" | "cellular4g" | "bluetooth" | "ethernet" | "wifi" | "wimax" | "other";
    /** Represents the cookie's 'SameSite' status: https://tools.ietf.org/html/draft-west-first-party-cookies */
    type CookieSameSite = "Strict" | "Lax";
    /** Timing information for the request. */
    interface ResourceTiming {
        /** Timing's requestTime is a baseline in seconds, while the other numbers are ticks in milliseconds relatively to this requestTime. */
        requestTime: number;
        /** Started resolving proxy. */
        proxyStart: number;
        /** Finished resolving proxy. */
        proxyEnd: number;
        /** Started DNS address resolve. */
        dnsStart: number;
        /** Finished DNS address resolve. */
        dnsEnd: number;
        /** Started connecting to the remote host. */
        connectStart: number;
        /** Connected to the remote host. */
        connectEnd: number;
        /** Started SSL handshake. */
        sslStart: number;
        /** Finished SSL handshake. */
        sslEnd: number;
        /** Started running ServiceWorker. */
        workerStart: number;
        /** Finished Starting ServiceWorker. */
        workerReady: number;
        /** Started sending request. */
        sendStart: number;
        /** Finished sending request. */
        sendEnd: number;
        /** Time the server started pushing request. */
        pushStart: number;
        /** Time the server finished pushing request. */
        pushEnd: number;
        /** Finished receiving response headers. */
        receiveHeadersEnd: number;
    }
    /** Loading priority of a resource request. */
    type ResourcePriority = "VeryLow" | "Low" | "Medium" | "High" | "VeryHigh";
    /** HTTP request data. */
    interface Request {
        /** Request URL. */
        url: string;
        /** HTTP request method. */
        method: string;
        /** HTTP request headers. */
        headers: Headers;
        /** HTTP POST request data. */
        postData?: string;
        /** The mixed content type of the request. */
        mixedContentType?: Security.MixedContentType;
        /** Priority of the resource request at the time request is sent. */
        initialPriority: ResourcePriority;
        /** The referrer policy of the request, as defined in https://www.w3.org/TR/referrer-policy/ */
        referrerPolicy: "unsafe-url" | "no-referrer-when-downgrade" | "no-referrer" | "origin" | "origin-when-cross-origin" | "same-origin" | "strict-origin" | "strict-origin-when-cross-origin";
        /** Whether is loaded via link preload. */
        isLinkPreload?: boolean;
    }
    /** Details of a signed certificate timestamp (SCT). */
    interface SignedCertificateTimestamp {
        /** Validation status. */
        status: string;
        /** Origin. */
        origin: string;
        /** Log name / description. */
        logDescription: string;
        /** Log ID. */
        logId: string;
        /** Issuance date. */
        timestamp: TimeSinceEpoch;
        /** Hash algorithm. */
        hashAlgorithm: string;
        /** Signature algorithm. */
        signatureAlgorithm: string;
        /** Signature data. */
        signatureData: string;
    }
    /** Security details about a request. */
    interface SecurityDetails {
        /** Protocol name (e.g. "TLS 1.2" or "QUIC"). */
        protocol: string;
        /** Key Exchange used by the connection, or the empty string if not applicable. */
        keyExchange: string;
        /** (EC)DH group used by the connection, if applicable. */
        keyExchangeGroup?: string;
        /** Cipher name. */
        cipher: string;
        /** TLS MAC. Note that AEAD ciphers do not have separate MACs. */
        mac?: string;
        /** Certificate ID value. */
        certificateId: Security.CertificateId;
        /** Certificate subject name. */
        subjectName: string;
        /** Subject Alternative Name (SAN) DNS names and IP addresses. */
        sanList: string[];
        /** Name of the issuing CA. */
        issuer: string;
        /** Certificate valid from date. */
        validFrom: TimeSinceEpoch;
        /** Certificate valid to (expiration) date */
        validTo: TimeSinceEpoch;
        /** List of signed certificate timestamps (SCTs). */
        signedCertificateTimestampList: SignedCertificateTimestamp[];
    }
    /** The reason why request was blocked. */
    type BlockedReason = "csp" | "mixed-content" | "origin" | "inspector" | "subresource-filter" | "other";
    /** HTTP response data. */
    interface Response {
        /** Response URL. This URL can be different from CachedResource.url in case of redirect. */
        url: string;
        /** HTTP response status code. */
        status: number;
        /** HTTP response status text. */
        statusText: string;
        /** HTTP response headers. */
        headers: Headers;
        /** HTTP response headers text. */
        headersText?: string;
        /** Resource mimeType as determined by the browser. */
        mimeType: string;
        /** Refined HTTP request headers that were actually transmitted over the network. */
        requestHeaders?: Headers;
        /** HTTP request headers text. */
        requestHeadersText?: string;
        /** Specifies whether physical connection was actually reused for this request. */
        connectionReused: boolean;
        /** Physical connection id that was actually used for this request. */
        connectionId: number;
        /** Remote IP address. */
        remoteIPAddress?: string;
        /** Remote port. */
        remotePort?: number;
        /** Specifies that the request was served from the disk cache. */
        fromDiskCache?: boolean;
        /** Specifies that the request was served from the ServiceWorker. */
        fromServiceWorker?: boolean;
        /** Total number of bytes received for this request so far. */
        encodedDataLength: number;
        /** Timing information for the given request. */
        timing?: ResourceTiming;
        /** Protocol used to fetch this request. */
        protocol?: string;
        /** Security state of the request resource. */
        securityState: Security.SecurityState;
        /** Security details for the request. */
        securityDetails?: SecurityDetails;
    }
    /** WebSocket request data. */
    interface WebSocketRequest {
        /** HTTP request headers. */
        headers: Headers;
    }
    /** WebSocket response data. */
    interface WebSocketResponse {
        /** HTTP response status code. */
        status: number;
        /** HTTP response status text. */
        statusText: string;
        /** HTTP response headers. */
        headers: Headers;
        /** HTTP response headers text. */
        headersText?: string;
        /** HTTP request headers. */
        requestHeaders?: Headers;
        /** HTTP request headers text. */
        requestHeadersText?: string;
    }
    /** WebSocket frame data. */
    interface WebSocketFrame {
        /** WebSocket frame opcode. */
        opcode: number;
        /** WebSocke frame mask. */
        mask: boolean;
        /** WebSocke frame payload data. */
        payloadData: string;
    }
    /** Information about the cached resource. */
    interface CachedResource {
        /** Resource URL. This is the url of the original network request. */
        url: string;
        /** Type of this resource. */
        type: Page.ResourceType;
        /** Cached response data. */
        response?: Response;
        /** Cached response body size. */
        bodySize: number;
    }
    /** Information about the request initiator. */
    interface Initiator {
        /** Type of this initiator. */
        type: "parser" | "script" | "preload" | "other";
        /** Initiator JavaScript stack trace, set for Script only. */
        stack?: Runtime.StackTrace;
        /** Initiator URL, set for Parser type or for Script type (when script is importing module). */
        url?: string;
        /** Initiator line number, set for Parser type or for Script type (when script is importing module) (0-based). */
        lineNumber?: number;
    }
    /** Cookie object */
    interface Cookie {
        /** Cookie name. */
        name: string;
        /** Cookie value. */
        value: string;
        /** Cookie domain. */
        domain: string;
        /** Cookie path. */
        path: string;
        /** Cookie expiration date as the number of seconds since the UNIX epoch. */
        expires: number;
        /** Cookie size. */
        size: number;
        /** True if cookie is http-only. */
        httpOnly: boolean;
        /** True if cookie is secure. */
        secure: boolean;
        /** True in case of session cookie. */
        session: boolean;
        /** Cookie SameSite type. */
        sameSite?: CookieSameSite;
    }
    /** Cookie parameter object */
    interface CookieParam {
        /** Cookie name. */
        name: string;
        /** Cookie value. */
        value: string;
        /** The request-URI to associate with the setting of the cookie. This value can affect the default domain and path values of the created cookie. */
        url?: string;
        /** Cookie domain. */
        domain?: string;
        /** Cookie path. */
        path?: string;
        /** True if cookie is secure. */
        secure?: boolean;
        /** True if cookie is http-only. */
        httpOnly?: boolean;
        /** Cookie SameSite type. */
        sameSite?: CookieSameSite;
        /** Cookie expiration date, session cookie if not set */
        expires?: TimeSinceEpoch;
    }
    /** Authorization challenge for HTTP status code 401 or 407. */
    interface AuthChallenge {
        /** Source of the authentication challenge. */
        source?: "Server" | "Proxy";
        /** Origin of the challenger. */
        origin: string;
        /** The authentication scheme used, such as basic or digest */
        scheme: string;
        /** The realm of the challenge. May be empty. */
        realm: string;
    }
    /** Response to an AuthChallenge. */
    interface AuthChallengeResponse {
        /** The decision on what to do in response to the authorization challenge.  Default means deferring to the default behavior of the net stack, which will likely either the Cancel authentication or display a popup dialog box. */
        response: "Default" | "CancelAuth" | "ProvideCredentials";
        /** The username to provide, possibly empty. Should only be set if response is ProvideCredentials. */
        username?: string;
        /** The password to provide, possibly empty. Should only be set if response is ProvideCredentials. */
        password?: string;
    }
    /** Stages of the interception to begin intercepting. Request will intercept before the request is sent. Response will intercept after the response is received. */
    type InterceptionStage = "Request" | "HeadersReceived";
    /** Request pattern for interception. */
    interface RequestPattern {
        /** Wildcards ('*' -> zero or more, '?' -> exactly one) are allowed. Escape character is backslash. Omitting is equivalent to "*". */
        urlPattern?: string;
        /** If set, only requests for matching resource types will be intercepted. */
        resourceType?: Page.ResourceType;
        /** Stage at wich to begin intercepting requests. Default is Request. */
        interceptionStage?: InterceptionStage;
    }
    type ResourceChangedPriorityParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** New priority */
        newPriority: ResourcePriority;
        /** Timestamp. */
        timestamp: MonotonicTime;
    };
    type RequestWillBeSentParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Loader identifier. Empty string if the request is fetched from worker. */
        loaderId: LoaderId;
        /** URL of the document this request is loaded for. */
        documentURL: string;
        /** Request data. */
        request: Request;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** Timestamp. */
        wallTime: TimeSinceEpoch;
        /** Request initiator. */
        initiator: Initiator;
        /** Redirect response data. */
        redirectResponse?: Response;
        /** Type of this resource. */
        type?: Page.ResourceType;
        /** Frame identifier. */
        frameId?: Page.FrameId;
    };
    type RequestServedFromCacheParameters = {
        /** Request identifier. */
        requestId: RequestId;
    };
    type ResponseReceivedParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Loader identifier. Empty string if the request is fetched from worker. */
        loaderId: LoaderId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** Resource type. */
        type: Page.ResourceType;
        /** Response data. */
        response: Response;
        /** Frame identifier. */
        frameId?: Page.FrameId;
    };
    type DataReceivedParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** Data chunk length. */
        dataLength: number;
        /** Actual bytes received (might be less than dataLength for compressed encodings). */
        encodedDataLength: number;
    };
    type LoadingFinishedParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** Total number of bytes received for this request. */
        encodedDataLength: number;
    };
    type LoadingFailedParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** Resource type. */
        type: Page.ResourceType;
        /** User friendly error message. */
        errorText: string;
        /** True if loading was canceled. */
        canceled?: boolean;
        /** The reason why loading was blocked, if any. */
        blockedReason?: BlockedReason;
    };
    type WebSocketWillSendHandshakeRequestParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** UTC Timestamp. */
        wallTime: TimeSinceEpoch;
        /** WebSocket request data. */
        request: WebSocketRequest;
    };
    type WebSocketHandshakeResponseReceivedParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** WebSocket response data. */
        response: WebSocketResponse;
    };
    type WebSocketCreatedParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** WebSocket request URL. */
        url: string;
        /** Request initiator. */
        initiator?: Initiator;
    };
    type WebSocketClosedParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
    };
    type WebSocketFrameReceivedParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** WebSocket response data. */
        response: WebSocketFrame;
    };
    type WebSocketFrameErrorParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** WebSocket frame error message. */
        errorMessage: string;
    };
    type WebSocketFrameSentParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** WebSocket response data. */
        response: WebSocketFrame;
    };
    type EventSourceMessageReceivedParameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: MonotonicTime;
        /** Message type. */
        eventName: string;
        /** Message identifier. */
        eventId: string;
        /** Message content. */
        data: string;
    };
    type RequestInterceptedParameters = {
        /** Each request the page makes will have a unique id, however if any redirects are encountered while processing that fetch, they will be reported with the same id as the original fetch. Likewise if HTTP authentication is needed then the same fetch id will be used. */
        interceptionId: InterceptionId;
        request: Request;
        /** The id of the frame that initiated the request. */
        frameId: Page.FrameId;
        /** How the requested resource will be used. */
        resourceType: Page.ResourceType;
        /** Whether this is a navigation request, which can abort the navigation completely. */
        isNavigationRequest: boolean;
        /** Redirect location, only sent if a redirect was intercepted. */
        redirectUrl?: string;
        /** Details of the Authorization Challenge encountered. If this is set then continueInterceptedRequest must contain an authChallengeResponse. */
        authChallenge?: AuthChallenge;
        /** Response error if intercepted at response stage or if redirect occurred while intercepting request. */
        responseErrorReason?: ErrorReason;
        /** Response code if intercepted at response stage or if redirect occurred while intercepting request or auth retry occurred. */
        responseStatusCode?: number;
        /** Response headers if intercepted at the response stage or if redirect occurred while intercepting request or auth retry occurred. */
        responseHeaders?: Headers;
    };
    type EnableParameters = {
        /** Buffer size in bytes to use when preserving network payloads (XHRs, etc). */
        maxTotalBufferSize?: number;
        /** Per-resource buffer size in bytes to use when preserving network payloads (XHRs, etc). */
        maxResourceBufferSize?: number;
    };
    type SetUserAgentOverrideParameters = {
        /** User agent to use. */
        userAgent: string;
    };
    type SearchInResponseBodyParameters = {
        /** Identifier of the network response to search. */
        requestId: RequestId;
        /** String to search for. */
        query: string;
        /** If true, search is case sensitive. */
        caseSensitive?: boolean;
        /** If true, treats string parameter as regex. */
        isRegex?: boolean;
    };
    type SearchInResponseBodyReturn = {
        /** List of search matches. */
        result: Debugger.SearchMatch[];
    };
    type SetExtraHTTPHeadersParameters = {
        /** Map with extra HTTP headers. */
        headers: Headers;
    };
    type GetResponseBodyParameters = {
        /** Identifier of the network request to get content for. */
        requestId: RequestId;
    };
    type GetResponseBodyReturn = {
        /** Response body. */
        body: string;
        /** True, if content was sent as base64. */
        base64Encoded: boolean;
    };
    type SetBlockedURLsParameters = {
        /** URL patterns to block. Wildcards ('*') are allowed. */
        urls: string[];
    };
    type ReplayXHRParameters = {
        /** Identifier of XHR to replay. */
        requestId: RequestId;
    };
    type CanClearBrowserCacheReturn = {
        /** True if browser cache can be cleared. */
        result: boolean;
    };
    type CanClearBrowserCookiesReturn = {
        /** True if browser cookies can be cleared. */
        result: boolean;
    };
    type GetCookiesParameters = {
        /** The list of URLs for which applicable cookies will be fetched */
        urls?: string[];
    };
    type GetCookiesReturn = {
        /** Array of cookie objects. */
        cookies: Cookie[];
    };
    type GetAllCookiesReturn = {
        /** Array of cookie objects. */
        cookies: Cookie[];
    };
    type DeleteCookiesParameters = {
        /** Name of the cookies to remove. */
        name: string;
        /** If specified, deletes all the cookies with the given name where domain and path match provided URL. */
        url?: string;
        /** If specified, deletes only cookies with the exact domain. */
        domain?: string;
        /** If specified, deletes only cookies with the exact path. */
        path?: string;
    };
    type SetCookieParameters = {
        /** Cookie name. */
        name: string;
        /** Cookie value. */
        value: string;
        /** The request-URI to associate with the setting of the cookie. This value can affect the default domain and path values of the created cookie. */
        url?: string;
        /** Cookie domain. */
        domain?: string;
        /** Cookie path. */
        path?: string;
        /** True if cookie is secure. */
        secure?: boolean;
        /** True if cookie is http-only. */
        httpOnly?: boolean;
        /** Cookie SameSite type. */
        sameSite?: CookieSameSite;
        /** Cookie expiration date, session cookie if not set */
        expires?: TimeSinceEpoch;
    };
    type SetCookieReturn = {
        /** True if successfully set cookie. */
        success: boolean;
    };
    type SetCookiesParameters = {
        /** Cookies to be set. */
        cookies: CookieParam[];
    };
    type CanEmulateNetworkConditionsReturn = {
        /** True if emulation of network conditions is supported. */
        result: boolean;
    };
    type EmulateNetworkConditionsParameters = {
        /** True to emulate internet disconnection. */
        offline: boolean;
        /** Minimum latency from request sent to response headers received (ms). */
        latency: number;
        /** Maximal aggregated download throughput (bytes/sec). -1 disables download throttling. */
        downloadThroughput: number;
        /** Maximal aggregated upload throughput (bytes/sec).  -1 disables upload throttling. */
        uploadThroughput: number;
        /** Connection type if known. */
        connectionType?: ConnectionType;
    };
    type SetCacheDisabledParameters = {
        /** Cache disabled state. */
        cacheDisabled: boolean;
    };
    type SetBypassServiceWorkerParameters = {
        /** Bypass service worker and load from network. */
        bypass: boolean;
    };
    type SetDataSizeLimitsForTestParameters = {
        /** Maximum total buffer size. */
        maxTotalSize: number;
        /** Maximum per-resource size. */
        maxResourceSize: number;
    };
    type GetCertificateParameters = {
        /** Origin to get certificate for. */
        origin: string;
    };
    type GetCertificateReturn = {
        tableNames: string[];
    };
    type SetRequestInterceptionParameters = {
        /** Requests matching any of these patterns will be forwarded and wait for the corresponding continueInterceptedRequest call. */
        patterns: RequestPattern[];
    };
    type ContinueInterceptedRequestParameters = {
        interceptionId: InterceptionId;
        /** If set this causes the request to fail with the given reason. Passing <code>Aborted</code> for requests marked with <code>isNavigationRequest</code> also cancels the navigation. Must not be set in response to an authChallenge. */
        errorReason?: ErrorReason;
        /** If set the requests completes using with the provided base64 encoded raw response, including HTTP status line and headers etc... Must not be set in response to an authChallenge. */
        rawResponse?: string;
        /** If set the request url will be modified in a way that's not observable by page. Must not be set in response to an authChallenge. */
        url?: string;
        /** If set this allows the request method to be overridden. Must not be set in response to an authChallenge. */
        method?: string;
        /** If set this allows postData to be set. Must not be set in response to an authChallenge. */
        postData?: string;
        /** If set this allows the request headers to be changed. Must not be set in response to an authChallenge. */
        headers?: Headers;
        /** Response to a requestIntercepted with an authChallenge. Must not be set otherwise. */
        authChallengeResponse?: AuthChallengeResponse;
    };
    type GetResponseBodyForInterceptionParameters = {
        /** Identifier for the intercepted request to get body for. */
        interceptionId: InterceptionId;
    };
    type GetResponseBodyForInterceptionReturn = {
        /** Response body. */
        body: string;
        /** True, if content was sent as base64. */
        base64Encoded: boolean;
    };
}
export declare namespace Database {
    /** Unique identifier of Database object. */
    type DatabaseId = string;
    /** Database object. */
    interface Database {
        /** Database ID. */
        id: DatabaseId;
        /** Database domain. */
        domain: string;
        /** Database name. */
        name: string;
        /** Database version. */
        version: string;
    }
    /** Database error. */
    interface Error {
        /** Error message. */
        message: string;
        /** Error code. */
        code: number;
    }
    type AddDatabaseParameters = {
        database: Database;
    };
    type GetDatabaseTableNamesParameters = {
        databaseId: DatabaseId;
    };
    type GetDatabaseTableNamesReturn = {
        tableNames: string[];
    };
    type ExecuteSQLParameters = {
        databaseId: DatabaseId;
        query: string;
    };
    type ExecuteSQLReturn = {
        columnNames?: string[];
        values?: any[];
        sqlError?: Error;
    };
}
export declare namespace IndexedDB {
    /** Database with an array of object stores. */
    interface DatabaseWithObjectStores {
        /** Database name. */
        name: string;
        /** Database version. */
        version: number;
        /** Object stores in this database. */
        objectStores: ObjectStore[];
    }
    /** Object store. */
    interface ObjectStore {
        /** Object store name. */
        name: string;
        /** Object store key path. */
        keyPath: KeyPath;
        /** If true, object store has auto increment flag set. */
        autoIncrement: boolean;
        /** Indexes in this object store. */
        indexes: ObjectStoreIndex[];
    }
    /** Object store index. */
    interface ObjectStoreIndex {
        /** Index name. */
        name: string;
        /** Index key path. */
        keyPath: KeyPath;
        /** If true, index is unique. */
        unique: boolean;
        /** If true, index allows multiple entries for a key. */
        multiEntry: boolean;
    }
    /** Key. */
    interface Key {
        /** Key type. */
        type: "number" | "string" | "date" | "array";
        /** Number value. */
        number?: number;
        /** String value. */
        string?: string;
        /** Date value. */
        date?: number;
        /** Array value. */
        array?: Key[];
    }
    /** Key range. */
    interface KeyRange {
        /** Lower bound. */
        lower?: Key;
        /** Upper bound. */
        upper?: Key;
        /** If true lower bound is open. */
        lowerOpen: boolean;
        /** If true upper bound is open. */
        upperOpen: boolean;
    }
    /** Data entry. */
    interface DataEntry {
        /** Key object. */
        key: Runtime.RemoteObject;
        /** Primary key object. */
        primaryKey: Runtime.RemoteObject;
        /** Value object. */
        value: Runtime.RemoteObject;
    }
    /** Key path. */
    interface KeyPath {
        /** Key path type. */
        type: "null" | "string" | "array";
        /** String value. */
        string?: string;
        /** Array value. */
        array?: string[];
    }
    type RequestDatabaseNamesParameters = {
        /** Security origin. */
        securityOrigin: string;
    };
    type RequestDatabaseNamesReturn = {
        /** Database names for origin. */
        databaseNames: string[];
    };
    type RequestDatabaseParameters = {
        /** Security origin. */
        securityOrigin: string;
        /** Database name. */
        databaseName: string;
    };
    type RequestDatabaseReturn = {
        /** Database with an array of object stores. */
        databaseWithObjectStores: DatabaseWithObjectStores;
    };
    type RequestDataParameters = {
        /** Security origin. */
        securityOrigin: string;
        /** Database name. */
        databaseName: string;
        /** Object store name. */
        objectStoreName: string;
        /** Index name, empty string for object store data requests. */
        indexName: string;
        /** Number of records to skip. */
        skipCount: number;
        /** Number of records to fetch. */
        pageSize: number;
        /** Key range. */
        keyRange?: KeyRange;
    };
    type RequestDataReturn = {
        /** Array of object store data entries. */
        objectStoreDataEntries: DataEntry[];
        /** If true, there are more entries to fetch in the given range. */
        hasMore: boolean;
    };
    type ClearObjectStoreParameters = {
        /** Security origin. */
        securityOrigin: string;
        /** Database name. */
        databaseName: string;
        /** Object store name. */
        objectStoreName: string;
    };
    type ClearObjectStoreReturn = any;
    type DeleteDatabaseParameters = {
        /** Security origin. */
        securityOrigin: string;
        /** Database name. */
        databaseName: string;
    };
    type DeleteDatabaseReturn = any;
}
export declare namespace CacheStorage {
    /** Unique identifier of the Cache object. */
    type CacheId = string;
    /** Data entry. */
    interface DataEntry {
        /** Request URL. */
        requestURL: string;
        /** Request method. */
        requestMethod: string;
        /** Request headers */
        requestHeaders: Header[];
        /** Number of seconds since epoch. */
        responseTime: number;
        /** HTTP response status code. */
        responseStatus: number;
        /** HTTP response status text. */
        responseStatusText: string;
        /** Response headers */
        responseHeaders: Header[];
    }
    /** Cache identifier. */
    interface Cache {
        /** An opaque unique id of the cache. */
        cacheId: CacheId;
        /** Security origin of the cache. */
        securityOrigin: string;
        /** The name of the cache. */
        cacheName: string;
    }
    interface Header {
        name: string;
        value: string;
    }
    /** Cached response */
    interface CachedResponse {
        /** Entry content, base64-encoded. */
        body: string;
    }
    type RequestCacheNamesParameters = {
        /** Security origin. */
        securityOrigin: string;
    };
    type RequestCacheNamesReturn = {
        /** Caches for the security origin. */
        caches: Cache[];
    };
    type RequestEntriesParameters = {
        /** ID of cache to get entries from. */
        cacheId: CacheId;
        /** Number of records to skip. */
        skipCount: number;
        /** Number of records to fetch. */
        pageSize: number;
    };
    type RequestEntriesReturn = {
        /** Array of object store data entries. */
        cacheDataEntries: DataEntry[];
        /** If true, there are more entries to fetch in the given range. */
        hasMore: boolean;
    };
    type DeleteCacheParameters = {
        /** Id of cache for deletion. */
        cacheId: CacheId;
    };
    type DeleteEntryParameters = {
        /** Id of cache where the entry will be deleted. */
        cacheId: CacheId;
        /** URL spec of the request. */
        request: string;
    };
    type RequestCachedResponseParameters = {
        /** Id of cache that contains the enty. */
        cacheId: CacheId;
        /** URL spec of the request. */
        requestURL: string;
    };
    type RequestCachedResponseReturn = {
        /** Response read from the cache. */
        response: CachedResponse;
    };
}
/** Query and modify DOM storage. */
export declare namespace DOMStorage {
    /** DOM Storage identifier. */
    interface StorageId {
        /** Security origin for the storage. */
        securityOrigin: string;
        /** Whether the storage is local storage (not session storage). */
        isLocalStorage: boolean;
    }
    /** DOM Storage item. */
    type Item = string[];
    type DomStorageItemsClearedParameters = {
        storageId: StorageId;
    };
    type DomStorageItemRemovedParameters = {
        storageId: StorageId;
        key: string;
    };
    type DomStorageItemAddedParameters = {
        storageId: StorageId;
        key: string;
        newValue: string;
    };
    type DomStorageItemUpdatedParameters = {
        storageId: StorageId;
        key: string;
        oldValue: string;
        newValue: string;
    };
    type ClearParameters = {
        storageId: StorageId;
    };
    type GetDOMStorageItemsParameters = {
        storageId: StorageId;
    };
    type GetDOMStorageItemsReturn = {
        entries: Item[];
    };
    type SetDOMStorageItemParameters = {
        storageId: StorageId;
        key: string;
        value: string;
    };
    type RemoveDOMStorageItemParameters = {
        storageId: StorageId;
        key: string;
    };
}
export declare namespace ApplicationCache {
    /** Detailed application cache resource information. */
    interface ApplicationCacheResource {
        /** Resource url. */
        url: string;
        /** Resource size. */
        size: number;
        /** Resource type. */
        type: string;
    }
    /** Detailed application cache information. */
    interface ApplicationCache {
        /** Manifest URL. */
        manifestURL: string;
        /** Application cache size. */
        size: number;
        /** Application cache creation time. */
        creationTime: number;
        /** Application cache update time. */
        updateTime: number;
        /** Application cache resources. */
        resources: ApplicationCacheResource[];
    }
    /** Frame identifier - manifest URL pair. */
    interface FrameWithManifest {
        /** Frame identifier. */
        frameId: Page.FrameId;
        /** Manifest URL. */
        manifestURL: string;
        /** Application cache status. */
        status: number;
    }
    type ApplicationCacheStatusUpdatedParameters = {
        /** Identifier of the frame containing document whose application cache updated status. */
        frameId: Page.FrameId;
        /** Manifest URL. */
        manifestURL: string;
        /** Updated application cache status. */
        status: number;
    };
    type NetworkStateUpdatedParameters = {
        isNowOnline: boolean;
    };
    type GetFramesWithManifestsReturn = {
        /** Array of frame identifiers with manifest urls for each frame containing a document associated with some application cache. */
        frameIds: FrameWithManifest[];
    };
    type GetManifestForFrameParameters = {
        /** Identifier of the frame containing document whose manifest is retrieved. */
        frameId: Page.FrameId;
    };
    type GetManifestForFrameReturn = {
        /** Manifest URL for document in the given frame. */
        manifestURL: string;
    };
    type GetApplicationCacheForFrameParameters = {
        /** Identifier of the frame containing document whose application cache is retrieved. */
        frameId: Page.FrameId;
    };
    type GetApplicationCacheForFrameReturn = {
        /** Relevant application cache data for the document in given frame. */
        applicationCache: ApplicationCache;
    };
}
/** This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object that has an <code>id</code>. This <code>id</code> can be used to get additional information on the Node, resolve it into the JavaScript object wrapper, etc. It is important that client receives DOM events only for the nodes that are known to the client. Backend keeps track of the nodes that were sent to the client and never sends the same node twice. It is client's responsibility to collect information about the nodes that were sent to the client.<p>Note that <code>iframe</code> owner elements will return corresponding document elements as their child nodes.</p> */
export declare namespace DOM {
    /** Unique DOM node identifier. */
    type NodeId = number;
    /** Unique DOM node identifier used to reference a node that may not have been pushed to the front-end. */
    type BackendNodeId = number;
    /** Backend node with a friendly name. */
    interface BackendNode {
        /** <code>Node</code>'s nodeType. */
        nodeType: number;
        /** <code>Node</code>'s nodeName. */
        nodeName: string;
        backendNodeId: BackendNodeId;
    }
    /** Pseudo element type. */
    type PseudoType = "first-line" | "first-letter" | "before" | "after" | "backdrop" | "selection" | "first-line-inherited" | "scrollbar" | "scrollbar-thumb" | "scrollbar-button" | "scrollbar-track" | "scrollbar-track-piece" | "scrollbar-corner" | "resizer" | "input-list-button";
    /** Shadow root type. */
    type ShadowRootType = "user-agent" | "open" | "closed";
    /** DOM interaction is implemented in terms of mirror objects that represent the actual DOM nodes. DOMNode is a base node mirror type. */
    interface Node {
        /** Node identifier that is passed into the rest of the DOM messages as the <code>nodeId</code>. Backend will only push node with given <code>id</code> once. It is aware of all requested nodes and will only fire DOM events for nodes known to the client. */
        nodeId: NodeId;
        /** The id of the parent node if any. */
        parentId?: NodeId;
        /** The BackendNodeId for this node. */
        backendNodeId: BackendNodeId;
        /** <code>Node</code>'s nodeType. */
        nodeType: number;
        /** <code>Node</code>'s nodeName. */
        nodeName: string;
        /** <code>Node</code>'s localName. */
        localName: string;
        /** <code>Node</code>'s nodeValue. */
        nodeValue: string;
        /** Child count for <code>Container</code> nodes. */
        childNodeCount?: number;
        /** Child nodes of this node when requested with children. */
        children?: Node[];
        /** Attributes of the <code>Element</code> node in the form of flat array <code>[name1, value1, name2, value2]</code>. */
        attributes?: string[];
        /** Document URL that <code>Document</code> or <code>FrameOwner</code> node points to. */
        documentURL?: string;
        /** Base URL that <code>Document</code> or <code>FrameOwner</code> node uses for URL completion. */
        baseURL?: string;
        /** <code>DocumentType</code>'s publicId. */
        publicId?: string;
        /** <code>DocumentType</code>'s systemId. */
        systemId?: string;
        /** <code>DocumentType</code>'s internalSubset. */
        internalSubset?: string;
        /** <code>Document</code>'s XML version in case of XML documents. */
        xmlVersion?: string;
        /** <code>Attr</code>'s name. */
        name?: string;
        /** <code>Attr</code>'s value. */
        value?: string;
        /** Pseudo element type for this node. */
        pseudoType?: PseudoType;
        /** Shadow root type. */
        shadowRootType?: ShadowRootType;
        /** Frame ID for frame owner elements. */
        frameId?: Page.FrameId;
        /** Content document for frame owner elements. */
        contentDocument?: Node;
        /** Shadow root list for given element host. */
        shadowRoots?: Node[];
        /** Content document fragment for template elements. */
        templateContent?: Node;
        /** Pseudo elements associated with this node. */
        pseudoElements?: Node[];
        /** Import document for the HTMLImport links. */
        importedDocument?: Node;
        /** Distributed nodes for given insertion point. */
        distributedNodes?: BackendNode[];
        /** Whether the node is SVG. */
        isSVG?: boolean;
    }
    /** A structure holding an RGBA color. */
    interface RGBA {
        /** The red component, in the [0-255] range. */
        r: number;
        /** The green component, in the [0-255] range. */
        g: number;
        /** The blue component, in the [0-255] range. */
        b: number;
        /** The alpha component, in the [0-1] range (default: 1). */
        a?: number;
    }
    /** An array of quad vertices, x immediately followed by y for each point, points clock-wise. */
    type Quad = number[];
    /** Box model. */
    interface BoxModel {
        /** Content box */
        content: Quad;
        /** Padding box */
        padding: Quad;
        /** Border box */
        border: Quad;
        /** Margin box */
        margin: Quad;
        /** Node width */
        width: number;
        /** Node height */
        height: number;
        /** Shape outside coordinates */
        shapeOutside?: ShapeOutsideInfo;
    }
    /** CSS Shape Outside details. */
    interface ShapeOutsideInfo {
        /** Shape bounds */
        bounds: Quad;
        /** Shape coordinate details */
        shape: any[];
        /** Margin shape bounds */
        marginShape: any[];
    }
    /** Rectangle. */
    interface Rect {
        /** X coordinate */
        x: number;
        /** Y coordinate */
        y: number;
        /** Rectangle width */
        width: number;
        /** Rectangle height */
        height: number;
    }
    type SetChildNodesParameters = {
        /** Parent node id to populate with children. */
        parentId: NodeId;
        /** Child nodes array. */
        nodes: Node[];
    };
    type AttributeModifiedParameters = {
        /** Id of the node that has changed. */
        nodeId: NodeId;
        /** Attribute name. */
        name: string;
        /** Attribute value. */
        value: string;
    };
    type AttributeRemovedParameters = {
        /** Id of the node that has changed. */
        nodeId: NodeId;
        /** A ttribute name. */
        name: string;
    };
    type InlineStyleInvalidatedParameters = {
        /** Ids of the nodes for which the inline styles have been invalidated. */
        nodeIds: NodeId[];
    };
    type CharacterDataModifiedParameters = {
        /** Id of the node that has changed. */
        nodeId: NodeId;
        /** New text value. */
        characterData: string;
    };
    type ChildNodeCountUpdatedParameters = {
        /** Id of the node that has changed. */
        nodeId: NodeId;
        /** New node count. */
        childNodeCount: number;
    };
    type ChildNodeInsertedParameters = {
        /** Id of the node that has changed. */
        parentNodeId: NodeId;
        /** If of the previous siblint. */
        previousNodeId: NodeId;
        /** Inserted node data. */
        node: Node;
    };
    type ChildNodeRemovedParameters = {
        /** Parent id. */
        parentNodeId: NodeId;
        /** Id of the node that has been removed. */
        nodeId: NodeId;
    };
    type ShadowRootPushedParameters = {
        /** Host element id. */
        hostId: NodeId;
        /** Shadow root. */
        root: Node;
    };
    type ShadowRootPoppedParameters = {
        /** Host element id. */
        hostId: NodeId;
        /** Shadow root id. */
        rootId: NodeId;
    };
    type PseudoElementAddedParameters = {
        /** Pseudo element's parent element id. */
        parentId: NodeId;
        /** The added pseudo element. */
        pseudoElement: Node;
    };
    type PseudoElementRemovedParameters = {
        /** Pseudo element's parent element id. */
        parentId: NodeId;
        /** The removed pseudo element id. */
        pseudoElementId: NodeId;
    };
    type DistributedNodesUpdatedParameters = {
        /** Insertion point where distrubuted nodes were updated. */
        insertionPointId: NodeId;
        /** Distributed nodes for given insertion point. */
        distributedNodes: BackendNode[];
    };
    type GetDocumentParameters = {
        /** The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0. */
        depth?: number;
        /** Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false). */
        pierce?: boolean;
    };
    type GetDocumentReturn = {
        /** Resulting node. */
        root: Node;
    };
    type GetFlattenedDocumentParameters = {
        /** The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0. */
        depth?: number;
        /** Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false). */
        pierce?: boolean;
    };
    type GetFlattenedDocumentReturn = {
        /** Resulting node. */
        nodes: Node[];
    };
    type CollectClassNamesFromSubtreeParameters = {
        /** Id of the node to collect class names. */
        nodeId: NodeId;
    };
    type CollectClassNamesFromSubtreeReturn = {
        /** Class name list. */
        classNames: string[];
    };
    type RequestChildNodesParameters = {
        /** Id of the node to get children for. */
        nodeId: NodeId;
        /** The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0. */
        depth?: number;
        /** Whether or not iframes and shadow roots should be traversed when returning the sub-tree (default is false). */
        pierce?: boolean;
    };
    type QuerySelectorParameters = {
        /** Id of the node to query upon. */
        nodeId: NodeId;
        /** Selector string. */
        selector: string;
    };
    type QuerySelectorReturn = {
        /** Query selector result. */
        nodeId: NodeId;
    };
    type QuerySelectorAllParameters = {
        /** Id of the node to query upon. */
        nodeId: NodeId;
        /** Selector string. */
        selector: string;
    };
    type QuerySelectorAllReturn = {
        /** Query selector result. */
        nodeIds: NodeId[];
    };
    type SetNodeNameParameters = {
        /** Id of the node to set name for. */
        nodeId: NodeId;
        /** New node's name. */
        name: string;
    };
    type SetNodeNameReturn = {
        /** New node's id. */
        nodeId: NodeId;
    };
    type SetNodeValueParameters = {
        /** Id of the node to set value for. */
        nodeId: NodeId;
        /** New node's value. */
        value: string;
    };
    type RemoveNodeParameters = {
        /** Id of the node to remove. */
        nodeId: NodeId;
    };
    type SetAttributeValueParameters = {
        /** Id of the element to set attribute for. */
        nodeId: NodeId;
        /** Attribute name. */
        name: string;
        /** Attribute value. */
        value: string;
    };
    type SetAttributesAsTextParameters = {
        /** Id of the element to set attributes for. */
        nodeId: NodeId;
        /** Text with a number of attributes. Will parse this text using HTML parser. */
        text: string;
        /** Attribute name to replace with new attributes derived from text in case text parsed successfully. */
        name?: string;
    };
    type RemoveAttributeParameters = {
        /** Id of the element to remove attribute from. */
        nodeId: NodeId;
        /** Name of the attribute to remove. */
        name: string;
    };
    type GetOuterHTMLParameters = {
        /** Identifier of the node. */
        nodeId?: NodeId;
        /** Identifier of the backend node. */
        backendNodeId?: BackendNodeId;
        /** JavaScript object id of the node wrapper. */
        objectId?: Runtime.RemoteObjectId;
    };
    type GetOuterHTMLReturn = {
        /** Outer HTML markup. */
        outerHTML: string;
    };
    type SetOuterHTMLParameters = {
        /** Id of the node to set markup for. */
        nodeId: NodeId;
        /** Outer HTML markup to set. */
        outerHTML: string;
    };
    type PerformSearchParameters = {
        /** Plain text or query selector or XPath search query. */
        query: string;
        /** True to search in user agent shadow DOM. */
        includeUserAgentShadowDOM?: boolean;
    };
    type PerformSearchReturn = {
        /** Unique search session identifier. */
        searchId: string;
        /** Number of search results. */
        resultCount: number;
    };
    type GetSearchResultsParameters = {
        /** Unique search session identifier. */
        searchId: string;
        /** Start index of the search result to be returned. */
        fromIndex: number;
        /** End index of the search result to be returned. */
        toIndex: number;
    };
    type GetSearchResultsReturn = {
        /** Ids of the search result nodes. */
        nodeIds: NodeId[];
    };
    type DiscardSearchResultsParameters = {
        /** Unique search session identifier. */
        searchId: string;
    };
    type RequestNodeParameters = {
        /** JavaScript object id to convert into node. */
        objectId: Runtime.RemoteObjectId;
    };
    type RequestNodeReturn = {
        /** Node id for given object. */
        nodeId: NodeId;
    };
    type PushNodeByPathToFrontendParameters = {
        /** Path to node in the proprietary format. */
        path: string;
    };
    type PushNodeByPathToFrontendReturn = {
        /** Id of the node for given path. */
        nodeId: NodeId;
    };
    type PushNodesByBackendIdsToFrontendParameters = {
        /** The array of backend node ids. */
        backendNodeIds: BackendNodeId[];
    };
    type PushNodesByBackendIdsToFrontendReturn = {
        /** The array of ids of pushed nodes that correspond to the backend ids specified in backendNodeIds. */
        nodeIds: NodeId[];
    };
    type SetInspectedNodeParameters = {
        /** DOM node id to be accessible by means of $x command line API. */
        nodeId: NodeId;
    };
    type ResolveNodeParameters = {
        /** Id of the node to resolve. */
        nodeId?: NodeId;
        /** Backend identifier of the node to resolve. */
        backendNodeId?: DOM.BackendNodeId;
        /** Symbolic group name that can be used to release multiple objects. */
        objectGroup?: string;
    };
    type ResolveNodeReturn = {
        /** JavaScript object wrapper for given node. */
        object: Runtime.RemoteObject;
    };
    type GetAttributesParameters = {
        /** Id of the node to retrieve attibutes for. */
        nodeId: NodeId;
    };
    type GetAttributesReturn = {
        /** An interleaved array of node attribute names and values. */
        attributes: string[];
    };
    type CopyToParameters = {
        /** Id of the node to copy. */
        nodeId: NodeId;
        /** Id of the element to drop the copy into. */
        targetNodeId: NodeId;
        /** Drop the copy before this node (if absent, the copy becomes the last child of <code>targetNodeId</code>). */
        insertBeforeNodeId?: NodeId;
    };
    type CopyToReturn = {
        /** Id of the node clone. */
        nodeId: NodeId;
    };
    type MoveToParameters = {
        /** Id of the node to move. */
        nodeId: NodeId;
        /** Id of the element to drop the moved node into. */
        targetNodeId: NodeId;
        /** Drop node before this one (if absent, the moved node becomes the last child of <code>targetNodeId</code>). */
        insertBeforeNodeId?: NodeId;
    };
    type MoveToReturn = {
        /** New id of the moved node. */
        nodeId: NodeId;
    };
    type FocusParameters = {
        /** Identifier of the node. */
        nodeId?: NodeId;
        /** Identifier of the backend node. */
        backendNodeId?: BackendNodeId;
        /** JavaScript object id of the node wrapper. */
        objectId?: Runtime.RemoteObjectId;
    };
    type SetFileInputFilesParameters = {
        /** Array of file paths to set. */
        files: string[];
        /** Identifier of the node. */
        nodeId?: NodeId;
        /** Identifier of the backend node. */
        backendNodeId?: BackendNodeId;
        /** JavaScript object id of the node wrapper. */
        objectId?: Runtime.RemoteObjectId;
    };
    type GetBoxModelParameters = {
        /** Identifier of the node. */
        nodeId?: NodeId;
        /** Identifier of the backend node. */
        backendNodeId?: BackendNodeId;
        /** JavaScript object id of the node wrapper. */
        objectId?: Runtime.RemoteObjectId;
    };
    type GetBoxModelReturn = {
        /** Box model for the node. */
        model: BoxModel;
    };
    type GetNodeForLocationParameters = {
        /** X coordinate. */
        x: number;
        /** Y coordinate. */
        y: number;
        /** False to skip to the nearest non-UA shadow root ancestor (default: false). */
        includeUserAgentShadowDOM?: boolean;
    };
    type GetNodeForLocationReturn = {
        /** Id of the node at given coordinates. */
        nodeId: NodeId;
    };
    type GetRelayoutBoundaryParameters = {
        /** Id of the node. */
        nodeId: NodeId;
    };
    type GetRelayoutBoundaryReturn = {
        /** Relayout boundary node id for the given node. */
        nodeId: NodeId;
    };
    type DescribeNodeParameters = {
        /** Identifier of the node. */
        nodeId?: NodeId;
        /** Identifier of the backend node. */
        backendNodeId?: BackendNodeId;
        /** JavaScript object id of the node wrapper. */
        objectId?: Runtime.RemoteObjectId;
        /** The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0. */
        depth?: number;
        /** Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false). */
        pierce?: boolean;
    };
    type DescribeNodeReturn = {
        /** Node description. */
        node: Node;
    };
}
/** This domain exposes CSS read/write operations. All CSS objects (stylesheets, rules, and styles) have an associated <code>id</code> used in subsequent operations on the related object. Each object type has a specific <code>id</code> structure, and those are not interchangeable between objects of different kinds. CSS objects can be loaded using the <code>get*ForNode()</code> calls (which accept a DOM node id). A client can also keep track of stylesheets via the <code>styleSheetAdded</code>/<code>styleSheetRemoved</code> events and subsequently load the required stylesheet contents using the <code>getStyleSheet[Text]()</code> methods. */
export declare namespace CSS {
    type StyleSheetId = string;
    /** Stylesheet type: "injected" for stylesheets injected via extension, "user-agent" for user-agent stylesheets, "inspector" for stylesheets created by the inspector (i.e. those holding the "via inspector" rules), "regular" for regular stylesheets. */
    type StyleSheetOrigin = "injected" | "user-agent" | "inspector" | "regular";
    /** CSS rule collection for a single pseudo style. */
    interface PseudoElementMatches {
        /** Pseudo element type. */
        pseudoType: DOM.PseudoType;
        /** Matches of CSS rules applicable to the pseudo style. */
        matches: RuleMatch[];
    }
    /** Inherited CSS rule collection from ancestor node. */
    interface InheritedStyleEntry {
        /** The ancestor node's inline style, if any, in the style inheritance chain. */
        inlineStyle?: CSSStyle;
        /** Matches of CSS rules matching the ancestor node in the style inheritance chain. */
        matchedCSSRules: RuleMatch[];
    }
    /** Match data for a CSS rule. */
    interface RuleMatch {
        /** CSS rule in the match. */
        rule: CSSRule;
        /** Matching selector indices in the rule's selectorList selectors (0-based). */
        matchingSelectors: number[];
    }
    /** Data for a simple selector (these are delimited by commas in a selector list). */
    interface Value {
        /** Value text. */
        text: string;
        /** Value range in the underlying resource (if available). */
        range?: SourceRange;
    }
    /** Selector list data. */
    interface SelectorList {
        /** Selectors in the list. */
        selectors: Value[];
        /** Rule selector text. */
        text: string;
    }
    /** CSS stylesheet metainformation. */
    interface CSSStyleSheetHeader {
        /** The stylesheet identifier. */
        styleSheetId: StyleSheetId;
        /** Owner frame identifier. */
        frameId: Page.FrameId;
        /** Stylesheet resource URL. */
        sourceURL: string;
        /** URL of source map associated with the stylesheet (if any). */
        sourceMapURL?: string;
        /** Stylesheet origin. */
        origin: StyleSheetOrigin;
        /** Stylesheet title. */
        title: string;
        /** The backend id for the owner node of the stylesheet. */
        ownerNode?: DOM.BackendNodeId;
        /** Denotes whether the stylesheet is disabled. */
        disabled: boolean;
        /** Whether the sourceURL field value comes from the sourceURL comment. */
        hasSourceURL?: boolean;
        /** Whether this stylesheet is created for STYLE tag by parser. This flag is not set for document.written STYLE tags. */
        isInline: boolean;
        /** Line offset of the stylesheet within the resource (zero based). */
        startLine: number;
        /** Column offset of the stylesheet within the resource (zero based). */
        startColumn: number;
        /** Size of the content (in characters). */
        length: number;
    }
    /** CSS rule representation. */
    interface CSSRule {
        /** The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from. */
        styleSheetId?: StyleSheetId;
        /** Rule selector data. */
        selectorList: SelectorList;
        /** Parent stylesheet's origin. */
        origin: StyleSheetOrigin;
        /** Associated style declaration. */
        style: CSSStyle;
        /** Media list array (for rules involving media queries). The array enumerates media queries starting with the innermost one, going outwards. */
        media?: CSSMedia[];
    }
    /** CSS coverage information. */
    interface RuleUsage {
        /** The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from. */
        styleSheetId: StyleSheetId;
        /** Offset of the start of the rule (including selector) from the beginning of the stylesheet. */
        startOffset: number;
        /** Offset of the end of the rule body from the beginning of the stylesheet. */
        endOffset: number;
        /** Indicates whether the rule was actually used by some element in the page. */
        used: boolean;
    }
    /** Text range within a resource. All numbers are zero-based. */
    interface SourceRange {
        /** Start line of range. */
        startLine: number;
        /** Start column of range (inclusive). */
        startColumn: number;
        /** End line of range */
        endLine: number;
        /** End column of range (exclusive). */
        endColumn: number;
    }
    interface ShorthandEntry {
        /** Shorthand name. */
        name: string;
        /** Shorthand value. */
        value: string;
        /** Whether the property has "!important" annotation (implies <code>false</code> if absent). */
        important?: boolean;
    }
    interface CSSComputedStyleProperty {
        /** Computed style property name. */
        name: string;
        /** Computed style property value. */
        value: string;
    }
    /** CSS style representation. */
    interface CSSStyle {
        /** The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from. */
        styleSheetId?: StyleSheetId;
        /** CSS properties in the style. */
        cssProperties: CSSProperty[];
        /** Computed values for all shorthands found in the style. */
        shorthandEntries: ShorthandEntry[];
        /** Style declaration text (if available). */
        cssText?: string;
        /** Style declaration range in the enclosing stylesheet (if available). */
        range?: SourceRange;
    }
    /** CSS property declaration data. */
    interface CSSProperty {
        /** The property name. */
        name: string;
        /** The property value. */
        value: string;
        /** Whether the property has "!important" annotation (implies <code>false</code> if absent). */
        important?: boolean;
        /** Whether the property is implicit (implies <code>false</code> if absent). */
        implicit?: boolean;
        /** The full property text as specified in the style. */
        text?: string;
        /** Whether the property is understood by the browser (implies <code>true</code> if absent). */
        parsedOk?: boolean;
        /** Whether the property is disabled by the user (present for source-based properties only). */
        disabled?: boolean;
        /** The entire property range in the enclosing style declaration (if available). */
        range?: SourceRange;
    }
    /** CSS media rule descriptor. */
    interface CSSMedia {
        /** Media query text. */
        text: string;
        /** Source of the media query: "mediaRule" if specified by a @media rule, "importRule" if specified by an @import rule, "linkedSheet" if specified by a "media" attribute in a linked stylesheet's LINK tag, "inlineSheet" if specified by a "media" attribute in an inline stylesheet's STYLE tag. */
        source: "mediaRule" | "importRule" | "linkedSheet" | "inlineSheet";
        /** URL of the document containing the media query description. */
        sourceURL?: string;
        /** The associated rule (@media or @import) header range in the enclosing stylesheet (if available). */
        range?: SourceRange;
        /** Identifier of the stylesheet containing this object (if exists). */
        styleSheetId?: StyleSheetId;
        /** Array of media queries. */
        mediaList?: MediaQuery[];
    }
    /** Media query descriptor. */
    interface MediaQuery {
        /** Array of media query expressions. */
        expressions: MediaQueryExpression[];
        /** Whether the media query condition is satisfied. */
        active: boolean;
    }
    /** Media query expression descriptor. */
    interface MediaQueryExpression {
        /** Media query expression value. */
        value: number;
        /** Media query expression units. */
        unit: string;
        /** Media query expression feature. */
        feature: string;
        /** The associated range of the value text in the enclosing stylesheet (if available). */
        valueRange?: SourceRange;
        /** Computed length of media query expression (if applicable). */
        computedLength?: number;
    }
    /** Information about amount of glyphs that were rendered with given font. */
    interface PlatformFontUsage {
        /** Font's family name reported by platform. */
        familyName: string;
        /** Indicates if the font was downloaded or resolved locally. */
        isCustomFont: boolean;
        /** Amount of glyphs that were rendered with this font. */
        glyphCount: number;
    }
    /** CSS keyframes rule representation. */
    interface CSSKeyframesRule {
        /** Animation name. */
        animationName: Value;
        /** List of keyframes. */
        keyframes: CSSKeyframeRule[];
    }
    /** CSS keyframe rule representation. */
    interface CSSKeyframeRule {
        /** The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from. */
        styleSheetId?: StyleSheetId;
        /** Parent stylesheet's origin. */
        origin: StyleSheetOrigin;
        /** Associated key text. */
        keyText: Value;
        /** Associated style declaration. */
        style: CSSStyle;
    }
    /** A descriptor of operation to mutate style declaration text. */
    interface StyleDeclarationEdit {
        /** The css style sheet identifier. */
        styleSheetId: StyleSheetId;
        /** The range of the style text in the enclosing stylesheet. */
        range: SourceRange;
        /** New style text. */
        text: string;
    }
    type StyleSheetChangedParameters = {
        styleSheetId: StyleSheetId;
    };
    type StyleSheetAddedParameters = {
        /** Added stylesheet metainfo. */
        header: CSSStyleSheetHeader;
    };
    type StyleSheetRemovedParameters = {
        /** Identifier of the removed stylesheet. */
        styleSheetId: StyleSheetId;
    };
    type GetMatchedStylesForNodeParameters = {
        nodeId: DOM.NodeId;
    };
    type GetMatchedStylesForNodeReturn = {
        /** Inline style for the specified DOM node. */
        inlineStyle?: CSSStyle;
        /** Attribute-defined element style (e.g. resulting from "width=20 height=100%"). */
        attributesStyle?: CSSStyle;
        /** CSS rules matching this node, from all applicable stylesheets. */
        matchedCSSRules?: RuleMatch[];
        /** Pseudo style matches for this node. */
        pseudoElements?: PseudoElementMatches[];
        /** A chain of inherited styles (from the immediate node parent up to the DOM tree root). */
        inherited?: InheritedStyleEntry[];
        /** A list of CSS keyframed animations matching this node. */
        cssKeyframesRules?: CSSKeyframesRule[];
    };
    type GetInlineStylesForNodeParameters = {
        nodeId: DOM.NodeId;
    };
    type GetInlineStylesForNodeReturn = {
        /** Inline style for the specified DOM node. */
        inlineStyle?: CSSStyle;
        /** Attribute-defined element style (e.g. resulting from "width=20 height=100%"). */
        attributesStyle?: CSSStyle;
    };
    type GetComputedStyleForNodeParameters = {
        nodeId: DOM.NodeId;
    };
    type GetComputedStyleForNodeReturn = {
        /** Computed style for the specified DOM node. */
        computedStyle: CSSComputedStyleProperty[];
    };
    type GetPlatformFontsForNodeParameters = {
        nodeId: DOM.NodeId;
    };
    type GetPlatformFontsForNodeReturn = {
        /** Usage statistics for every employed platform font. */
        fonts: PlatformFontUsage[];
    };
    type GetStyleSheetTextParameters = {
        styleSheetId: StyleSheetId;
    };
    type GetStyleSheetTextReturn = {
        /** The stylesheet text. */
        text: string;
    };
    type CollectClassNamesParameters = {
        styleSheetId: StyleSheetId;
    };
    type CollectClassNamesReturn = {
        /** Class name list. */
        classNames: string[];
    };
    type SetStyleSheetTextParameters = {
        styleSheetId: StyleSheetId;
        text: string;
    };
    type SetStyleSheetTextReturn = {
        /** URL of source map associated with script (if any). */
        sourceMapURL?: string;
    };
    type SetRuleSelectorParameters = {
        styleSheetId: StyleSheetId;
        range: SourceRange;
        selector: string;
    };
    type SetRuleSelectorReturn = {
        /** The resulting selector list after modification. */
        selectorList: SelectorList;
    };
    type SetKeyframeKeyParameters = {
        styleSheetId: StyleSheetId;
        range: SourceRange;
        keyText: string;
    };
    type SetKeyframeKeyReturn = {
        /** The resulting key text after modification. */
        keyText: Value;
    };
    type SetStyleTextsParameters = {
        edits: StyleDeclarationEdit[];
    };
    type SetStyleTextsReturn = {
        /** The resulting styles after modification. */
        styles: CSSStyle[];
    };
    type SetMediaTextParameters = {
        styleSheetId: StyleSheetId;
        range: SourceRange;
        text: string;
    };
    type SetMediaTextReturn = {
        /** The resulting CSS media rule after modification. */
        media: CSSMedia;
    };
    type CreateStyleSheetParameters = {
        /** Identifier of the frame where "via-inspector" stylesheet should be created. */
        frameId: Page.FrameId;
    };
    type CreateStyleSheetReturn = {
        /** Identifier of the created "via-inspector" stylesheet. */
        styleSheetId: StyleSheetId;
    };
    type AddRuleParameters = {
        /** The css style sheet identifier where a new rule should be inserted. */
        styleSheetId: StyleSheetId;
        /** The text of a new rule. */
        ruleText: string;
        /** Text position of a new rule in the target style sheet. */
        location: SourceRange;
    };
    type AddRuleReturn = {
        /** The newly created rule. */
        rule: CSSRule;
    };
    type ForcePseudoStateParameters = {
        /** The element id for which to force the pseudo state. */
        nodeId: DOM.NodeId;
        /** Element pseudo classes to force when computing the element's style. */
        forcedPseudoClasses: Array<"active" | "focus" | "hover" | "visited">;
    };
    type GetMediaQueriesReturn = {
        medias: CSSMedia[];
    };
    type SetEffectivePropertyValueForNodeParameters = {
        /** The element id for which to set property. */
        nodeId: DOM.NodeId;
        propertyName: string;
        value: string;
    };
    type GetBackgroundColorsParameters = {
        /** Id of the node to get background colors for. */
        nodeId: DOM.NodeId;
    };
    type GetBackgroundColorsReturn = {
        /** The range of background colors behind this element, if it contains any visible text. If no visible text is present, this will be undefined. In the case of a flat background color, this will consist of simply that color. In the case of a gradient, this will consist of each of the color stops. For anything more complicated, this will be an empty array. Images will be ignored (as if the image had failed to load). */
        backgroundColors?: string[];
        /** The computed font size for this node, as a CSS computed value string (e.g. '12px'). */
        computedFontSize?: string;
        /** The computed font weight for this node, as a CSS computed value string (e.g. 'normal' or '100'). */
        computedFontWeight?: string;
        /** The computed font size for the document body, as a computed CSS value string (e.g. '16px'). */
        computedBodyFontSize?: string;
    };
    type TakeCoverageDeltaReturn = {
        coverage: RuleUsage[];
    };
    type StopRuleUsageTrackingReturn = {
        ruleUsage: RuleUsage[];
    };
}
/** This domain facilitates obtaining document snapshots with DOM, layout, and style information. */
export declare namespace DOMSnapshot {
    /** A Node in the DOM tree. */
    interface DOMNode {
        /** <code>Node</code>'s nodeType. */
        nodeType: number;
        /** <code>Node</code>'s nodeName. */
        nodeName: string;
        /** <code>Node</code>'s nodeValue. */
        nodeValue: string;
        /** Only set for textarea elements, contains the text value. */
        textValue?: string;
        /** Only set for input elements, contains the input's associated text value. */
        inputValue?: string;
        /** Only set for radio and checkbox input elements, indicates if the element has been checked */
        inputChecked?: boolean;
        /** Only set for option elements, indicates if the element has been selected */
        optionSelected?: boolean;
        /** <code>Node</code>'s id, corresponds to DOM.Node.backendNodeId. */
        backendNodeId: DOM.BackendNodeId;
        /** The indexes of the node's child nodes in the <code>domNodes</code> array returned by <code>getSnapshot</code>, if any. */
        childNodeIndexes?: number[];
        /** Attributes of an <code>Element</code> node. */
        attributes?: NameValue[];
        /** Indexes of pseudo elements associated with this node in the <code>domNodes</code> array returned by <code>getSnapshot</code>, if any. */
        pseudoElementIndexes?: number[];
        /** The index of the node's related layout tree node in the <code>layoutTreeNodes</code> array returned by <code>getSnapshot</code>, if any. */
        layoutNodeIndex?: number;
        /** Document URL that <code>Document</code> or <code>FrameOwner</code> node points to. */
        documentURL?: string;
        /** Base URL that <code>Document</code> or <code>FrameOwner</code> node uses for URL completion. */
        baseURL?: string;
        /** Only set for documents, contains the document's content language. */
        contentLanguage?: string;
        /** Only set for documents, contains the document's character set encoding. */
        documentEncoding?: string;
        /** <code>DocumentType</code> node's publicId. */
        publicId?: string;
        /** <code>DocumentType</code> node's systemId. */
        systemId?: string;
        /** Frame ID for frame owner elements and also for the document node. */
        frameId?: Page.FrameId;
        /** The index of a frame owner element's content document in the <code>domNodes</code> array returned by <code>getSnapshot</code>, if any. */
        contentDocumentIndex?: number;
        /** Index of the imported document's node of a link element in the <code>domNodes</code> array returned by <code>getSnapshot</code>, if any. */
        importedDocumentIndex?: number;
        /** Index of the content node of a template element in the <code>domNodes</code> array returned by <code>getSnapshot</code>. */
        templateContentIndex?: number;
        /** Type of a pseudo element node. */
        pseudoType?: DOM.PseudoType;
        /** Whether this DOM node responds to mouse clicks. This includes nodes that have had click event listeners attached via JavaScript as well as anchor tags that naturally navigate when clicked. */
        isClickable?: boolean;
    }
    /** Details of post layout rendered text positions. The exact layout should not be regarded as stable and may change between versions. */
    interface InlineTextBox {
        /** The absolute position bounding box. */
        boundingBox: DOM.Rect;
        /** The starting index in characters, for this post layout textbox substring. */
        startCharacterIndex: number;
        /** The number of characters in this post layout textbox substring. */
        numCharacters: number;
    }
    /** Details of an element in the DOM tree with a LayoutObject. */
    interface LayoutTreeNode {
        /** The index of the related DOM node in the <code>domNodes</code> array returned by <code>getSnapshot</code>. */
        domNodeIndex: number;
        /** The absolute position bounding box. */
        boundingBox: DOM.Rect;
        /** Contents of the LayoutText, if any. */
        layoutText?: string;
        /** The post-layout inline text nodes, if any. */
        inlineTextNodes?: InlineTextBox[];
        /** Index into the <code>computedStyles</code> array returned by <code>getSnapshot</code>. */
        styleIndex?: number;
    }
    /** A subset of the full ComputedStyle as defined by the request whitelist. */
    interface ComputedStyle {
        /** Name/value pairs of computed style properties. */
        properties: NameValue[];
    }
    /** A name/value pair. */
    interface NameValue {
        /** Attribute/property name. */
        name: string;
        /** Attribute/property value. */
        value: string;
    }
    type GetSnapshotParameters = {
        /** Whitelist of computed styles to return. */
        computedStyleWhitelist: string[];
    };
    type GetSnapshotReturn = {
        /** The nodes in the DOM tree. The DOMNode at index 0 corresponds to the root document. */
        domNodes: DOMNode[];
        /** The nodes in the layout tree. */
        layoutTreeNodes: LayoutTreeNode[];
        /** Whitelisted ComputedStyle properties for each node in the layout tree. */
        computedStyles: ComputedStyle[];
    };
}
/** Input/Output operations for streams produced by DevTools. */
export declare namespace IO {
    /** This is either obtained from another method or specifed as <code>blob:&lt;uuid&gt;</code> where <code>&lt;uuid&gt</code> is an UUID of a Blob. */
    type StreamHandle = string;
    type ReadParameters = {
        /** Handle of the stream to read. */
        handle: StreamHandle;
        /** Seek to the specified offset before reading (if not specificed, proceed with offset following the last read). */
        offset?: number;
        /** Maximum number of bytes to read (left upon the agent discretion if not specified). */
        size?: number;
    };
    type ReadReturn = {
        /** Set if the data is base64-encoded */
        base64Encoded?: boolean;
        /** Data that were read. */
        data: string;
        /** Set if the end-of-file condition occured while reading. */
        eof: boolean;
    };
    type CloseParameters = {
        /** Handle of the stream to close. */
        handle: StreamHandle;
    };
    type ResolveBlobParameters = {
        /** Object id of a Blob object wrapper. */
        objectId: Runtime.RemoteObjectId;
    };
    type ResolveBlobReturn = {
        /** UUID of the specified Blob. */
        uuid: string;
    };
}
/** DOM debugging allows setting breakpoints on particular DOM operations and events. JavaScript execution will stop on these operations as if there was a regular breakpoint set. */
export declare namespace DOMDebugger {
    /** DOM breakpoint type. */
    type DOMBreakpointType = "subtree-modified" | "attribute-modified" | "node-removed";
    /** Object event listener. */
    interface EventListener {
        /** <code>EventListener</code>'s type. */
        type: string;
        /** <code>EventListener</code>'s useCapture. */
        useCapture: boolean;
        /** <code>EventListener</code>'s passive flag. */
        passive: boolean;
        /** <code>EventListener</code>'s once flag. */
        once: boolean;
        /** Script id of the handler code. */
        scriptId: Runtime.ScriptId;
        /** Line number in the script (0-based). */
        lineNumber: number;
        /** Column number in the script (0-based). */
        columnNumber: number;
        /** Event handler function value. */
        handler?: Runtime.RemoteObject;
        /** Event original handler function value. */
        originalHandler?: Runtime.RemoteObject;
        /** Node the listener is added to (if any). */
        backendNodeId?: DOM.BackendNodeId;
    }
    type SetDOMBreakpointParameters = {
        /** Identifier of the node to set breakpoint on. */
        nodeId: DOM.NodeId;
        /** Type of the operation to stop upon. */
        type: DOMBreakpointType;
    };
    type RemoveDOMBreakpointParameters = {
        /** Identifier of the node to remove breakpoint from. */
        nodeId: DOM.NodeId;
        /** Type of the breakpoint to remove. */
        type: DOMBreakpointType;
    };
    type SetEventListenerBreakpointParameters = {
        /** DOM Event name to stop on (any DOM event will do). */
        eventName: string;
        /** EventTarget interface name to stop on. If equal to <code>"*"</code> or not provided, will stop on any EventTarget. */
        targetName?: string;
    };
    type RemoveEventListenerBreakpointParameters = {
        /** Event name. */
        eventName: string;
        /** EventTarget interface name. */
        targetName?: string;
    };
    type SetInstrumentationBreakpointParameters = {
        /** Instrumentation name to stop on. */
        eventName: string;
    };
    type RemoveInstrumentationBreakpointParameters = {
        /** Instrumentation name to stop on. */
        eventName: string;
    };
    type SetXHRBreakpointParameters = {
        /** Resource URL substring. All XHRs having this substring in the URL will get stopped upon. */
        url: string;
    };
    type RemoveXHRBreakpointParameters = {
        /** Resource URL substring. */
        url: string;
    };
    type GetEventListenersParameters = {
        /** Identifier of the object to return listeners for. */
        objectId: Runtime.RemoteObjectId;
        /** The maximum depth at which Node children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0. */
        depth?: number;
        /** Whether or not iframes and shadow roots should be traversed when returning the subtree (default is false). Reports listeners for all contexts if pierce is enabled. */
        pierce?: boolean;
    };
    type GetEventListenersReturn = {
        /** Array of relevant listeners. */
        listeners: EventListener[];
    };
}
/** Supports additional targets discovery and allows to attach to them. */
export declare namespace Target {
    type TargetID = string;
    /** Unique identifier of attached debugging session. */
    type SessionID = string;
    type BrowserContextID = string;
    interface TargetInfo {
        targetId: TargetID;
        type: string;
        title: string;
        url: string;
        /** Whether the target has an attached client. */
        attached: boolean;
        /** Opener target Id */
        openerId?: TargetID;
    }
    interface RemoteLocation {
        host: string;
        port: number;
    }
    type TargetCreatedParameters = {
        targetInfo: TargetInfo;
    };
    type TargetInfoChangedParameters = {
        targetInfo: TargetInfo;
    };
    type TargetDestroyedParameters = {
        targetId: TargetID;
    };
    type AttachedToTargetParameters = {
        /** Identifier assigned to the session used to send/receive messages. */
        sessionId: SessionID;
        targetInfo: TargetInfo;
        waitingForDebugger: boolean;
    };
    type DetachedFromTargetParameters = {
        /** Detached session identifier. */
        sessionId: SessionID;
        /** Deprecated. */
        targetId?: TargetID;
    };
    type ReceivedMessageFromTargetParameters = {
        /** Identifier of a session which sends a message. */
        sessionId: SessionID;
        message: string;
        /** Deprecated. */
        targetId?: TargetID;
    };
    type SetDiscoverTargetsParameters = {
        /** Whether to discover available targets. */
        discover: boolean;
    };
    type SetAutoAttachParameters = {
        /** Whether to auto-attach to related targets. */
        autoAttach: boolean;
        /** Whether to pause new targets when attaching to them. Use <code>Runtime.runIfWaitingForDebugger</code> to run paused targets. */
        waitForDebuggerOnStart: boolean;
    };
    type SetAttachToFramesParameters = {
        /** Whether to attach to frames. */
        value: boolean;
    };
    type SetRemoteLocationsParameters = {
        /** List of remote locations. */
        locations: RemoteLocation[];
    };
    type SendMessageToTargetParameters = {
        message: string;
        /** Identifier of the session. */
        sessionId?: SessionID;
        /** Deprecated. */
        targetId?: TargetID;
    };
    type GetTargetInfoParameters = {
        targetId: TargetID;
    };
    type GetTargetInfoReturn = {
        targetInfo: TargetInfo;
    };
    type ActivateTargetParameters = {
        targetId: TargetID;
    };
    type CloseTargetParameters = {
        targetId: TargetID;
    };
    type CloseTargetReturn = {
        success: boolean;
    };
    type AttachToTargetParameters = {
        targetId: TargetID;
    };
    type AttachToTargetReturn = {
        /** Id assigned to the session. */
        sessionId: SessionID;
    };
    type DetachFromTargetParameters = {
        /** Session to detach. */
        sessionId?: SessionID;
        /** Deprecated. */
        targetId?: TargetID;
    };
    type CreateBrowserContextReturn = {
        /** The id of the context created. */
        browserContextId: BrowserContextID;
    };
    type DisposeBrowserContextParameters = {
        browserContextId: BrowserContextID;
    };
    type DisposeBrowserContextReturn = {
        success: boolean;
    };
    type CreateTargetParameters = {
        /** The initial URL the page will be navigated to. */
        url: string;
        /** Frame width in DIP (headless chrome only). */
        width?: number;
        /** Frame height in DIP (headless chrome only). */
        height?: number;
        /** The browser context to create the page in (headless chrome only). */
        browserContextId?: BrowserContextID;
        /** Whether BeginFrames for this target will be controlled via DevTools (headless chrome only, not supported on MacOS yet, false by default). */
        enableBeginFrameControl?: boolean;
    };
    type CreateTargetReturn = {
        /** The id of the page opened. */
        targetId: TargetID;
    };
    type GetTargetsReturn = {
        /** The list of targets. */
        targetInfos: TargetInfo[];
    };
}
/** This domain provides experimental commands only supported in headless mode. */
export declare namespace HeadlessExperimental {
    /** Encoding options for a screenshot. */
    interface ScreenshotParams {
        /** Image compression format (defaults to png). */
        format?: "jpeg" | "png";
        /** Compression quality from range [0..100] (jpeg only). */
        quality?: number;
    }
    type NeedsBeginFramesChangedParameters = {
        /** True if BeginFrames are needed, false otherwise. */
        needsBeginFrames: boolean;
    };
    type BeginFrameParameters = {
        /** Timestamp of this BeginFrame (milliseconds since epoch). If not set, the current time will be used. */
        frameTime?: Runtime.Timestamp;
        /** Deadline of this BeginFrame (milliseconds since epoch). If not set, the deadline will be calculated from the frameTime and interval. */
        deadline?: Runtime.Timestamp;
        /** The interval between BeginFrames that is reported to the compositor, in milliseconds. Defaults to a 60 frames/second interval, i.e. about 16.666 milliseconds. */
        interval?: number;
        /** If set, a screenshot of the frame will be captured and returned in the response. Otherwise, no screenshot will be captured. */
        screenshot?: ScreenshotParams;
    };
    type BeginFrameReturn = {
        /** Whether the BeginFrame resulted in damage and, thus, a new frame was committed to the display. */
        hasDamage: boolean;
        /** Whether the main frame submitted a new display frame in response to this BeginFrame. */
        mainFrameContentUpdated: boolean;
        /** Base64-encoded image data of the screenshot, if one was requested and successfully taken. */
        screenshotData?: string;
    };
}
export declare namespace ServiceWorker {
    /** ServiceWorker registration. */
    interface ServiceWorkerRegistration {
        registrationId: string;
        scopeURL: string;
        isDeleted: boolean;
    }
    type ServiceWorkerVersionRunningStatus = "stopped" | "starting" | "running" | "stopping";
    type ServiceWorkerVersionStatus = "new" | "installing" | "installed" | "activating" | "activated" | "redundant";
    /** ServiceWorker version. */
    interface ServiceWorkerVersion {
        versionId: string;
        registrationId: string;
        scriptURL: string;
        runningStatus: ServiceWorkerVersionRunningStatus;
        status: ServiceWorkerVersionStatus;
        /** The Last-Modified header value of the main script. */
        scriptLastModified?: number;
        /** The time at which the response headers of the main script were received from the server.  For cached script it is the last time the cache entry was validated. */
        scriptResponseTime?: number;
        controlledClients?: Target.TargetID[];
        targetId?: Target.TargetID;
    }
    /** ServiceWorker error message. */
    interface ServiceWorkerErrorMessage {
        errorMessage: string;
        registrationId: string;
        versionId: string;
        sourceURL: string;
        lineNumber: number;
        columnNumber: number;
    }
    type WorkerRegistrationUpdatedParameters = {
        registrations: ServiceWorkerRegistration[];
    };
    type WorkerVersionUpdatedParameters = {
        versions: ServiceWorkerVersion[];
    };
    type WorkerErrorReportedParameters = {
        errorMessage: ServiceWorkerErrorMessage;
    };
    type UnregisterParameters = {
        scopeURL: string;
    };
    type UpdateRegistrationParameters = {
        scopeURL: string;
    };
    type StartWorkerParameters = {
        scopeURL: string;
    };
    type SkipWaitingParameters = {
        scopeURL: string;
    };
    type StopWorkerParameters = {
        versionId: string;
    };
    type InspectWorkerParameters = {
        versionId: string;
    };
    type SetForceUpdateOnPageLoadParameters = {
        forceUpdateOnPageLoad: boolean;
    };
    type DeliverPushMessageParameters = {
        origin: string;
        registrationId: string;
        data: string;
    };
    type DispatchSyncEventParameters = {
        origin: string;
        registrationId: string;
        tag: string;
        lastChance: boolean;
    };
}
export declare namespace Input {
    interface TouchPoint {
        /** X coordinate of the event relative to the main frame's viewport in CSS pixels. */
        x: number;
        /** Y coordinate of the event relative to the main frame's viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport. */
        y: number;
        /** X radius of the touch area (default: 1.0). */
        radiusX?: number;
        /** Y radius of the touch area (default: 1.0). */
        radiusY?: number;
        /** Rotation angle (default: 0.0). */
        rotationAngle?: number;
        /** Force (default: 1.0). */
        force?: number;
        /** Identifier used to track touch sources between events, must be unique within an event. */
        id?: number;
    }
    type GestureSourceType = "default" | "touch" | "mouse";
    /** UTC time in seconds, counted from January 1, 1970. */
    type TimeSinceEpoch = number;
    type SetIgnoreInputEventsParameters = {
        /** Ignores input events processing when set to true. */
        ignore: boolean;
    };
    type DispatchKeyEventParameters = {
        /** Type of the key event. */
        type: "keyDown" | "keyUp" | "rawKeyDown" | "char";
        /** Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0). */
        modifiers?: number;
        /** Time at which the event occurred. */
        timestamp?: TimeSinceEpoch;
        /** Text as generated by processing a virtual key code with a keyboard layout. Not needed for for <code>keyUp</code> and <code>rawKeyDown</code> events (default: "") */
        text?: string;
        /** Text that would have been generated by the keyboard if no modifiers were pressed (except for shift). Useful for shortcut (accelerator) key handling (default: ""). */
        unmodifiedText?: string;
        /** Unique key identifier (e.g., 'U+0041') (default: ""). */
        keyIdentifier?: string;
        /** Unique DOM defined string value for each physical key (e.g., 'KeyA') (default: ""). */
        code?: string;
        /** Unique DOM defined string value describing the meaning of the key in the context of active modifiers, keyboard layout, etc (e.g., 'AltGr') (default: ""). */
        key?: string;
        /** Windows virtual key code (default: 0). */
        windowsVirtualKeyCode?: number;
        /** Native virtual key code (default: 0). */
        nativeVirtualKeyCode?: number;
        /** Whether the event was generated from auto repeat (default: false). */
        autoRepeat?: boolean;
        /** Whether the event was generated from the keypad (default: false). */
        isKeypad?: boolean;
        /** Whether the event was a system key event (default: false). */
        isSystemKey?: boolean;
        /** Whether the event was from the left or right side of the keyboard. 1=Left, 2=Right (default: 0). */
        location?: number;
    };
    type DispatchMouseEventParameters = {
        /** Type of the mouse event. */
        type: "mousePressed" | "mouseReleased" | "mouseMoved" | "mouseWheel";
        /** X coordinate of the event relative to the main frame's viewport in CSS pixels. */
        x: number;
        /** Y coordinate of the event relative to the main frame's viewport in CSS pixels. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport. */
        y: number;
        /** Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0). */
        modifiers?: number;
        /** Time at which the event occurred. */
        timestamp?: TimeSinceEpoch;
        /** Mouse button (default: "none"). */
        button?: "none" | "left" | "middle" | "right";
        /** Number of times the mouse button was clicked (default: 0). */
        clickCount?: number;
        /** X delta in CSS pixels for mouse wheel event (default: 0). */
        deltaX?: number;
        /** Y delta in CSS pixels for mouse wheel event (default: 0). */
        deltaY?: number;
    };
    type DispatchTouchEventParameters = {
        /** Type of the touch event. TouchEnd and TouchCancel must not contain any touch points, while TouchStart and TouchMove must contains at least one. */
        type: "touchStart" | "touchEnd" | "touchMove" | "touchCancel";
        /** Active touch points on the touch device. One event per any changed point (compared to previous touch event in a sequence) is generated, emulating pressing/moving/releasing points one by one. */
        touchPoints: TouchPoint[];
        /** Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0). */
        modifiers?: number;
        /** Time at which the event occurred. */
        timestamp?: TimeSinceEpoch;
    };
    type EmulateTouchFromMouseEventParameters = {
        /** Type of the mouse event. */
        type: "mousePressed" | "mouseReleased" | "mouseMoved" | "mouseWheel";
        /** X coordinate of the mouse pointer in DIP. */
        x: number;
        /** Y coordinate of the mouse pointer in DIP. */
        y: number;
        /** Time at which the event occurred. */
        timestamp: TimeSinceEpoch;
        /** Mouse button. */
        button: "none" | "left" | "middle" | "right";
        /** X delta in DIP for mouse wheel event (default: 0). */
        deltaX?: number;
        /** Y delta in DIP for mouse wheel event (default: 0). */
        deltaY?: number;
        /** Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0). */
        modifiers?: number;
        /** Number of times the mouse button was clicked (default: 0). */
        clickCount?: number;
    };
    type SynthesizePinchGestureParameters = {
        /** X coordinate of the start of the gesture in CSS pixels. */
        x: number;
        /** Y coordinate of the start of the gesture in CSS pixels. */
        y: number;
        /** Relative scale factor after zooming (>1.0 zooms in, <1.0 zooms out). */
        scaleFactor: number;
        /** Relative pointer speed in pixels per second (default: 800). */
        relativeSpeed?: number;
        /** Which type of input events to be generated (default: 'default', which queries the platform for the preferred input type). */
        gestureSourceType?: GestureSourceType;
    };
    type SynthesizeScrollGestureParameters = {
        /** X coordinate of the start of the gesture in CSS pixels. */
        x: number;
        /** Y coordinate of the start of the gesture in CSS pixels. */
        y: number;
        /** The distance to scroll along the X axis (positive to scroll left). */
        xDistance?: number;
        /** The distance to scroll along the Y axis (positive to scroll up). */
        yDistance?: number;
        /** The number of additional pixels to scroll back along the X axis, in addition to the given distance. */
        xOverscroll?: number;
        /** The number of additional pixels to scroll back along the Y axis, in addition to the given distance. */
        yOverscroll?: number;
        /** Prevent fling (default: true). */
        preventFling?: boolean;
        /** Swipe speed in pixels per second (default: 800). */
        speed?: number;
        /** Which type of input events to be generated (default: 'default', which queries the platform for the preferred input type). */
        gestureSourceType?: GestureSourceType;
        /** The number of times to repeat the gesture (default: 0). */
        repeatCount?: number;
        /** The number of milliseconds delay between each repeat. (default: 250). */
        repeatDelayMs?: number;
        /** The name of the interaction markers to generate, if not empty (default: ""). */
        interactionMarkerName?: string;
    };
    type SynthesizeTapGestureParameters = {
        /** X coordinate of the start of the gesture in CSS pixels. */
        x: number;
        /** Y coordinate of the start of the gesture in CSS pixels. */
        y: number;
        /** Duration between touchdown and touchup events in ms (default: 50). */
        duration?: number;
        /** Number of times to perform the tap (e.g. 2 for double tap, default: 1). */
        tapCount?: number;
        /** Which type of input events to be generated (default: 'default', which queries the platform for the preferred input type). */
        gestureSourceType?: GestureSourceType;
    };
}
export declare namespace LayerTree {
    /** Unique Layer identifier. */
    type LayerId = string;
    /** Unique snapshot identifier. */
    type SnapshotId = string;
    /** Rectangle where scrolling happens on the main thread. */
    interface ScrollRect {
        /** Rectangle itself. */
        rect: DOM.Rect;
        /** Reason for rectangle to force scrolling on the main thread */
        type: "RepaintsOnScroll" | "TouchEventHandler" | "WheelEventHandler";
    }
    /** Sticky position constraints. */
    interface StickyPositionConstraint {
        /** Layout rectangle of the sticky element before being shifted */
        stickyBoxRect: DOM.Rect;
        /** Layout rectangle of the containing block of the sticky element */
        containingBlockRect: DOM.Rect;
        /** The nearest sticky layer that shifts the sticky box */
        nearestLayerShiftingStickyBox?: LayerId;
        /** The nearest sticky layer that shifts the containing block */
        nearestLayerShiftingContainingBlock?: LayerId;
    }
    /** Serialized fragment of layer picture along with its offset within the layer. */
    interface PictureTile {
        /** Offset from owning layer left boundary */
        x: number;
        /** Offset from owning layer top boundary */
        y: number;
        /** Base64-encoded snapshot data. */
        picture: string;
    }
    /** Information about a compositing layer. */
    interface Layer {
        /** The unique id for this layer. */
        layerId: LayerId;
        /** The id of parent (not present for root). */
        parentLayerId?: LayerId;
        /** The backend id for the node associated with this layer. */
        backendNodeId?: DOM.BackendNodeId;
        /** Offset from parent layer, X coordinate. */
        offsetX: number;
        /** Offset from parent layer, Y coordinate. */
        offsetY: number;
        /** Layer width. */
        width: number;
        /** Layer height. */
        height: number;
        /** Transformation matrix for layer, default is identity matrix */
        transform?: number[];
        /** Transform anchor point X, absent if no transform specified */
        anchorX?: number;
        /** Transform anchor point Y, absent if no transform specified */
        anchorY?: number;
        /** Transform anchor point Z, absent if no transform specified */
        anchorZ?: number;
        /** Indicates how many time this layer has painted. */
        paintCount: number;
        /** Indicates whether this layer hosts any content, rather than being used for transform/scrolling purposes only. */
        drawsContent: boolean;
        /** Set if layer is not visible. */
        invisible?: boolean;
        /** Rectangles scrolling on main thread only. */
        scrollRects?: ScrollRect[];
        /** Sticky position constraint information */
        stickyPositionConstraint?: StickyPositionConstraint;
    }
    /** Array of timings, one per paint step. */
    type PaintProfile = number[];
    type LayerTreeDidChangeParameters = {
        /** Layer tree, absent if not in the comspositing mode. */
        layers?: Layer[];
    };
    type LayerPaintedParameters = {
        /** The id of the painted layer. */
        layerId: LayerId;
        /** Clip rectangle. */
        clip: DOM.Rect;
    };
    type CompositingReasonsParameters = {
        /** The id of the layer for which we want to get the reasons it was composited. */
        layerId: LayerId;
    };
    type CompositingReasonsReturn = {
        /** A list of strings specifying reasons for the given layer to become composited. */
        compositingReasons: string[];
    };
    type MakeSnapshotParameters = {
        /** The id of the layer. */
        layerId: LayerId;
    };
    type MakeSnapshotReturn = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
    };
    type LoadSnapshotParameters = {
        /** An array of tiles composing the snapshot. */
        tiles: PictureTile[];
    };
    type LoadSnapshotReturn = {
        /** The id of the snapshot. */
        snapshotId: SnapshotId;
    };
    type ReleaseSnapshotParameters = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
    };
    type ProfileSnapshotParameters = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
        /** The maximum number of times to replay the snapshot (1, if not specified). */
        minRepeatCount?: number;
        /** The minimum duration (in seconds) to replay the snapshot. */
        minDuration?: number;
        /** The clip rectangle to apply when replaying the snapshot. */
        clipRect?: DOM.Rect;
    };
    type ProfileSnapshotReturn = {
        /** The array of paint profiles, one per run. */
        timings: PaintProfile[];
    };
    type ReplaySnapshotParameters = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
        /** The first step to replay from (replay from the very start if not specified). */
        fromStep?: number;
        /** The last step to replay to (replay till the end if not specified). */
        toStep?: number;
        /** The scale to apply while replaying (defaults to 1). */
        scale?: number;
    };
    type ReplaySnapshotReturn = {
        /** A data: URL for resulting image. */
        dataURL: string;
    };
    type SnapshotCommandLogParameters = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
    };
    type SnapshotCommandLogReturn = {
        /** The array of canvas function calls. */
        commandLog: any[];
    };
}
export declare namespace DeviceOrientation {
    type SetDeviceOrientationOverrideParameters = {
        /** Mock alpha */
        alpha: number;
        /** Mock beta */
        beta: number;
        /** Mock gamma */
        gamma: number;
    };
}
export declare namespace Tracing {
    /** Configuration for memory dump. Used only when "memory-infra" category is enabled. */
    type MemoryDumpConfig = any;
    interface TraceConfig {
        /** Controls how the trace buffer stores data. */
        recordMode?: "recordUntilFull" | "recordContinuously" | "recordAsMuchAsPossible" | "echoToConsole";
        /** Turns on JavaScript stack sampling. */
        enableSampling?: boolean;
        /** Turns on system tracing. */
        enableSystrace?: boolean;
        /** Turns on argument filter. */
        enableArgumentFilter?: boolean;
        /** Included category filters. */
        includedCategories?: string[];
        /** Excluded category filters. */
        excludedCategories?: string[];
        /** Configuration to synthesize the delays in tracing. */
        syntheticDelays?: string[];
        /** Configuration for memory dump triggers. Used only when "memory-infra" category is enabled. */
        memoryDumpConfig?: MemoryDumpConfig;
    }
    type DataCollectedParameters = {
        value: any[];
    };
    type TracingCompleteParameters = {
        /** A handle of the stream that holds resulting trace data. */
        stream?: IO.StreamHandle;
    };
    type BufferUsageParameters = {
        /** A number in range [0..1] that indicates the used size of event buffer as a fraction of its total size. */
        percentFull?: number;
        /** An approximate number of events in the trace log. */
        eventCount?: number;
        /** A number in range [0..1] that indicates the used size of event buffer as a fraction of its total size. */
        value?: number;
    };
    type StartParameters = {
        /** Category/tag filter */
        categories?: string;
        /** Tracing options */
        options?: string;
        /** If set, the agent will issue bufferUsage events at this interval, specified in milliseconds */
        bufferUsageReportingInterval?: number;
        /** Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to <code>ReportEvents</code>). */
        transferMode?: "ReportEvents" | "ReturnAsStream";
        traceConfig?: TraceConfig;
    };
    type GetCategoriesReturn = {
        /** A list of supported tracing categories. */
        categories: string[];
    };
    type RequestMemoryDumpReturn = {
        /** GUID of the resulting global memory dump. */
        dumpGuid: string;
        /** True iff the global memory dump succeeded. */
        success: boolean;
    };
    type RecordClockSyncMarkerParameters = {
        /** The ID of this clock sync marker */
        syncId: string;
    };
}
export declare namespace Animation {
    /** Animation instance. */
    interface Animation {
        /** <code>Animation</code>'s id. */
        id: string;
        /** <code>Animation</code>'s name. */
        name: string;
        /** <code>Animation</code>'s internal paused state. */
        pausedState: boolean;
        /** <code>Animation</code>'s play state. */
        playState: string;
        /** <code>Animation</code>'s playback rate. */
        playbackRate: number;
        /** <code>Animation</code>'s start time. */
        startTime: number;
        /** <code>Animation</code>'s current time. */
        currentTime: number;
        /** Animation type of <code>Animation</code>. */
        type: "CSSTransition" | "CSSAnimation" | "WebAnimation";
        /** <code>Animation</code>'s source animation node. */
        source?: AnimationEffect;
        /** A unique ID for <code>Animation</code> representing the sources that triggered this CSS animation/transition. */
        cssId?: string;
    }
    /** AnimationEffect instance */
    interface AnimationEffect {
        /** <code>AnimationEffect</code>'s delay. */
        delay: number;
        /** <code>AnimationEffect</code>'s end delay. */
        endDelay: number;
        /** <code>AnimationEffect</code>'s iteration start. */
        iterationStart: number;
        /** <code>AnimationEffect</code>'s iterations. */
        iterations: number;
        /** <code>AnimationEffect</code>'s iteration duration. */
        duration: number;
        /** <code>AnimationEffect</code>'s playback direction. */
        direction: string;
        /** <code>AnimationEffect</code>'s fill mode. */
        fill: string;
        /** <code>AnimationEffect</code>'s target node. */
        backendNodeId?: DOM.BackendNodeId;
        /** <code>AnimationEffect</code>'s keyframes. */
        keyframesRule?: KeyframesRule;
        /** <code>AnimationEffect</code>'s timing function. */
        easing: string;
    }
    /** Keyframes Rule */
    interface KeyframesRule {
        /** CSS keyframed animation's name. */
        name?: string;
        /** List of animation keyframes. */
        keyframes: KeyframeStyle[];
    }
    /** Keyframe Style */
    interface KeyframeStyle {
        /** Keyframe's time offset. */
        offset: string;
        /** <code>AnimationEffect</code>'s timing function. */
        easing: string;
    }
    type AnimationCreatedParameters = {
        /** Id of the animation that was created. */
        id: string;
    };
    type AnimationStartedParameters = {
        /** Animation that was started. */
        animation: Animation;
    };
    type AnimationCanceledParameters = {
        /** Id of the animation that was cancelled. */
        id: string;
    };
    type GetPlaybackRateReturn = {
        /** Playback rate for animations on page. */
        playbackRate: number;
    };
    type SetPlaybackRateParameters = {
        /** Playback rate for animations on page */
        playbackRate: number;
    };
    type GetCurrentTimeParameters = {
        /** Id of animation. */
        id: string;
    };
    type GetCurrentTimeReturn = {
        /** Current time of the page. */
        currentTime: number;
    };
    type SetPausedParameters = {
        /** Animations to set the pause state of. */
        animations: string[];
        /** Paused state to set to. */
        paused: boolean;
    };
    type SetTimingParameters = {
        /** Animation id. */
        animationId: string;
        /** Duration of the animation. */
        duration: number;
        /** Delay of the animation. */
        delay: number;
    };
    type SeekAnimationsParameters = {
        /** List of animation ids to seek. */
        animations: string[];
        /** Set the current time of each animation. */
        currentTime: number;
    };
    type ReleaseAnimationsParameters = {
        /** List of animation ids to seek. */
        animations: string[];
    };
    type ResolveAnimationParameters = {
        /** Animation id. */
        animationId: string;
    };
    type ResolveAnimationReturn = {
        /** Corresponding remote object. */
        remoteObject: Runtime.RemoteObject;
    };
}
export declare namespace Accessibility {
    /** Unique accessibility node identifier. */
    type AXNodeId = string;
    /** Enum of possible property types. */
    type AXValueType = "boolean" | "tristate" | "booleanOrUndefined" | "idref" | "idrefList" | "integer" | "node" | "nodeList" | "number" | "string" | "computedString" | "token" | "tokenList" | "domRelation" | "role" | "internalRole" | "valueUndefined";
    /** Enum of possible property sources. */
    type AXValueSourceType = "attribute" | "implicit" | "style" | "contents" | "placeholder" | "relatedElement";
    /** Enum of possible native property sources (as a subtype of a particular AXValueSourceType). */
    type AXValueNativeSourceType = "figcaption" | "label" | "labelfor" | "labelwrapped" | "legend" | "tablecaption" | "title" | "other";
    /** A single source for a computed AX property. */
    interface AXValueSource {
        /** What type of source this is. */
        type: AXValueSourceType;
        /** The value of this property source. */
        value?: AXValue;
        /** The name of the relevant attribute, if any. */
        attribute?: string;
        /** The value of the relevant attribute, if any. */
        attributeValue?: AXValue;
        /** Whether this source is superseded by a higher priority source. */
        superseded?: boolean;
        /** The native markup source for this value, e.g. a <label> element. */
        nativeSource?: AXValueNativeSourceType;
        /** The value, such as a node or node list, of the native source. */
        nativeSourceValue?: AXValue;
        /** Whether the value for this property is invalid. */
        invalid?: boolean;
        /** Reason for the value being invalid, if it is. */
        invalidReason?: string;
    }
    interface AXRelatedNode {
        /** The BackendNodeId of the related DOM node. */
        backendDOMNodeId: DOM.BackendNodeId;
        /** The IDRef value provided, if any. */
        idref?: string;
        /** The text alternative of this node in the current context. */
        text?: string;
    }
    interface AXProperty {
        /** The name of this property. */
        name: AXPropertyName;
        /** The value of this property. */
        value: AXValue;
    }
    /** A single computed AX property. */
    interface AXValue {
        /** The type of this value. */
        type: AXValueType;
        /** The computed value of this property. */
        value?: any;
        /** One or more related nodes, if applicable. */
        relatedNodes?: AXRelatedNode[];
        /** The sources which contributed to the computation of this property. */
        sources?: AXValueSource[];
    }
    /** Values of AXProperty name: from 'busy' to 'roledescription' - states which apply to every AX node, from 'live' to 'root' - attributes which apply to nodes in live regions, from 'autocomplete' to 'valuetext' - attributes which apply to widgets, from 'checked' to 'selected' - states which apply to widgets, from 'activedescendant' to 'owns' - relationships between elements other than parent/child/sibling. */
    type AXPropertyName = "busy" | "disabled" | "hidden" | "hiddenRoot" | "invalid" | "keyshortcuts" | "roledescription" | "live" | "atomic" | "relevant" | "root" | "autocomplete" | "haspopup" | "level" | "multiselectable" | "orientation" | "multiline" | "readonly" | "required" | "valuemin" | "valuemax" | "valuetext" | "checked" | "expanded" | "modal" | "pressed" | "selected" | "activedescendant" | "controls" | "describedby" | "details" | "errormessage" | "flowto" | "labelledby" | "owns";
    /** A node in the accessibility tree. */
    interface AXNode {
        /** Unique identifier for this node. */
        nodeId: AXNodeId;
        /** Whether this node is ignored for accessibility */
        ignored: boolean;
        /** Collection of reasons why this node is hidden. */
        ignoredReasons?: AXProperty[];
        /** This <code>Node</code>'s role, whether explicit or implicit. */
        role?: AXValue;
        /** The accessible name for this <code>Node</code>. */
        name?: AXValue;
        /** The accessible description for this <code>Node</code>. */
        description?: AXValue;
        /** The value for this <code>Node</code>. */
        value?: AXValue;
        /** All other properties */
        properties?: AXProperty[];
        /** IDs for each of this node's child nodes. */
        childIds?: AXNodeId[];
        /** The backend ID for the associated DOM node, if any. */
        backendDOMNodeId?: DOM.BackendNodeId;
    }
    type GetPartialAXTreeParameters = {
        /** ID of node to get the partial accessibility tree for. */
        nodeId: DOM.NodeId;
        /** Whether to fetch this nodes ancestors, siblings and children. Defaults to true. */
        fetchRelatives?: boolean;
    };
    type GetPartialAXTreeReturn = {
        /** The <code>Accessibility.AXNode</code> for this DOM node, if it exists, plus its ancestors, siblings and children, if requested. */
        nodes: AXNode[];
    };
}
export declare namespace Storage {
    /** Enum of possible storage types. */
    type StorageType = "appcache" | "cookies" | "file_systems" | "indexeddb" | "local_storage" | "shader_cache" | "websql" | "service_workers" | "cache_storage" | "all" | "other";
    /** Usage for a storage type. */
    interface UsageForType {
        /** Name of storage type. */
        storageType: StorageType;
        /** Storage usage (bytes). */
        usage: number;
    }
    type CacheStorageListUpdatedParameters = {
        /** Origin to update. */
        origin: string;
    };
    type CacheStorageContentUpdatedParameters = {
        /** Origin to update. */
        origin: string;
        /** Name of cache in origin. */
        cacheName: string;
    };
    type IndexedDBListUpdatedParameters = {
        /** Origin to update. */
        origin: string;
    };
    type IndexedDBContentUpdatedParameters = {
        /** Origin to update. */
        origin: string;
        /** Database to update. */
        databaseName: string;
        /** ObjectStore to update. */
        objectStoreName: string;
    };
    type ClearDataForOriginParameters = {
        /** Security origin. */
        origin: string;
        /** Comma separated origin names. */
        storageTypes: string;
    };
    type GetUsageAndQuotaParameters = {
        /** Security origin. */
        origin: string;
    };
    type GetUsageAndQuotaReturn = {
        /** Storage usage (bytes). */
        usage: number;
        /** Storage quota (bytes). */
        quota: number;
        /** Storage usage per type (bytes). */
        usageBreakdown: UsageForType[];
    };
    type TrackCacheStorageForOriginParameters = {
        /** Security origin. */
        origin: string;
    };
    type UntrackCacheStorageForOriginParameters = {
        /** Security origin. */
        origin: string;
    };
    type TrackIndexedDBForOriginParameters = {
        /** Security origin. */
        origin: string;
    };
    type UntrackIndexedDBForOriginParameters = {
        /** Security origin. */
        origin: string;
    };
}
/** Provides access to log entries. */
export declare namespace Log {
    /** Log entry. */
    interface LogEntry {
        /** Log entry source. */
        source: "xml" | "javascript" | "network" | "storage" | "appcache" | "rendering" | "security" | "deprecation" | "worker" | "violation" | "intervention" | "recommendation" | "other";
        /** Log entry severity. */
        level: "verbose" | "info" | "warning" | "error";
        /** Logged text. */
        text: string;
        /** Timestamp when this entry was added. */
        timestamp: Runtime.Timestamp;
        /** URL of the resource if known. */
        url?: string;
        /** Line number in the resource. */
        lineNumber?: number;
        /** JavaScript stack trace. */
        stackTrace?: Runtime.StackTrace;
        /** Identifier of the network request associated with this entry. */
        networkRequestId?: Network.RequestId;
        /** Identifier of the worker associated with this entry. */
        workerId?: string;
        /** Call arguments. */
        args?: Runtime.RemoteObject[];
    }
    /** Violation configuration setting. */
    interface ViolationSetting {
        /** Violation type. */
        name: "longTask" | "longLayout" | "blockedEvent" | "blockedParser" | "discouragedAPIUse" | "handler" | "recurringHandler";
        /** Time threshold to trigger upon. */
        threshold: number;
    }
    type EntryAddedParameters = {
        /** The entry. */
        entry: LogEntry;
    };
    type StartViolationsReportParameters = {
        /** Configuration for violations. */
        config: ViolationSetting[];
    };
}
/** The SystemInfo domain defines methods and events for querying low-level system information. */
export declare namespace SystemInfo {
    /** Describes a single graphics processor (GPU). */
    interface GPUDevice {
        /** PCI ID of the GPU vendor, if available; 0 otherwise. */
        vendorId: number;
        /** PCI ID of the GPU device, if available; 0 otherwise. */
        deviceId: number;
        /** String description of the GPU vendor, if the PCI ID is not available. */
        vendorString: string;
        /** String description of the GPU device, if the PCI ID is not available. */
        deviceString: string;
    }
    /** Provides information about the GPU(s) on the system. */
    interface GPUInfo {
        /** The graphics devices on the system. Element 0 is the primary GPU. */
        devices: GPUDevice[];
        /** An optional dictionary of additional GPU related attributes. */
        auxAttributes?: any;
        /** An optional dictionary of graphics features and their status. */
        featureStatus?: any;
        /** An optional array of GPU driver bug workarounds. */
        driverBugWorkarounds: string[];
    }
    type GetInfoReturn = {
        /** Information about the GPUs on the system. */
        gpu: GPUInfo;
        /** A platform-dependent description of the model of the machine. On Mac OS, this is, for example, 'MacBookPro'. Will be the empty string if not supported. */
        modelName: string;
        /** A platform-dependent description of the version of the machine. On Mac OS, this is, for example, '10.1'. Will be the empty string if not supported. */
        modelVersion: string;
        /** The command line string used to launch the browser. Will be the empty string if not supported. */
        commandLine: string;
    };
}
/** The Tethering domain defines methods and events for browser port binding. */
export declare namespace Tethering {
    type AcceptedParameters = {
        /** Port number that was successfully bound. */
        port: number;
        /** Connection id to be used. */
        connectionId: string;
    };
    type BindParameters = {
        /** Port number to bind. */
        port: number;
    };
    type UnbindParameters = {
        /** Port number to unbind. */
        port: number;
    };
}
/** The Browser domain defines methods and events for browser managing. */
export declare namespace Browser {
    type WindowID = number;
    /** The state of the browser window. */
    type WindowState = "normal" | "minimized" | "maximized" | "fullscreen";
    /** Browser window bounds information */
    interface Bounds {
        /** The offset from the left edge of the screen to the window in pixels. */
        left?: number;
        /** The offset from the top edge of the screen to the window in pixels. */
        top?: number;
        /** The window width in pixels. */
        width?: number;
        /** The window height in pixels. */
        height?: number;
        /** The window state. Default to normal. */
        windowState?: WindowState;
    }
    type GetWindowForTargetParameters = {
        /** Devtools agent host id. */
        targetId: Target.TargetID;
    };
    type GetWindowForTargetReturn = {
        /** Browser window id. */
        windowId: WindowID;
        /** Bounds information of the window. When window state is 'minimized', the restored window position and size are returned. */
        bounds: Bounds;
    };
    type GetVersionReturn = {
        /** Protocol version. */
        protocolVersion: string;
        /** Product name. */
        product: string;
        /** Product revision. */
        revision: string;
        /** User-Agent. */
        userAgent: string;
        /** V8 version. */
        jsVersion: string;
    };
    type SetWindowBoundsParameters = {
        /** Browser window id. */
        windowId: WindowID;
        /** New window bounds. The 'minimized', 'maximized' and 'fullscreen' states cannot be combined with 'left', 'top', 'width' or 'height'. Leaves unspecified fields unchanged. */
        bounds: Bounds;
    };
    type GetWindowBoundsParameters = {
        /** Browser window id. */
        windowId: WindowID;
    };
    type GetWindowBoundsReturn = {
        /** Bounds information of the window. When window state is 'minimized', the restored window position and size are returned. */
        bounds: Bounds;
    };
}
/** Provides information about the protocol schema. */
export declare namespace Schema {
    /** Description of the protocol domain. */
    interface Domain {
        /** Domain name. */
        name: string;
        /** Domain version. */
        version: string;
    }
    type GetDomainsReturn = {
        /** List of supported domains. */
        domains: Domain[];
    };
}
/** Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects. Evaluation results are returned as mirror object that expose object type, string representation and unique identifier that can be used for further object reference. Original objects are maintained in memory unless they are either explicitly released or are released along with the other objects in their object group. */
export declare namespace Runtime {
    /** Unique script identifier. */
    type ScriptId = string;
    /** Unique object identifier. */
    type RemoteObjectId = string;
    /** Primitive value which cannot be JSON-stringified. */
    type UnserializableValue = "Infinity" | "NaN" | "-Infinity" | "-0";
    /** Mirror object referencing original JavaScript object. */
    interface RemoteObject {
        /** Object type. */
        type: "object" | "function" | "undefined" | "string" | "number" | "boolean" | "symbol";
        /** Object subtype hint. Specified for <code>object</code> type values only. */
        subtype?: "array" | "null" | "node" | "regexp" | "date" | "map" | "set" | "weakmap" | "weakset" | "iterator" | "generator" | "error" | "proxy" | "promise" | "typedarray";
        /** Object class (constructor) name. Specified for <code>object</code> type values only. */
        className?: string;
        /** Remote object value in case of primitive values or JSON values (if it was requested). */
        value?: any;
        /** Primitive value which can not be JSON-stringified does not have <code>value</code>, but gets this property. */
        unserializableValue?: UnserializableValue;
        /** String representation of the object. */
        description?: string;
        /** Unique object identifier (for non-primitive values). */
        objectId?: RemoteObjectId;
        /** Preview containing abbreviated property values. Specified for <code>object</code> type values only. */
        preview?: ObjectPreview;
        customPreview?: CustomPreview;
    }
    interface CustomPreview {
        header: string;
        hasBody: boolean;
        formatterObjectId: RemoteObjectId;
        bindRemoteObjectFunctionId: RemoteObjectId;
        configObjectId?: RemoteObjectId;
    }
    /** Object containing abbreviated remote object value. */
    interface ObjectPreview {
        /** Object type. */
        type: "object" | "function" | "undefined" | "string" | "number" | "boolean" | "symbol";
        /** Object subtype hint. Specified for <code>object</code> type values only. */
        subtype?: "array" | "null" | "node" | "regexp" | "date" | "map" | "set" | "weakmap" | "weakset" | "iterator" | "generator" | "error";
        /** String representation of the object. */
        description?: string;
        /** True iff some of the properties or entries of the original object did not fit. */
        overflow: boolean;
        /** List of the properties. */
        properties: PropertyPreview[];
        /** List of the entries. Specified for <code>map</code> and <code>set</code> subtype values only. */
        entries?: EntryPreview[];
    }
    interface PropertyPreview {
        /** Property name. */
        name: string;
        /** Object type. Accessor means that the property itself is an accessor property. */
        type: "object" | "function" | "undefined" | "string" | "number" | "boolean" | "symbol" | "accessor";
        /** User-friendly property value string. */
        value?: string;
        /** Nested value preview. */
        valuePreview?: ObjectPreview;
        /** Object subtype hint. Specified for <code>object</code> type values only. */
        subtype?: "array" | "null" | "node" | "regexp" | "date" | "map" | "set" | "weakmap" | "weakset" | "iterator" | "generator" | "error";
    }
    interface EntryPreview {
        /** Preview of the key. Specified for map-like collection entries. */
        key?: ObjectPreview;
        /** Preview of the value. */
        value: ObjectPreview;
    }
    /** Object property descriptor. */
    interface PropertyDescriptor {
        /** Property name or symbol description. */
        name: string;
        /** The value associated with the property. */
        value?: RemoteObject;
        /** True if the value associated with the property may be changed (data descriptors only). */
        writable?: boolean;
        /** A function which serves as a getter for the property, or <code>undefined</code> if there is no getter (accessor descriptors only). */
        get?: RemoteObject;
        /** A function which serves as a setter for the property, or <code>undefined</code> if there is no setter (accessor descriptors only). */
        set?: RemoteObject;
        /** True if the type of this property descriptor may be changed and if the property may be deleted from the corresponding object. */
        configurable: boolean;
        /** True if this property shows up during enumeration of the properties on the corresponding object. */
        enumerable: boolean;
        /** True if the result was thrown during the evaluation. */
        wasThrown?: boolean;
        /** True if the property is owned for the object. */
        isOwn?: boolean;
        /** Property symbol object, if the property is of the <code>symbol</code> type. */
        symbol?: RemoteObject;
    }
    /** Object internal property descriptor. This property isn't normally visible in JavaScript code. */
    interface InternalPropertyDescriptor {
        /** Conventional property name. */
        name: string;
        /** The value associated with the property. */
        value?: RemoteObject;
    }
    /** Represents function call argument. Either remote object id <code>objectId</code>, primitive <code>value</code>, unserializable primitive value or neither of (for undefined) them should be specified. */
    interface CallArgument {
        /** Primitive value or serializable javascript object. */
        value?: any;
        /** Primitive value which can not be JSON-stringified. */
        unserializableValue?: UnserializableValue;
        /** Remote object handle. */
        objectId?: RemoteObjectId;
    }
    /** Id of an execution context. */
    type ExecutionContextId = number;
    /** Description of an isolated world. */
    interface ExecutionContextDescription {
        /** Unique id of the execution context. It can be used to specify in which execution context script evaluation should be performed. */
        id: ExecutionContextId;
        /** Execution context origin. */
        origin: string;
        /** Human readable name describing given context. */
        name: string;
        /** Embedder-specific auxiliary data. */
        auxData?: any;
    }
    /** Detailed information about exception (or error) that was thrown during script compilation or execution. */
    interface ExceptionDetails {
        /** Exception id. */
        exceptionId: number;
        /** Exception text, which should be used together with exception object when available. */
        text: string;
        /** Line number of the exception location (0-based). */
        lineNumber: number;
        /** Column number of the exception location (0-based). */
        columnNumber: number;
        /** Script ID of the exception location. */
        scriptId?: ScriptId;
        /** URL of the exception location, to be used when the script was not reported. */
        url?: string;
        /** JavaScript stack trace if available. */
        stackTrace?: StackTrace;
        /** Exception object if available. */
        exception?: RemoteObject;
        /** Identifier of the context where exception happened. */
        executionContextId?: ExecutionContextId;
    }
    /** Number of milliseconds since epoch. */
    type Timestamp = number;
    /** Stack entry for runtime errors and assertions. */
    interface CallFrame {
        /** JavaScript function name. */
        functionName: string;
        /** JavaScript script id. */
        scriptId: ScriptId;
        /** JavaScript script name or url. */
        url: string;
        /** JavaScript script line number (0-based). */
        lineNumber: number;
        /** JavaScript script column number (0-based). */
        columnNumber: number;
    }
    /** Call frames for assertions or error messages. */
    interface StackTrace {
        /** String label of this stack trace. For async traces this may be a name of the function that initiated the async call. */
        description?: string;
        /** JavaScript function name. */
        callFrames: CallFrame[];
        /** Asynchronous JavaScript stack trace that preceded this stack, if available. */
        parent?: StackTrace;
        /** Creation frame of the Promise which produced the next synchronous trace when resolved, if available. */
        promiseCreationFrame?: CallFrame;
    }
    type AsyncTaskId = string;
    type ExecutionContextCreatedParameters = {
        /** A newly created execution context. */
        context: ExecutionContextDescription;
    };
    type ExecutionContextDestroyedParameters = {
        /** Id of the destroyed context */
        executionContextId: ExecutionContextId;
    };
    type ExceptionThrownParameters = {
        /** Timestamp of the exception. */
        timestamp: Timestamp;
        exceptionDetails: ExceptionDetails;
    };
    type ExceptionRevokedParameters = {
        /** Reason describing why exception was revoked. */
        reason: string;
        /** The id of revoked exception, as reported in <code>exceptionThrown</code>. */
        exceptionId: number;
    };
    type ConsoleAPICalledParameters = {
        /** Type of the call. */
        type: "log" | "debug" | "info" | "error" | "warning" | "dir" | "dirxml" | "table" | "trace" | "clear" | "startGroup" | "startGroupCollapsed" | "endGroup" | "assert" | "profile" | "profileEnd" | "count" | "timeEnd";
        /** Call arguments. */
        args: RemoteObject[];
        /** Identifier of the context where the call was made. */
        executionContextId: ExecutionContextId;
        /** Call timestamp. */
        timestamp: Timestamp;
        /** Stack trace captured when the call was made. */
        stackTrace?: StackTrace;
        /** Console context descriptor for calls on non-default console context (not console.*): 'anonymous#unique-logger-id' for call on unnamed context, 'name#unique-logger-id' for call on named context. */
        context?: string;
    };
    type InspectRequestedParameters = {
        object: RemoteObject;
        hints: any;
    };
    type EvaluateParameters = {
        /** Expression to evaluate. */
        expression: string;
        /** Symbolic group name that can be used to release multiple objects. */
        objectGroup?: string;
        /** Determines whether Command Line API should be available during the evaluation. */
        includeCommandLineAPI?: boolean;
        /** In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides <code>setPauseOnException</code> state. */
        silent?: boolean;
        /** Specifies in which execution context to perform evaluation. If the parameter is omitted the evaluation will be performed in the context of the inspected page. */
        contextId?: ExecutionContextId;
        /** Whether the result is expected to be a JSON object that should be sent by value. */
        returnByValue?: boolean;
        /** Whether preview should be generated for the result. */
        generatePreview?: boolean;
        /** Whether execution should be treated as initiated by user in the UI. */
        userGesture?: boolean;
        /** Whether execution should <code>await</code> for resulting value and return once awaited promise is resolved. */
        awaitPromise?: boolean;
    };
    type EvaluateReturn = {
        /** Evaluation result. */
        result: RemoteObject;
        /** Exception details. */
        exceptionDetails?: ExceptionDetails;
    };
    type AwaitPromiseParameters = {
        /** Identifier of the promise. */
        promiseObjectId: RemoteObjectId;
        /** Whether the result is expected to be a JSON object that should be sent by value. */
        returnByValue?: boolean;
        /** Whether preview should be generated for the result. */
        generatePreview?: boolean;
    };
    type AwaitPromiseReturn = {
        /** Promise result. Will contain rejected value if promise was rejected. */
        result: RemoteObject;
        /** Exception details if stack strace is available. */
        exceptionDetails?: ExceptionDetails;
    };
    type CallFunctionOnParameters = {
        /** Declaration of the function to call. */
        functionDeclaration: string;
        /** Identifier of the object to call function on. Either objectId or executionContextId should be specified. */
        objectId?: RemoteObjectId;
        /** Call arguments. All call arguments must belong to the same JavaScript world as the target object. */
        arguments?: CallArgument[];
        /** In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides <code>setPauseOnException</code> state. */
        silent?: boolean;
        /** Whether the result is expected to be a JSON object which should be sent by value. */
        returnByValue?: boolean;
        /** Whether preview should be generated for the result. */
        generatePreview?: boolean;
        /** Whether execution should be treated as initiated by user in the UI. */
        userGesture?: boolean;
        /** Whether execution should <code>await</code> for resulting value and return once awaited promise is resolved. */
        awaitPromise?: boolean;
        /** Specifies execution context which global object will be used to call function on. Either executionContextId or objectId should be specified. */
        executionContextId?: ExecutionContextId;
        /** Symbolic group name that can be used to release multiple objects. If objectGroup is not specified and objectId is, objectGroup will be inherited from object. */
        objectGroup?: string;
    };
    type CallFunctionOnReturn = {
        /** Call result. */
        result: RemoteObject;
        /** Exception details. */
        exceptionDetails?: ExceptionDetails;
    };
    type GetPropertiesParameters = {
        /** Identifier of the object to return properties for. */
        objectId: RemoteObjectId;
        /** If true, returns properties belonging only to the element itself, not to its prototype chain. */
        ownProperties?: boolean;
        /** If true, returns accessor properties (with getter/setter) only; internal properties are not returned either. */
        accessorPropertiesOnly?: boolean;
        /** Whether preview should be generated for the results. */
        generatePreview?: boolean;
    };
    type GetPropertiesReturn = {
        /** Object properties. */
        result: PropertyDescriptor[];
        /** Internal object properties (only of the element itself). */
        internalProperties?: InternalPropertyDescriptor[];
        /** Exception details. */
        exceptionDetails?: ExceptionDetails;
    };
    type ReleaseObjectParameters = {
        /** Identifier of the object to release. */
        objectId: RemoteObjectId;
    };
    type ReleaseObjectGroupParameters = {
        /** Symbolic object group name. */
        objectGroup: string;
    };
    type SetCustomObjectFormatterEnabledParameters = {
        enabled: boolean;
    };
    type CompileScriptParameters = {
        /** Expression to compile. */
        expression: string;
        /** Source url to be set for the script. */
        sourceURL: string;
        /** Specifies whether the compiled script should be persisted. */
        persistScript: boolean;
        /** Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page. */
        executionContextId?: ExecutionContextId;
    };
    type CompileScriptReturn = {
        /** Id of the script. */
        scriptId?: ScriptId;
        /** Exception details. */
        exceptionDetails?: ExceptionDetails;
    };
    type RunScriptParameters = {
        /** Id of the script to run. */
        scriptId: ScriptId;
        /** Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page. */
        executionContextId?: ExecutionContextId;
        /** Symbolic group name that can be used to release multiple objects. */
        objectGroup?: string;
        /** In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides <code>setPauseOnException</code> state. */
        silent?: boolean;
        /** Determines whether Command Line API should be available during the evaluation. */
        includeCommandLineAPI?: boolean;
        /** Whether the result is expected to be a JSON object which should be sent by value. */
        returnByValue?: boolean;
        /** Whether preview should be generated for the result. */
        generatePreview?: boolean;
        /** Whether execution should <code>await</code> for resulting value and return once awaited promise is resolved. */
        awaitPromise?: boolean;
    };
    type RunScriptReturn = {
        /** Run result. */
        result: RemoteObject;
        /** Exception details. */
        exceptionDetails?: ExceptionDetails;
    };
    type QueryObjectsParameters = {
        /** Identifier of the prototype to return objects for. */
        prototypeObjectId: RemoteObjectId;
    };
    type QueryObjectsReturn = {
        /** Array with objects. */
        objects: RemoteObject;
    };
    type GlobalLexicalScopeNamesParameters = {
        /** Specifies in which execution context to lookup global scope variables. */
        executionContextId?: ExecutionContextId;
    };
    type GlobalLexicalScopeNamesReturn = {
        names: string[];
    };
}
/** Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing breakpoints, stepping through execution, exploring stack traces, etc. */
export declare namespace Debugger {
    /** Breakpoint identifier. */
    type BreakpointId = string;
    /** Call frame identifier. */
    type CallFrameId = string;
    /** Location in the source code. */
    interface Location {
        /** Script identifier as reported in the <code>Debugger.scriptParsed</code>. */
        scriptId: Runtime.ScriptId;
        /** Line number in the script (0-based). */
        lineNumber: number;
        /** Column number in the script (0-based). */
        columnNumber?: number;
    }
    /** Location in the source code. */
    interface ScriptPosition {
        lineNumber: number;
        columnNumber: number;
    }
    /** JavaScript call frame. Array of call frames form the call stack. */
    interface CallFrame {
        /** Call frame identifier. This identifier is only valid while the virtual machine is paused. */
        callFrameId: CallFrameId;
        /** Name of the JavaScript function called on this call frame. */
        functionName: string;
        /** Location in the source code. */
        functionLocation?: Location;
        /** Location in the source code. */
        location: Location;
        /** JavaScript script name or url. */
        url: string;
        /** Scope chain for this call frame. */
        scopeChain: Scope[];
        /** <code>this</code> object for this call frame. */
        this: Runtime.RemoteObject;
        /** The value being returned, if the function is at return point. */
        returnValue?: Runtime.RemoteObject;
    }
    /** Scope description. */
    interface Scope {
        /** Scope type. */
        type: "global" | "local" | "with" | "closure" | "catch" | "block" | "script" | "eval" | "module";
        /** Object representing the scope. For <code>global</code> and <code>with</code> scopes it represents the actual object; for the rest of the scopes, it is artificial transient object enumerating scope variables as its properties. */
        object: Runtime.RemoteObject;
        name?: string;
        /** Location in the source code where scope starts */
        startLocation?: Location;
        /** Location in the source code where scope ends */
        endLocation?: Location;
    }
    /** Search match for resource. */
    interface SearchMatch {
        /** Line number in resource content. */
        lineNumber: number;
        /** Line with match content. */
        lineContent: string;
    }
    interface BreakLocation {
        /** Script identifier as reported in the <code>Debugger.scriptParsed</code>. */
        scriptId: Runtime.ScriptId;
        /** Line number in the script (0-based). */
        lineNumber: number;
        /** Column number in the script (0-based). */
        columnNumber?: number;
        type?: "debuggerStatement" | "call" | "return";
    }
    type ScriptParsedParameters = {
        /** Identifier of the script parsed. */
        scriptId: Runtime.ScriptId;
        /** URL or name of the script parsed (if any). */
        url: string;
        /** Line offset of the script within the resource with given URL (for script tags). */
        startLine: number;
        /** Column offset of the script within the resource with given URL. */
        startColumn: number;
        /** Last line of the script. */
        endLine: number;
        /** Length of the last line of the script. */
        endColumn: number;
        /** Specifies script creation context. */
        executionContextId: Runtime.ExecutionContextId;
        /** Content hash of the script. */
        hash: string;
        /** Embedder-specific auxiliary data. */
        executionContextAuxData?: any;
        /** True, if this script is generated as a result of the live edit operation. */
        isLiveEdit?: boolean;
        /** URL of source map associated with script (if any). */
        sourceMapURL?: string;
        /** True, if this script has sourceURL. */
        hasSourceURL?: boolean;
        /** True, if this script is ES6 module. */
        isModule?: boolean;
        /** This script length. */
        length?: number;
        /** JavaScript top stack frame of where the script parsed event was triggered if available. */
        stackTrace?: Runtime.StackTrace;
    };
    type ScriptFailedToParseParameters = {
        /** Identifier of the script parsed. */
        scriptId: Runtime.ScriptId;
        /** URL or name of the script parsed (if any). */
        url: string;
        /** Line offset of the script within the resource with given URL (for script tags). */
        startLine: number;
        /** Column offset of the script within the resource with given URL. */
        startColumn: number;
        /** Last line of the script. */
        endLine: number;
        /** Length of the last line of the script. */
        endColumn: number;
        /** Specifies script creation context. */
        executionContextId: Runtime.ExecutionContextId;
        /** Content hash of the script. */
        hash: string;
        /** Embedder-specific auxiliary data. */
        executionContextAuxData?: any;
        /** URL of source map associated with script (if any). */
        sourceMapURL?: string;
        /** True, if this script has sourceURL. */
        hasSourceURL?: boolean;
        /** True, if this script is ES6 module. */
        isModule?: boolean;
        /** This script length. */
        length?: number;
        /** JavaScript top stack frame of where the script parsed event was triggered if available. */
        stackTrace?: Runtime.StackTrace;
    };
    type BreakpointResolvedParameters = {
        /** Breakpoint unique identifier. */
        breakpointId: BreakpointId;
        /** Actual breakpoint location. */
        location: Location;
    };
    type PausedParameters = {
        /** Call stack the virtual machine stopped on. */
        callFrames: CallFrame[];
        /** Pause reason. */
        reason: "XHR" | "DOM" | "EventListener" | "exception" | "assert" | "debugCommand" | "promiseRejection" | "OOM" | "other" | "ambiguous";
        /** Object containing break-specific auxiliary properties. */
        data?: any;
        /** Hit breakpoints IDs */
        hitBreakpoints?: string[];
        /** Async stack trace, if any. */
        asyncStackTrace?: Runtime.StackTrace;
        /** Scheduled async task id. */
        scheduledAsyncTaskId?: Runtime.AsyncTaskId;
    };
    type SetBreakpointsActiveParameters = {
        /** New value for breakpoints active state. */
        active: boolean;
    };
    type SetSkipAllPausesParameters = {
        /** New value for skip pauses state. */
        skip: boolean;
    };
    type SetBreakpointByUrlParameters = {
        /** Line number to set breakpoint at. */
        lineNumber: number;
        /** URL of the resources to set breakpoint on. */
        url?: string;
        /** Regex pattern for the URLs of the resources to set breakpoints on. Either <code>url</code> or <code>urlRegex</code> must be specified. */
        urlRegex?: string;
        /** Script hash of the resources to set breakpoint on. */
        scriptHash?: string;
        /** Offset in the line to set breakpoint at. */
        columnNumber?: number;
        /** Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true. */
        condition?: string;
    };
    type SetBreakpointByUrlReturn = {
        /** Id of the created breakpoint for further reference. */
        breakpointId: BreakpointId;
        /** List of the locations this breakpoint resolved into upon addition. */
        locations: Location[];
    };
    type SetBreakpointParameters = {
        /** Location to set breakpoint in. */
        location: Location;
        /** Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true. */
        condition?: string;
    };
    type SetBreakpointReturn = {
        /** Id of the created breakpoint for further reference. */
        breakpointId: BreakpointId;
        /** Location this breakpoint resolved into. */
        actualLocation: Location;
    };
    type RemoveBreakpointParameters = {
        breakpointId: BreakpointId;
    };
    type GetPossibleBreakpointsParameters = {
        /** Start of range to search possible breakpoint locations in. */
        start: Location;
        /** End of range to search possible breakpoint locations in (excluding). When not specified, end of scripts is used as end of range. */
        end?: Location;
        /** Only consider locations which are in the same (non-nested) function as start. */
        restrictToFunction?: boolean;
    };
    type GetPossibleBreakpointsReturn = {
        /** List of the possible breakpoint locations. */
        locations: BreakLocation[];
    };
    type ContinueToLocationParameters = {
        /** Location to continue to. */
        location: Location;
        targetCallFrames?: "any" | "current";
    };
    type PauseOnAsyncTaskParameters = {
        /** Debugger will pause when given async task is started. */
        asyncTaskId: Runtime.AsyncTaskId;
    };
    type StepIntoParameters = {
        /** Debugger will issue additional Debugger.paused notification if any async task is scheduled before next pause. */
        breakOnAsyncCall?: boolean;
    };
    type SearchInContentParameters = {
        /** Id of the script to search in. */
        scriptId: Runtime.ScriptId;
        /** String to search for. */
        query: string;
        /** If true, search is case sensitive. */
        caseSensitive?: boolean;
        /** If true, treats string parameter as regex. */
        isRegex?: boolean;
    };
    type SearchInContentReturn = {
        /** List of search matches. */
        result: SearchMatch[];
    };
    type SetScriptSourceParameters = {
        /** Id of the script to edit. */
        scriptId: Runtime.ScriptId;
        /** New content of the script. */
        scriptSource: string;
        /**  If true the change will not actually be applied. Dry run may be used to get result description without actually modifying the code. */
        dryRun?: boolean;
    };
    type SetScriptSourceReturn = {
        /** New stack trace in case editing has happened while VM was stopped. */
        callFrames?: CallFrame[];
        /** Whether current call stack  was modified after applying the changes. */
        stackChanged?: boolean;
        /** Async stack trace, if any. */
        asyncStackTrace?: Runtime.StackTrace;
        /** Exception details if any. */
        exceptionDetails?: Runtime.ExceptionDetails;
    };
    type RestartFrameParameters = {
        /** Call frame identifier to evaluate on. */
        callFrameId: CallFrameId;
    };
    type RestartFrameReturn = {
        /** New stack trace. */
        callFrames: CallFrame[];
        /** Async stack trace, if any. */
        asyncStackTrace?: Runtime.StackTrace;
    };
    type GetScriptSourceParameters = {
        /** Id of the script to get source for. */
        scriptId: Runtime.ScriptId;
    };
    type GetScriptSourceReturn = {
        /** Script source. */
        scriptSource: string;
    };
    type SetPauseOnExceptionsParameters = {
        /** Pause on exceptions mode. */
        state: "none" | "uncaught" | "all";
    };
    type EvaluateOnCallFrameParameters = {
        /** Call frame identifier to evaluate on. */
        callFrameId: CallFrameId;
        /** Expression to evaluate. */
        expression: string;
        /** String object group name to put result into (allows rapid releasing resulting object handles using <code>releaseObjectGroup</code>). */
        objectGroup?: string;
        /** Specifies whether command line API should be available to the evaluated expression, defaults to false. */
        includeCommandLineAPI?: boolean;
        /** In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides <code>setPauseOnException</code> state. */
        silent?: boolean;
        /** Whether the result is expected to be a JSON object that should be sent by value. */
        returnByValue?: boolean;
        /** Whether preview should be generated for the result. */
        generatePreview?: boolean;
        /** Whether to throw an exception if side effect cannot be ruled out during evaluation. */
        throwOnSideEffect?: boolean;
    };
    type EvaluateOnCallFrameReturn = {
        /** Object wrapper for the evaluation result. */
        result: Runtime.RemoteObject;
        /** Exception details. */
        exceptionDetails?: Runtime.ExceptionDetails;
    };
    type SetVariableValueParameters = {
        /** 0-based number of scope as was listed in scope chain. Only 'local', 'closure' and 'catch' scope types are allowed. Other scopes could be manipulated manually. */
        scopeNumber: number;
        /** Variable name. */
        variableName: string;
        /** New variable value. */
        newValue: Runtime.CallArgument;
        /** Id of callframe that holds variable. */
        callFrameId: CallFrameId;
    };
    type SetReturnValueParameters = {
        /** New return value. */
        newValue: Runtime.CallArgument;
    };
    type SetAsyncCallStackDepthParameters = {
        /** Maximum depth of async call stacks. Setting to <code>0</code> will effectively disable collecting async call stacks (default). */
        maxDepth: number;
    };
    type SetBlackboxPatternsParameters = {
        /** Array of regexps that will be used to check script url for blackbox state. */
        patterns: string[];
    };
    type SetBlackboxedRangesParameters = {
        /** Id of the script. */
        scriptId: Runtime.ScriptId;
        positions: ScriptPosition[];
    };
}
/** This domain is deprecated - use Runtime or Log instead. */
export declare namespace Console {
    /** Console message. */
    interface ConsoleMessage {
        /** Message source. */
        source: "xml" | "javascript" | "network" | "console-api" | "storage" | "appcache" | "rendering" | "security" | "other" | "deprecation" | "worker";
        /** Message severity. */
        level: "log" | "warning" | "error" | "debug" | "info";
        /** Message text. */
        text: string;
        /** URL of the message origin. */
        url?: string;
        /** Line number in the resource that generated this message (1-based). */
        line?: number;
        /** Column number in the resource that generated this message (1-based). */
        column?: number;
    }
    type MessageAddedParameters = {
        /** Console message that has been added. */
        message: ConsoleMessage;
    };
}
export declare namespace Profiler {
    /** Profile node. Holds callsite information, execution statistics and child nodes. */
    interface ProfileNode {
        /** Unique id of the node. */
        id: number;
        /** Function location. */
        callFrame: Runtime.CallFrame;
        /** Number of samples where this node was on top of the call stack. */
        hitCount?: number;
        /** Child node ids. */
        children?: number[];
        /** The reason of being not optimized. The function may be deoptimized or marked as don't optimize. */
        deoptReason?: string;
        /** An array of source position ticks. */
        positionTicks?: PositionTickInfo[];
    }
    /** Profile. */
    interface Profile {
        /** The list of profile nodes. First item is the root node. */
        nodes: ProfileNode[];
        /** Profiling start timestamp in microseconds. */
        startTime: number;
        /** Profiling end timestamp in microseconds. */
        endTime: number;
        /** Ids of samples top nodes. */
        samples?: number[];
        /** Time intervals between adjacent samples in microseconds. The first delta is relative to the profile startTime. */
        timeDeltas?: number[];
    }
    /** Specifies a number of samples attributed to a certain source position. */
    interface PositionTickInfo {
        /** Source line number (1-based). */
        line: number;
        /** Number of samples attributed to the source line. */
        ticks: number;
    }
    /** Coverage data for a source range. */
    interface CoverageRange {
        /** JavaScript script source offset for the range start. */
        startOffset: number;
        /** JavaScript script source offset for the range end. */
        endOffset: number;
        /** Collected execution count of the source range. */
        count: number;
    }
    /** Coverage data for a JavaScript function. */
    interface FunctionCoverage {
        /** JavaScript function name. */
        functionName: string;
        /** Source ranges inside the function with coverage data. */
        ranges: CoverageRange[];
        /** Whether coverage data for this function has block granularity. */
        isBlockCoverage: boolean;
    }
    /** Coverage data for a JavaScript script. */
    interface ScriptCoverage {
        /** JavaScript script id. */
        scriptId: Runtime.ScriptId;
        /** JavaScript script name or url. */
        url: string;
        /** Functions contained in the script that has coverage data. */
        functions: FunctionCoverage[];
    }
    /** Describes a type collected during runtime. */
    interface TypeObject {
        /** Name of a type collected with type profiling. */
        name: string;
    }
    /** Source offset and types for a parameter or return value. */
    interface TypeProfileEntry {
        /** Source offset of the parameter or end of function for return values. */
        offset: number;
        /** The types for this parameter or return value. */
        types: TypeObject[];
    }
    /** Type profile data collected during runtime for a JavaScript script. */
    interface ScriptTypeProfile {
        /** JavaScript script id. */
        scriptId: Runtime.ScriptId;
        /** JavaScript script name or url. */
        url: string;
        /** Type profile entries for parameters and return values of the functions in the script. */
        entries: TypeProfileEntry[];
    }
    type ConsoleProfileStartedParameters = {
        id: string;
        /** Location of console.profile(). */
        location: Debugger.Location;
        /** Profile title passed as an argument to console.profile(). */
        title?: string;
    };
    type ConsoleProfileFinishedParameters = {
        id: string;
        /** Location of console.profileEnd(). */
        location: Debugger.Location;
        profile: Profile;
        /** Profile title passed as an argument to console.profile(). */
        title?: string;
    };
    type SetSamplingIntervalParameters = {
        /** New sampling interval in microseconds. */
        interval: number;
    };
    type StopReturn = {
        /** Recorded profile. */
        profile: Profile;
    };
    type StartPreciseCoverageParameters = {
        /** Collect accurate call counts beyond simple 'covered' or 'not covered'. */
        callCount?: boolean;
        /** Collect block-based coverage. */
        detailed?: boolean;
    };
    type TakePreciseCoverageReturn = {
        /** Coverage data for the current isolate. */
        result: ScriptCoverage[];
    };
    type GetBestEffortCoverageReturn = {
        /** Coverage data for the current isolate. */
        result: ScriptCoverage[];
    };
    type TakeTypeProfileReturn = {
        /** Type profile for all scripts since startTypeProfile() was turned on. */
        result: ScriptTypeProfile[];
    };
}
export declare namespace HeapProfiler {
    /** Heap snapshot object id. */
    type HeapSnapshotObjectId = string;
    /** Sampling Heap Profile node. Holds callsite information, allocation statistics and child nodes. */
    interface SamplingHeapProfileNode {
        /** Function location. */
        callFrame: Runtime.CallFrame;
        /** Allocations size in bytes for the node excluding children. */
        selfSize: number;
        /** Child nodes. */
        children: SamplingHeapProfileNode[];
    }
    /** Profile. */
    interface SamplingHeapProfile {
        head: SamplingHeapProfileNode;
    }
    type AddHeapSnapshotChunkParameters = {
        chunk: string;
    };
    type ReportHeapSnapshotProgressParameters = {
        done: number;
        total: number;
        finished?: boolean;
    };
    type LastSeenObjectIdParameters = {
        lastSeenObjectId: number;
        timestamp: number;
    };
    type HeapStatsUpdateParameters = {
        /** An array of triplets. Each triplet describes a fragment. The first integer is the fragment index, the second integer is a total count of objects for the fragment, the third integer is a total size of the objects for the fragment. */
        statsUpdate: number[];
    };
    type StartTrackingHeapObjectsParameters = {
        trackAllocations?: boolean;
    };
    type StopTrackingHeapObjectsParameters = {
        /** If true 'reportHeapSnapshotProgress' events will be generated while snapshot is being taken when the tracking is stopped. */
        reportProgress?: boolean;
    };
    type TakeHeapSnapshotParameters = {
        /** If true 'reportHeapSnapshotProgress' events will be generated while snapshot is being taken. */
        reportProgress?: boolean;
    };
    type GetObjectByHeapObjectIdParameters = {
        objectId: HeapSnapshotObjectId;
        /** Symbolic group name that can be used to release multiple objects. */
        objectGroup?: string;
    };
    type GetObjectByHeapObjectIdReturn = {
        /** Evaluation result. */
        result: Runtime.RemoteObject;
    };
    type AddInspectedHeapObjectParameters = {
        /** Heap snapshot object id to be accessible by means of $x command line API. */
        heapObjectId: HeapSnapshotObjectId;
    };
    type GetHeapObjectIdParameters = {
        /** Identifier of the object to get heap object id for. */
        objectId: Runtime.RemoteObjectId;
    };
    type GetHeapObjectIdReturn = {
        /** Id of the heap snapshot object corresponding to the passed remote object id. */
        heapSnapshotObjectId: HeapSnapshotObjectId;
    };
    type StartSamplingParameters = {
        /** Average sample interval in bytes. Poisson distribution is used for the intervals. The default value is 32768 bytes. */
        samplingInterval?: number;
    };
    type StopSamplingReturn = {
        /** Recorded sampling heap profile. */
        profile: SamplingHeapProfile;
    };
    type GetSamplingProfileReturn = {
        /** Return the sampling profile being collected. */
        profile: SamplingHeapProfile;
    };
}
